/*=============================================================================================
/==============================================================================================
/	Module Name	: calc_U_ESI_Fpo_hiu2p.sas (called by "multi_person_HIUs.sas")									
/ 	Purpose    	: To calculate the utilities of multi-person HIUs from choosing the alternatives
/				  of the ESI family coverage with Public Insurance 
/	Summary		:
/	(1) For each HIU, calculate the probabilities of being in each of the 16 health states and 
/			expected medical spending associated with each state.
/	(2) Based on the expected health states and expected spending, calculate expected OOP under
/		different coverage types:
/		(2a) ESI: PPO, HMO, HDHP
/		(2b) Medicaid/CHIP
/	(3) Based on the variation of possible health states and associated spending, calculate
/		the variance of OOP
/		(3a) ESI: PPO, HMO, HDHP
/		(3b) Medicaid/CHIP
/	(4) Calculate the number of people with each of 3 types of ESI and Medicaid/CHIP in each HIU.
/			The unweighted number is used in the utility shifter calculation.  
/			The weighted number is used in the probability calculations in simulate_multi_person_HIUs.sas. 
/	(5) Calculate utilities of ESI (given Medicaid/CHIP is also available to the HIU) from the perspectives of both firms and HIUs.
/		(5a) HIUs:  Each person with an offer will be offered one type of ESI. 
/					Conditional on the type of ESI offered to the HIU member, calculate utilities.
/		(5b) Firms: Calculate utilities associated with each type of ESI, 
/					because firms compare utilities across those options and decide which type of ESI to offer. 				
/	Notes: (1) This MACRO calc_U_ESI_Fpo_hiu2p(person,firm_u=,hiu_u=) has three arguments: 
/				The first argument is the person offered an ESI family plan
/				The second and third arguments indicate whether to calculate the firm
/				objective function value (firm_u=yes, hiu_u=no) or to calculate HIU
/				utilities (firm_u=no, hiu_u=yes).
/				Note that HIU's utilities are also used in the firm behavior calibration,
/				because firms evaluate their workers' demand for ESI.
/			(2) This MACRO is called in both calibration and simulation routines. When called in
/				the simulation routine, this code uses the utility shifter already calibrated
/			(3) Utility for the GNL model is defined in the slide deck and has 5 components: 
/				(a) Income
/				(b) Costs associated with the alternative (such as premiums and
/					individual mandate penalty if applicable) 
/				(c) Expected out-of-pocket (OOP) health care spending
/				(d) Risk associated with uncertain OOP spending 
/				(e) (Unobservable) utility shifter 
/				Some of those components are calculated in codes that precede this code
/				For simulation, those components are HIU income, 
/							post-tax/post-subsidy premiums for non-group and ESI, 
/							and utility shifters calibrated
/				For calibration, those components are HIU income, 
/							post-tax/post-subsidy premiums for non-group and ESI
/				Other components are calculated in this code: expected OOP spending and  
/							risk associated with the uncertain OOP spending.
/ 			For the more information on the utility function, see Congressional Budget Office,
/			HISIM2The Health Insurance Simulation Model Used in Preparing CBOs Spring 2019
/			Baseline Budget Projections (April 2019), www.cbo.gov/publication/55097.
/	The code is written in SAS, version 9.4.
/==============================================================================================
/============================================================================================*/

%macro calc_U_ESI_Fpo_hiu2p(person,firm_u=,hiu_u=);

	%local j p;

	/******************************************************************************************
	/	Initialize arrays to 0 for utility calculation
	/*****************************************************************************************/
	%initialize_array_0;

	/******************************************************************************************
	/	For the HIUs whose member [&person] has an family plan offer and is not eligible for public 
	/	insurance and the HIU can have different types of coverage for different members.
	/*****************************************************************************************/
	
	if offer_family_sim_&person.=1 and medicaid_CHIP_elig[&person.] ne 1 and split_decision_hiu=1 then do;

		/************************************************************************************** 
		/	Initialize count variables to 0 for utility calculation
		/*************************************************************************************/
		%initialize_n_to_0;

		/************************************************************************************** 
		/	Initialize the location array that identifies people index in a family plan to 0
		/*************************************************************************************/
		do i=1 to &DIM.;
			location[i]=0;
		end;

		/************************************************************************************** 
		/	Count the number of people who can make ESI decisions, 
		/	i.e. people ineligible for public insurance or non-dependent children
		/		    (excluding those whose coverage types were not held constant)
		/	and populate the location array indexing the person number corresponding to 
		/			the total number of people who can make ESI decisions in the HIU
		/*************************************************************************************/
		c=0;
		N=0;
		do i=1 to &DIM.;
			if (medicaid_CHIP_elig[i] ne 1 or market_ID_primary[i] ne 1) and age[i] ne . then do;
				c = c+1;
				N = sum(N,wgt[i]/wgt[i]);
				location[c] = i;
			end;
		end;

		/**************************************************************************************
		/	Estimate HIU-level health spending probabilities for family plan coverage options
		/	This macro outputs individual-specific arrays of prob_hlth_hiu and spend_hlth_hiu
		/	Note: For details about probability distribution of health spending, see 
		/		  Congressional Budget Office, "Sources and Preparation of Data Used in HISIM2CBOs 
		/		  Health Insurance Simulation Model" (April 2019), www.cbo.gov/publication/55087						
		/*************************************************************************************/		
		%estimate_HIU_HS_probs;

/**********************************************************************************************
/	Calculate the expected out-of-pocket health care spending 
/*********************************************************************************************/	

		/**************************************************************************************
		/	For HIUs with 2 or more members eligible for the ESI family plan
		/*************************************************************************************/
		if N>1 then do;

			/**********************************************************************************
			/	Calculate the expected out-of-pocket health care spending on ESI plans by plan type, 
			/   looping through all 16 possible health states
			/*********************************************************************************/	
			do g=1 to 16;
				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family PPO is greater than zero 
				/*****************************************************************************/
				if coins_pre_esi_ppo_f[&person.]>0 then do;
					e_oop_spend_ppo_hlth[g] = prob_hlth_hiu[g]*sum((spend_hlth_hiu[g]<=deduct_esi_ppo_f[&person.]/coins_pre_esi_ppo_f[&person.])*
													  (spend_hlth_hiu[g]*coins_pre_esi_ppo_f[&person.]),
													  (spend_hlth_hiu[g]>deduct_esi_ppo_f[&person.]/coins_pre_esi_ppo_f[&person.])*
													  (min(sum(deduct_esi_ppo_f[&person.],(spend_hlth_hiu[g]-deduct_esi_ppo_f[&person.]/coins_pre_esi_ppo_f[&person.])*coins_post_esi_ppo_f[&person.]),oopmax_esi_ppo_f[&person.])));
				end;
				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family HMO is greater than zero 
				/*****************************************************************************/	
				if coins_pre_esi_hmo_f[&person.]>0 then do;
					e_oop_spend_hmo_hlth[g] = prob_hlth_hiu[g]*sum((spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])<=deduct_esi_hmo_f[&person.]/coins_pre_esi_hmo_f[&person.])*
											          (spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])*coins_pre_esi_hmo_f[&person.]),
													  (spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])>deduct_esi_hmo_f[&person.]/coins_pre_esi_hmo_f[&person.])*
													  (min(sum(deduct_esi_hmo_f[&person.],(spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])-deduct_esi_hmo_f[&person.]/coins_pre_esi_hmo_f[&person.])*coins_post_esi_hmo_f[&person.]),oopmax_esi_hmo_f[&person.])));
				end;
				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family HDHP is greater than zero 
				/*****************************************************************************/
				if coins_pre_esi_hdhp_f[&person.]>0 then do;
					e_oop_spend_hdhp_hlth[g] = prob_hlth_hiu[g]*sum((spend_hlth_hiu[g]<=deduct_esi_hdhp_f[&person.]/coins_pre_esi_hdhp_f[&person.])*
													   (max(0,sum(spend_hlth_hiu[g]*coins_pre_esi_hdhp_f[&person.],-HSA_esi_hdhp_f[&person.]))),
													   (spend_hlth_hiu[g]>deduct_esi_hdhp_f[&person.]/coins_pre_esi_hdhp_f[&person.])*
													   (min(max(0,sum(deduct_esi_hdhp_f[&person.],(spend_hlth_hiu[g]-deduct_esi_hdhp_f[&person.]/coins_pre_esi_hdhp_f[&person.])*coins_post_esi_hdhp_f[&person.],-HSA_esi_hdhp_f[&person.])),
		 											        oopmax_esi_hdhp_f[&person.])));
				end;
				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family PPO is zero 
				/*****************************************************************************/
				if coins_pre_esi_ppo_f[&person.]=0 then do;
					e_oop_spend_ppo_hlth[g] = prob_hlth_hiu[g]*sum((spend_hlth_hiu[g]<=deduct_esi_ppo_f[&person.])*
													  (spend_hlth_hiu[g]*coins_pre_esi_ppo_f[&person.]),
													  (spend_hlth_hiu[g]>deduct_esi_ppo_f[&person.])*
													  (min(sum(deduct_esi_ppo_f[&person.],(spend_hlth_hiu[g]-deduct_esi_ppo_f[&person.])*coins_post_esi_ppo_f[&person.]),oopmax_esi_ppo_f[&person.])));
				end;
				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family HMO is zero 
				/*****************************************************************************/
				if coins_pre_esi_hmo_f[&person.]=0 then do;
					e_oop_spend_hmo_hlth[g] = prob_hlth_hiu[g]*sum((spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])<=deduct_esi_hmo_f[&person.])*
											          (spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])*coins_pre_esi_hmo_f[&person.]),
													  (spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])>deduct_esi_hmo_f[&person.])*
													  (min(sum(deduct_esi_hmo_f[&person.],(spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])-deduct_esi_hmo_f[&person.])*coins_post_esi_hmo_f[&person.]),oopmax_esi_hmo_f[&person.])));
				end;
				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family HDHP is zero 
				/*****************************************************************************/
				if coins_pre_esi_hdhp_f[&person.]=0 then do;
					e_oop_spend_hdhp_hlth[g] = prob_hlth_hiu[g]*sum((spend_hlth_hiu[g]<=deduct_esi_hdhp_f[&person.])*
													   (max(0,sum(spend_hlth_hiu[g]*coins_pre_esi_hdhp_f[&person.],-HSA_esi_hdhp_f[&person.]))),
													   (spend_hlth_hiu[g]>deduct_esi_hdhp_f[&person.])*
													   (min(max(0,sum(deduct_esi_hdhp_f[&person.],(spend_hlth_hiu[g]-deduct_esi_hdhp_f[&person.])*coins_post_esi_hdhp_f[&person.],-HSA_esi_hdhp_f[&person.])),
		 											   oopmax_esi_hdhp_f[&person.])));
				end;
			end;
		end;

		/**************************************************************************************
		/	For HIUs with only one member eligible for ESI plan. 
		/	Note: 	They can only be on an ESI single plan.
		/*************************************************************************************/
		if N=1 then do;

			%do p=1 %to &DIM.;
				if &p.=location[1] then do;
				/******************************************************************************
				/	Calculate the expected out-of-pocket health care spending on ESI plans by plan type, 
				/   looping through all 16 possible health states
				/*****************************************************************************/
					do g=1 to 16;
						/***********************************************************************
						/	If the pre-deductible coinsurance rate for single PPO is greater than
						/	zero 
						/**********************************************************************/
						if coins_pre_esi_ppo_s[&person.]>0 then do;
							e_oop_spend_ppo_hlth[g] = PROB&p.[g]*sum((SPEND&p.[g]<=deduct_esi_ppo_s[&person.]/coins_pre_esi_ppo_s[&person.])*
															 (SPEND&p.[g]*coins_pre_esi_ppo_s[&person.]),
															 (SPEND&p.[g]>deduct_esi_ppo_s[&person.]/coins_pre_esi_ppo_s[&person.])*
															 (min(sum(deduct_esi_ppo_s[&person.],(SPEND&p.[g]-deduct_esi_ppo_s[&person.]/coins_pre_esi_ppo_s[&person.])*coins_post_esi_ppo_s[&person.]),oopmax_esi_ppo_s[&person.])));
						end;
						/***********************************************************************
						/	If the pre-deductible coinsurance rate for single HMO is greater than
						/	zero 
						/**********************************************************************/
						if coins_pre_esi_hmo_s[&person.]>0 then do;
							e_oop_spend_hmo_hlth[g] = PROB&p.[g]*sum((SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])<=deduct_esi_hmo_s[&person.]/coins_pre_esi_hmo_s[&person.])*
													         (SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])*coins_pre_esi_hmo_s[&person.]),
															 (SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])>deduct_esi_hmo_s[&person.]/coins_pre_esi_hmo_s[&person.])*
															 (min(sum(deduct_esi_hmo_s[&person.],(SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])-deduct_esi_hmo_s[&person.]/coins_pre_esi_hmo_s[&person.])*coins_post_esi_hmo_s[&person.]),oopmax_esi_hmo_s[&person.])));
						end;
						/***********************************************************************
						/	If the pre-deductible coinsurance rate for single HDHP is greater than
						/	zero 
						/**********************************************************************/
						if coins_pre_esi_hdhp_s[&person.]>0 then do;
							e_oop_spend_hdhp_hlth[g] = PROB&p.[g]*sum((SPEND&p.[g]<=deduct_esi_hdhp_s[&person.]/coins_pre_esi_hdhp_s[&person.])*
															  (max(0,sum(SPEND&p.[g]*coins_pre_esi_hdhp_s[&person.],-HSA_esi_hdhp_s[&person.]))),
															  (SPEND&p.[g]>deduct_esi_hdhp_s[&person.]/coins_pre_esi_hdhp_s[&person.])*
															  (min(max(0,sum(deduct_esi_hdhp_s[&person.],(SPEND&p.[g]-deduct_esi_hdhp_s[&person.]/coins_pre_esi_hdhp_s[&person.])*coins_post_esi_hdhp_s[&person.],-HSA_esi_hdhp_s[&person.])),
				 											       oopmax_esi_hdhp_s[&person.])));
						end;
						/***********************************************************************
						/	If the pre-deductible coinsurance rate for single PPO is zero 
						/**********************************************************************/						
						if coins_pre_esi_ppo_s[&person.]=0 then do;
							e_oop_spend_ppo_hlth[g] = PROB&p.[g]*sum((SPEND&p.[g]<=deduct_esi_ppo_s[&person.])*
															 (SPEND&p.[g]*coins_pre_esi_ppo_s[&person.]),
															 (SPEND&p.[g]>deduct_esi_ppo_s[&person.])*
															 (min(sum(deduct_esi_ppo_s[&person.],(SPEND&p.[g]-deduct_esi_ppo_s[&person.])*coins_post_esi_ppo_s[&person.]),oopmax_esi_ppo_s[&person.])));
						end;
						/***********************************************************************
						/	If the pre-deductible coinsurance rate for single HMO is zero 
						/**********************************************************************/
						if coins_pre_esi_hmo_s[&person.]=0 then do;
							e_oop_spend_hmo_hlth[g] = PROB&p.[g]*sum((SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])<=deduct_esi_hmo_s[&person.])*
													         (SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])*coins_pre_esi_hmo_s[&person.]),
															 (SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])>deduct_esi_hmo_s[&person.])*
															 (min(sum(deduct_esi_hmo_s[&person.],(SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])-deduct_esi_hmo_s[&person.])*coins_post_esi_hmo_s[&person.]),oopmax_esi_hmo_s[&person.])));
						end;
						/***********************************************************************
						/	If the pre-deductible coinsurance rate for single HDHP is zero 
						/**********************************************************************/
						if coins_pre_esi_hdhp_s[&person.]=0 then do;
							e_oop_spend_hdhp_hlth[g] = PROB&p.[g]*sum((SPEND&p.[g]<=deduct_esi_hdhp_s[&person.])*
															  (max(0,sum(SPEND&p.[g]*coins_pre_esi_hdhp_s[&person.],-HSA_esi_hdhp_s[&person.]))),
															  (SPEND&p.[g]>deduct_esi_hdhp_s[&person.])*
															  (min(max(0,sum(deduct_esi_hdhp_s[&person.],(SPEND&p.[g]-deduct_esi_hdhp_s[&person.])*coins_post_esi_hdhp_s[&person.],-HSA_esi_hdhp_s[&person.])),
				 											       oopmax_esi_hdhp_s[&person.])));
						end;

					end;
				end;
			%end;
		end;

		/**************************************************************************************
		/	Calculate expected out-of-pocket health care spending of each health state for
		/	those who are eligible for public insurance
		/*************************************************************************************/
		%do j=1 %to &DIM.;
			if market_ID_primary[&j.]=1 and medicaid_CHIP_elig[&j.]=1 and age[&j.] ne . then do;
				do k=1 to 16;
					e_oop_spend_medicaid_hlth    [k] = sum(e_oop_spend_medicaid_hlth    [k],PROB&j.[k]*SPEND&j.[k]*&MCD_pct.);
					e_oop_spend_medicaid_hlth_&j.[k] = sum(e_oop_spend_medicaid_hlth_&j.[k],PROB&j.[k]*SPEND&j.[k]*&MCD_pct.);			
				end;
			end;
		%end;

		/**************************************************************************************
		/	Calculate the expected out-of-pocket health care spending over all health states
		/*************************************************************************************/
		e_oop_spend_ppo_hiu2p   	= sum(of e_oop_spend_ppo_hlth[*] );
	   	e_oop_spend_hmo_hiu2p   	= sum(of e_oop_spend_hmo_hlth[*] );
	   	e_oop_spend_hdhp_hiu2p  	= sum(of e_oop_spend_hdhp_hlth[*]);
		e_oop_spend_medicaid_hiu2p  = sum(of e_oop_spend_medicaid_hlth[*]  );


/**********************************************************************************************
/	Calculate the variance of the out-of-pocket health care spending 
/*********************************************************************************************/	

		/**************************************************************************************
		/	For HIUs with 2 or more members eligible for an ESI family plan
		/*************************************************************************************/
		if N>1 then do;

			/***********************************************************************************
			/	Calculate variance of out-of-pocket health care spending for each health state 
			/**********************************************************************************/
			do g=1 to 16;

				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family PPO is greater than zero 
				/*****************************************************************************/
				if coins_pre_esi_ppo_f[&person.]>0 then do;
					v_oop_spend_ppo_hlth[g] = prob_hlth_hiu[g]*(sum((spend_hlth_hiu[g]<=deduct_esi_ppo_f[&person.]/coins_pre_esi_ppo_f[&person.])*
												  (spend_hlth_hiu[g]*coins_pre_esi_ppo_f[&person.]),
												  (spend_hlth_hiu[g]>deduct_esi_ppo_f[&person.]/coins_pre_esi_ppo_f[&person.])*
												  (min(sum(deduct_esi_ppo_f[&person.],(spend_hlth_hiu[g]-deduct_esi_ppo_f[&person.]/coins_pre_esi_ppo_f[&person.])*coins_post_esi_ppo_f[&person.]),oopmax_esi_ppo_f[&person.])))-e_oop_spend_ppo_hiu2p)**2;
				end;
				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family HMO is greater than zero 
				/*****************************************************************************/
				if coins_pre_esi_hmo_f[&person.]>0 then do;
					v_oop_spend_hmo_hlth[g] = prob_hlth_hiu[g]*(sum((spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])<=deduct_esi_hmo_f[&person.]/coins_pre_esi_hmo_f[&person.])*
											      (spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])*coins_pre_esi_hmo_f[&person.]),
												  (spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])>deduct_esi_hmo_f[&person.]/coins_pre_esi_hmo_f[&person.])*
												  (min(sum(deduct_esi_hmo_f[&person.],(spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])-deduct_esi_hmo_f[&person.]/coins_pre_esi_hmo_f[&person.])*coins_post_esi_hmo_f[&person.]),oopmax_esi_hmo_f[&person.])))-e_oop_spend_hmo_hiu2p)**2;
				end;
				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family HDHP is greater than zero 
				/*****************************************************************************/
				if coins_pre_esi_hdhp_f[&person.]>0 then do;
					v_oop_spend_hdhp_hlth[g] = prob_hlth_hiu[g]*(sum((spend_hlth_hiu[g]<=deduct_esi_hdhp_f[&person.]/coins_pre_esi_hdhp_f[&person.])*
												   (max(0,sum(spend_hlth_hiu[g]*coins_pre_esi_hdhp_f[&person.],-HSA_esi_hdhp_f[&person.]))),
												   (spend_hlth_hiu[g]>deduct_esi_hdhp_f[&person.]/coins_pre_esi_hdhp_f[&person.])*
												   (min(max(0,sum(deduct_esi_hdhp_f[&person.],(spend_hlth_hiu[g]-deduct_esi_hdhp_f[&person.]/coins_pre_esi_hdhp_f[&person.])*coins_post_esi_hdhp_f[&person.],-HSA_esi_hdhp_f[&person.])),
		 										    oopmax_esi_hdhp_f[&person.])))-e_oop_spend_hdhp_hiu2p)**2;
				end;
				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family PPO is zero 
				/*****************************************************************************/
				if coins_pre_esi_ppo_f[&person.]=0 then do;
					v_oop_spend_ppo_hlth[g] = prob_hlth_hiu[g]*(sum((spend_hlth_hiu[g]<=deduct_esi_ppo_f[&person.])*
												  (spend_hlth_hiu[g]*coins_pre_esi_ppo_f[&person.]),
												  (spend_hlth_hiu[g]>deduct_esi_ppo_f[&person.])*
											      (min(sum(deduct_esi_ppo_f[&person.],(spend_hlth_hiu[g]-deduct_esi_ppo_f[&person.])*coins_post_esi_ppo_f[&person.]),oopmax_esi_ppo_f[&person.])))-e_oop_spend_ppo_hiu2p)**2;
				end;
				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family HMO is zero 
				/*****************************************************************************/
				if coins_pre_esi_hmo_f[&person.]=0 then do;
					v_oop_spend_hmo_hlth[g] = prob_hlth_hiu[g]*(sum((spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])<=deduct_esi_hmo_f[&person.])*
											      (spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])*coins_pre_esi_hmo_f[&person.]),
											      (spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])>deduct_esi_hmo_f[&person.])*
											      (min(sum(deduct_esi_hmo_f[&person.],(spend_hlth_hiu[g]*(1-HMO_mgmt_fact[&person.])-deduct_esi_hmo_f[&person.])*coins_post_esi_hmo_f[&person.]),oopmax_esi_hmo_f[&person.])))-e_oop_spend_hmo_hiu2p)**2;
				end;
				/******************************************************************************
				/	If the pre-deductible coinsurance rate for family HDHP is zero 
				/*****************************************************************************/
				if coins_pre_esi_hdhp_f[&person.]=0 then do;
					v_oop_spend_hdhp_hlth[g] = prob_hlth_hiu[g]*(sum((spend_hlth_hiu[g]<=deduct_esi_hdhp_f[&person.])*
												   (max(0,sum(spend_hlth_hiu[g]*coins_pre_esi_hdhp_f[&person.],-HSA_esi_hdhp_f[&person.]))),
												   (spend_hlth_hiu[g]>deduct_esi_hdhp_f[&person.])*
												   (min(max(0,sum(deduct_esi_hdhp_f[&person.],(spend_hlth_hiu[g]-deduct_esi_hdhp_f[&person.])*coins_post_esi_hdhp_f[&person.],-HSA_esi_hdhp_f[&person.])),
		 											oopmax_esi_hdhp_f[&person.])))-e_oop_spend_hdhp_hiu2p)**2;
				end;

		   	end;
		end;

		/**************************************************************************************
		/	For HIUs with only one member eligible for ESI plan 
		/*************************************************************************************/
		if N=1 then do;
			
			%do p=1 %to &DIM.;
				if &p.=location[1] then do;
					/**************************************************************************
					/	Calculate the variance of out-of-pocket health care spending for each
					/	health state
					/*************************************************************************/
					do g=1 to 16;

						/**********************************************************************
						/	If the pre-deductible coinsurance rate for single PPO is greater than zero 
						/*********************************************************************/
						if coins_pre_esi_ppo_s[&person.]>0 then do;
							v_oop_spend_ppo_hlth[g] = PROB&p.[g]*(sum((SPEND&p.[g]<=deduct_esi_ppo_s[&person.]/coins_pre_esi_ppo_s[&person.])*
														 (SPEND&p.[g]*coins_pre_esi_ppo_s[&person.]),
														 (SPEND&p.[g]>deduct_esi_ppo_s[&person.]/coins_pre_esi_ppo_s[&person.])*
														 (min(sum(deduct_esi_ppo_s[&person.],(SPEND&p.[g]-deduct_esi_ppo_s[&person.]/coins_pre_esi_ppo_s[&person.])*coins_post_esi_ppo_s[&person.]),oopmax_esi_ppo_s[&person.])))-e_oop_spend_ppo_hiu2p)**2;
						end;
						/**********************************************************************
						/	If the pre-deductible coinsurance rate for single HMO is greater than zero 
						/*********************************************************************/
						if coins_pre_esi_hmo_s[&person.]>0 then do;
							v_oop_spend_hmo_hlth[g] = PROB&p.[g]*(sum((SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])<=deduct_esi_hmo_s[&person.]/coins_pre_esi_hmo_s[&person.])*
													     (SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])*coins_pre_esi_hmo_s[&person.]),
														 (SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])>deduct_esi_hmo_s[&person.]/coins_pre_esi_hmo_s[&person.])*
														 (min(sum(deduct_esi_hmo_s[&person.],(SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])-deduct_esi_hmo_s[&person.]/coins_pre_esi_hmo_s[&person.])*coins_post_esi_hmo_s[&person.]),oopmax_esi_hmo_s[&person.])))-e_oop_spend_hmo_hiu2p)**2;
						end;
						/**********************************************************************
						/	If the pre-deductible coinsurance rate for single HDHP is greater than zero 
						/*********************************************************************/
						if coins_pre_esi_hdhp_s[&person.]>0 then do;
							v_oop_spend_hdhp_hlth[g] = PROB&p.[g]*(sum((SPEND&p.[g]<=deduct_esi_hdhp_s[&person.]/coins_pre_esi_hdhp_s[&person.])*
														  (max(0,sum(SPEND&p.[g]*coins_pre_esi_hdhp_s[&person.],-HSA_esi_hdhp_s[&person.]))),
														  (SPEND&p.[g]>deduct_esi_hdhp_s[&person.]/coins_pre_esi_hdhp_s[&person.])*
														  (min(max(0,sum(deduct_esi_hdhp_s[&person.],(SPEND&p.[g]-deduct_esi_hdhp_s[&person.]/coins_pre_esi_hdhp_s[&person.])*coins_post_esi_hdhp_s[&person.],-HSA_esi_hdhp_s[&person.])),
				 										       oopmax_esi_hdhp_s[&person.])))-e_oop_spend_hdhp_hiu2p)**2;
						end;
						/**********************************************************************
						/	If the pre-deductible coinsurance rate for single PPO is zero 
						/*********************************************************************/
						if coins_pre_esi_ppo_s[&person.]=0 then do;
							v_oop_spend_ppo_hlth[g] = PROB&p.[g]*(sum((SPEND&p.[g]<=deduct_esi_ppo_s[&person.])*
														 (SPEND&p.[g]*coins_pre_esi_ppo_s[&person.]),
														 (SPEND&p.[g]>deduct_esi_ppo_s[&person.])*
													     (min(sum(deduct_esi_ppo_s[&person.],(SPEND&p.[g]-deduct_esi_ppo_s[&person.])*coins_post_esi_ppo_s[&person.]),oopmax_esi_ppo_s[&person.])))-e_oop_spend_ppo_hiu2p)**2;
						end;
						/**********************************************************************
						/	If the pre-deductible coinsurance rate for single HMO is zero 
						/*********************************************************************/
						if coins_pre_esi_hmo_s[&person.]=0 then do;
							v_oop_spend_hmo_hlth[g] = PROB&p.[g]*(sum((SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])<=deduct_esi_hmo_s[&person.])*
													     (SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])*coins_pre_esi_hmo_s[&person.]),
													     (SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])>deduct_esi_hmo_s[&person.])*
													     (min(sum(deduct_esi_hmo_s[&person.],(SPEND&p.[g]*(1-HMO_mgmt_fact[&person.])-deduct_esi_hmo_s[&person.])*coins_post_esi_hmo_s[&person.]),oopmax_esi_hmo_s[&person.])))-e_oop_spend_hmo_hiu2p)**2;
						end;
						/**********************************************************************
						/	If the pre-deductible coinsurance rate for single HDHP is zero 
						/*********************************************************************/
						if coins_pre_esi_hdhp_s[&person.]=0 then do;
							v_oop_spend_hdhp_hlth[g] = PROB&p.[g]*(sum((SPEND&p.[g]<=deduct_esi_hdhp_s[&person.])*
														  (max(0,sum(SPEND&p.[g]*coins_pre_esi_hdhp_s[&person.],-HSA_esi_hdhp_s[&person.]))),
														  (SPEND&p.[g]>deduct_esi_hdhp_s[&person.])*
														  (min(max(0,sum(deduct_esi_hdhp_s[&person.],(SPEND&p.[g]-deduct_esi_hdhp_s[&person.])*coins_post_esi_hdhp_s[&person.],-HSA_esi_hdhp_s[&person.])),
				 										   oopmax_esi_hdhp_s[&person.])))-e_oop_spend_hdhp_hiu2p)**2;
						end;
				   	end;
				end;
			%end;
		end;

		/**************************************************************************************
		/	Calculate the variance of out-of-pocket health care spending of each health state 
		/	for those who are eligible for public insurance
		/*************************************************************************************/
		%do j=1 %to &DIM.;
			if market_ID_primary[&j.]=1 and medicaid_CHIP_elig[&j.]=1 and age[&j.] ne . then do;
				do g=1 to 16;
					v_oop_spend_medicaid_hlth[g]=sum(v_oop_spend_medicaid_hlth[g],PROB&j.[g]*(SPEND&j.[g]*&MCD_pct.-sum(of e_oop_spend_medicaid_hlth_&j.[*]))**2);
				end;
			end;
		%end;

		/**************************************************************************************
		/	Calculate the variance of out-of-pocket health care spending over all health states
		/*************************************************************************************/
		v_oop_spend_ppo_hiu2p  = sum(sum(of v_oop_spend_ppo_hlth[*] ),sum(of v_oop_spend_medicaid_hlth[*]));
		v_oop_spend_hmo_hiu2p  = sum(sum(of v_oop_spend_hmo_hlth[*] ),sum(of v_oop_spend_medicaid_hlth[*]));
		v_oop_spend_hdhp_hiu2p = sum(sum(of v_oop_spend_hdhp_hlth[*]),sum(of v_oop_spend_medicaid_hlth[*]));

/***********************************************************************************************
/	Calculate the number of people (unweighted and weighted) eligible for each coverage type
/	in each HIU
/**********************************************************************************************/
		%do j=1 %to &DIM.;
			%macro ESIF_N(TYP);			
			/**********************************************************************************
			/	Count the number of people (N_ for unweighted, Nw_ for weighted) who are not eligible for public insurance 
			/	(excluding non-dependent children and people whose coverage types were held constant)
			/	in an HIU whose [&person.]th member has an offer of ESI plan of type &TYP (i.e. PPO, HMO, and HDHP) 
			/*********************************************************************************/
		 		if market_ID_primary[&j.]=1 and offer_&TYP.[&person.]=1 and medicaid_CHIP_elig[&j.] ne 1 and age[&j.] ne . then do;
					N_&TYP.  = sum(N_&TYP.,wgt[&j.]/wgt[&j.]);
					Nw_&TYP. = sum(Nw_&TYP.,wgt[&j.]);
				end;
			%mend ESIF_N;
			%ESIF_N(PPO);%ESIF_N(HMO);%ESIF_N(HDHP);

			/**********************************************************************************
			/	Count the number of people (N_ for unweighted, Nw_ for weighted) 
			/	who are eligible for public insurance, by eligibility type 
			/	(excluding non-dependent children and those whose coverage types were held constant)
			/*********************************************************************************/
			if market_ID_primary[&j.]=1 and medicaid_CHIP_elig[&j.]=1 and age[&j.] ne . then do;
		  		if pe_medicaid_CHIP_elig_kid[&j.]=1 then do;
		   			N_medicaid_pe_kid  = sum(N_medicaid_pe_kid,wgt[&j.]/wgt[&j.]);
		   			Nw_medicaid_pe_kid = sum(Nw_medicaid_pe_kid,wgt[&j.]);
		  		end;
				else if pe_medicaid_CHIP_elig_adult[&j.]=1 then do;
		   			N_medicaid_pe_adult  = sum(N_medicaid_pe_adult,wgt[&j.]/wgt[&j.]);
		   			Nw_medicaid_pe_adult = sum(Nw_medicaid_pe_adult,wgt[&j.]);
		  		end;
		  		else if ne_medicaid_CHIP_elig[&j.]=1 then do;
		   			N_medicaid_ne  = sum(N_medicaid_ne,wgt[&j.]/wgt[&j.]);
		   			Nw_medicaid_ne = sum(Nw_medicaid_ne,wgt[&j.]);
		  		end;
		  		else if chip_elig[&j.]=1 then do;
		  	 		N_chip  = sum(N_chip,wgt[&j.]/wgt[&j.]);
		   			Nw_chip = sum(Nw_chip,wgt[&j.]);
		  		end;
			end;
			/**********************************************************************************
			/  Count the number of of non-dependent children (N_ for unweighted, Nw_ for weighted)
			/  (excluding those whose coverage types were held constant)
			/*********************************************************************************/
			if market_ID_primary[&j.] ne 1 and age[&j.] ne . then do;
				N_nondep_kids  = sum(N_nondep_kids,wgt[&j.]/wgt[&j.]);
				Nw_nondep_kids = sum(Nw_nondep_kids,wgt[&j.]);
			end;
		%end;
		
/************************************************************************************** 
/	From HIUs' perspective 
/*************************************************************************************/
		%if &hiu_u.=yes %then %do;

			/**********************************************************************************
			/	Calculate the utility (without the utility shifters) using the expected OOP
			/	spending and the variance of OOP spending calculated above
			/*********************************************************************************/
			%macro uESIfpo(TYP);    
		 		     if offer_&TYP.[&person.]=1 and N>1 and esi_ee_f_prem_&TYP._post[&person.]<&budget_constraint_frac.*DISP_INC then 
						U_ESI_Fpo_&person.  = hiuinc - esi_ee_f_prem_&TYP._post[&person.] - e_oop_spend_&TYP._hiu2p - e_oop_spend_medicaid_hiu2p - 0.5*&RA_param.* v_oop_spend_&TYP._hiu2p;
				else if offer_&TYP.[&person.]=1 and N=1 and esi_ee_f_prem_&TYP._post[&person.]<&budget_constraint_frac.*DISP_INC then 
						U_ESI_Fpo_&person.  = hiuinc - esi_ee_s_prem_&TYP._post[&person.] - e_oop_spend_&TYP._hiu2p - e_oop_spend_medicaid_hiu2p - 0.5*&RA_param.* v_oop_spend_&TYP._hiu2p;
			%mend uESIfpo;
			%uESIfpo(PPO);%uESIfpo(HMO);%uESIfpo(HDHP);

			N_ESI_Fpo_PPO_&person.   		= N_PPO;
			N_ESI_Fpo_HMO_&person.   		= N_HMO;
			N_ESI_Fpo_HDHP_&person.  		= N_HDHP;
			N_ESI_Fpo_nondepkids_&person.   = N_nondep_kids;
			N_ESI_Fpo_MCDpe_kid_&person. 	= N_medicaid_pe_kid;
			N_ESI_Fpo_MCDpe_adult_&person.	= N_medicaid_pe_adult;
			N_ESI_Fpo_MCDne_&person.   		= N_medicaid_ne;
			N_ESI_Fpo_chip_&person.			= N_chip;
			Nw_ESI_Fpo_PPO_&person.  		= Nw_PPO;
			Nw_ESI_Fpo_HMO_&person.  		= Nw_HMO;
			Nw_ESI_Fpo_HDHP_&person. 		= Nw_HDHP;
			Nw_ESI_Fpo_nondepkids_&person.  = Nw_nondep_kids;
			Nw_ESI_Fpo_MCDpe_kid_&person.   = Nw_medicaid_pe_kid;
			Nw_ESI_Fpo_MCDpe_adult_&person. = Nw_medicaid_pe_adult;
			Nw_ESI_Fpo_MCDne_&person.   	= Nw_medicaid_ne;
			Nw_ESI_Fpo_chip_&person.		= Nw_chip;

			/**********************************************************************************
			/	Calculate the utility with the utility shifters
			/*********************************************************************************/
			U_ESI_Fpo_&person. = U_ESI_Fpo_&person. + N_PPO*ESI_F_PPO_SHIFT 
													+ N_HMO*ESI_F_HMO_SHIFT 
													+ N_HDHP*ESI_F_HDHP_SHIFT
										            + N_nondep_kids*ESI_F_nondepkids_SHIFT 
										            + N_medicaid_pe_kid*MCD_SHIFT_pe_kid 
													+ N_medicaid_pe_adult*MCD_SHIFT_pe_adult 
													+ N_medicaid_ne*MCD_SHIFT_ne 
													+ N_chip*CHIP_SHIFT;
		%end;

/************************************************************************************** 
/	From firms' perspective (to model firm behaviors) 
/*************************************************************************************/
		%if &firm_u.=yes %then %do;
			
			/**********************************************************************************
			/	Calculate the utility (without the utility shifters)
			/	Note:	In modeling firm behaviors, workers' HIU utilities are specific to the 
			/			ESI plan type (e.g. PPO, HMO, HDHP) for those who received the ESI offer, 
			/			because workers' willingness to pay is calculated for each ESI plan
			/*********************************************************************************/			
			%macro uESIfpo(TYP);
				if N>1 then do;
					if p_index[1] ne . and p_index[2] ne . then do;
			 			if offer_&TYP.[&person.]=1 and p_index[&person.]=hiu_p_index and esi_ee_f_prem_&TYP._post[&person.]<&budget_constraint_frac.*DISP_INC then 
							U_ESI_Fpo_&TYP._&person.  = hiuinc - esi_ee_f_prem_&TYP._post[&person.] - e_oop_spend_&TYP._hiu2p - e_oop_spend_medicaid_hiu2p - 0.5*&RA_param.*v_oop_spend_&TYP._hiu2p;
			  			if offer_&TYP.[&person.]=1 and p_index[&person.] ne hiu_p_index and esi_ee_f_prem_&TYP._post[&person.]<&budget_constraint_frac.*DISP_INC then 
							U_ESI_Fpo_&person.  	  = hiuinc - esi_ee_f_prem_&TYP._post[&person.] - e_oop_spend_&TYP._hiu2p - e_oop_spend_medicaid_hiu2p - 0.5*&RA_param.*v_oop_spend_&TYP._hiu2p;
					end;
					if p_index[1] ne . and p_index[2]=. then do;
			 			if offer_&TYP.[&person.]=1 and p_index[1]=hiu_p_index and esi_ee_f_prem_&TYP._post[&person.]<&budget_constraint_frac.*DISP_INC then 
							U_ESI_Fpo_&TYP._&person. = hiuinc - esi_ee_f_prem_&TYP._post[&person.] - e_oop_spend_&TYP._hiu2p - e_oop_spend_medicaid_hiu2p - 0.5*&RA_param.*v_oop_spend_&TYP._hiu2p;
			  			if offer_&TYP.[&person.]=1 and p_index[1] ne hiu_p_index and esi_ee_f_prem_&TYP._post[&person.]<&budget_constraint_frac.*DISP_INC then 
							U_ESI_Fpo_&person.       = hiuinc - esi_ee_f_prem_&TYP._post[&person.] - e_oop_spend_&TYP._hiu2p - e_oop_spend_medicaid_hiu2p - 0.5*&RA_param.*v_oop_spend_&TYP._hiu2p;
					end;
				end;
				else if N=1 then do;
					if p_index[1] ne . and p_index[2] ne . then do;
			 			if offer_&TYP.[&person.]=1 and p_index[&person.]=hiu_p_index and esi_ee_f_prem_&TYP._post[&person.]<&budget_constraint_frac.*DISP_INC then 
							U_ESI_Fpo_&TYP._&person. = hiuinc - esi_ee_s_prem_&TYP._post[&person.] - e_oop_spend_&TYP._hiu2p - e_oop_spend_medicaid_hiu2p - 0.5*&RA_param.*v_oop_spend_&TYP._hiu2p;
			  			if offer_&TYP.[&person.]=1 and p_index[&person.] ne hiu_p_index and esi_ee_f_prem_&TYP._post[&person.]<&budget_constraint_frac.*DISP_INC then 
							U_ESI_Fpo_&person. 		 = hiuinc - esi_ee_s_prem_&TYP._post[&person.] - e_oop_spend_&TYP._hiu2p - e_oop_spend_medicaid_hiu2p - 0.5*&RA_param.*v_oop_spend_&TYP._hiu2p;
					end;
					if p_index[1] ne . and p_index[2]=. then do;
			 			if offer_&TYP.[&person.]=1 and p_index[1]=hiu_p_index and esi_ee_f_prem_&TYP._post[&person.]<&budget_constraint_frac.*DISP_INC then 
							U_ESI_Fpo_&TYP._&person. = hiuinc - esi_ee_s_prem_&TYP._post[&person.] - e_oop_spend_&TYP._hiu2p - e_oop_spend_medicaid_hiu2p - 0.5*&RA_param.*v_oop_spend_&TYP._hiu2p;
			  			if offer_&TYP.[&person.]=1 and p_index[1] ne hiu_p_index and esi_ee_f_prem_&TYP._post[&person.]<&budget_constraint_frac.*DISP_INC then 
							U_ESI_Fpo_&person.       = hiuinc - esi_ee_s_prem_&TYP._post[&person.] - e_oop_spend_&TYP._hiu2p - e_oop_spend_medicaid_hiu2p - 0.5*&RA_param.*v_oop_spend_&TYP._hiu2p;
					end;
				end;
			%mend uESIfpo;
			%uESIfpo(PPO);%uESIfpo(HMO);%uESIfpo(HDHP);

			/**********************************************************************************
			/	Calculate the utility with the utility shifters
			/*********************************************************************************/	
			if p_index[1] ne . and p_index[2] ne . then do;
				if p_index[&person.]=hiu_p_index then do; 
		 			U_ESI_Fpo_PPO_&person.  = U_ESI_Fpo_PPO_&person.
												+ N_PPO*ESI_F_PPO_SHIFT   
												+ N_nondep_kids*ESI_F_nondepkids_SHIFT 
												+ N_medicaid_pe_kid*MCD_SHIFT_pe_kid 
												+ N_medicaid_pe_adult*MCD_SHIFT_pe_adult 
												+ N_medicaid_ne*MCD_SHIFT_ne 
												+ N_chip*CHIP_SHIFT;
		 			U_ESI_Fpo_HMO_&person.  = U_ESI_Fpo_HMO_&person.  
												+ N_HMO*ESI_F_HMO_SHIFT   
												+ N_nondep_kids*ESI_F_nondepkids_SHIFT 
												+ N_medicaid_pe_kid*MCD_SHIFT_pe_kid 
												+ N_medicaid_pe_adult*MCD_SHIFT_pe_adult 
												+ N_medicaid_ne*MCD_SHIFT_ne 
												+ N_chip*CHIP_SHIFT;
		 			U_ESI_Fpo_HDHP_&person. = U_ESI_Fpo_HDHP_&person. 
												+ N_HDHP*ESI_F_HDHP_SHIFT 
												+ N_nondep_kids*ESI_F_nondepkids_SHIFT 
												+ N_medicaid_pe_kid*MCD_SHIFT_pe_kid 
												+ N_medicaid_pe_adult*MCD_SHIFT_pe_adult 
												+ N_medicaid_ne*MCD_SHIFT_ne 
												+ N_chip*CHIP_SHIFT;
				end;
				if p_index[&person.] ne hiu_p_index then do; 
		 			U_ESI_Fpo_&person. = U_ESI_Fpo_&person. 
												+ N_PPO*ESI_F_PPO_SHIFT 
												+ N_HMO*ESI_F_HMO_SHIFT 
												+ N_HDHP*ESI_F_HDHP_SHIFT 
										   		+ N_nondep_kids*ESI_F_nondepkids_SHIFT 
										   		+ N_medicaid_pe_kid*MCD_SHIFT_pe_kid 
												+ N_medicaid_pe_adult*MCD_SHIFT_pe_adult 
												+ N_medicaid_ne*MCD_SHIFT_ne 
												+ N_chip*CHIP_SHIFT;
				end;
			end;
			if p_index[1] ne . and p_index[2]=. then do;
				if p_index[1]=hiu_p_index then do; 
		 			U_ESI_Fpo_PPO_&person.  = U_ESI_Fpo_PPO_&person.  
												+ N_PPO*ESI_F_PPO_SHIFT   
												+ N_nondep_kids*ESI_F_nondepkids_SHIFT 
												+ N_medicaid_pe_kid*MCD_SHIFT_pe_kid 
												+ N_medicaid_pe_adult*MCD_SHIFT_pe_adult 
												+ N_medicaid_ne*MCD_SHIFT_ne 
												+ N_chip*CHIP_SHIFT;
		 			U_ESI_Fpo_HMO_&person.  = U_ESI_Fpo_HMO_&person.  
												+ N_HMO*ESI_F_HMO_SHIFT   
												+ N_nondep_kids*ESI_F_nondepkids_SHIFT 
												+ N_medicaid_pe_kid*MCD_SHIFT_pe_kid 
												+ N_medicaid_pe_adult*MCD_SHIFT_pe_adult 
												+ N_medicaid_ne*MCD_SHIFT_ne 
												+ N_chip*CHIP_SHIFT;
		 			U_ESI_Fpo_HDHP_&person. = U_ESI_Fpo_HDHP_&person. 
												+ N_HDHP*ESI_F_HDHP_SHIFT 
												+ N_nondep_kids*ESI_F_nondepkids_SHIFT 
												+ N_medicaid_pe_kid*MCD_SHIFT_pe_kid 
												+ N_medicaid_pe_adult*MCD_SHIFT_pe_adult 
												+ N_medicaid_ne*MCD_SHIFT_ne 
												+ N_chip*CHIP_SHIFT;
				end;
				if p_index[1] ne hiu_p_index then do; 
		 			U_ESI_Fpo_&person. = U_ESI_Fpo_&person. 
												+ N_PPO*ESI_F_PPO_SHIFT 
												+ N_HMO*ESI_F_HMO_SHIFT 
												+ N_HDHP*ESI_F_HDHP_SHIFT 
										   		+ N_nondep_kids*ESI_F_nondepkids_SHIFT  
										   		+ N_medicaid_pe_kid*MCD_SHIFT_pe_kid 
												+ N_medicaid_pe_adult*MCD_SHIFT_pe_adult 
												+ N_medicaid_ne*MCD_SHIFT_ne 
												+ N_chip*CHIP_SHIFT;
				end;
			end;
		%end;

	end;
%mend calc_U_ESI_Fpo_hiu2p;
