/*=============================================================================================
/==============================================================================================
/	Module Name : calc_U_nongroup_hiu1.sas (called by "single_person_HIUs.sas")
/ 	Purpose   	: To calculate HIU's utility for nongroup coverage of single-person HIU				
/	Summary		:
/		(1) Calculate the expected out-of-pocket (OOP) health care spending by tier and by in/outside the marketplaces
/		(2) Calculate the variance of OOP spending by tier and by in/outside the marketplaces
/		(3)	Calculate the variance of OOP spending under silver plan in the marketplaces by ESI
/			type (PPO/HMO/HDHP) for firm offering decisions
/		(4) Calculate the HIU-level utility shifter on a plan in and outside the marketplaces
/	Notes: (1) This MACRO calc_U_nongroup_hiu1(firm_u=,hiu_u=) has two arguments:
/				The first is to calculate the firm objective function value (firm_u=yes, hiu_u=no) 
/				and the second one is to calculate HIU utilities (firm_u=no, hiu_u=yes)
/				Note that HIU's utilities are also used in the firm behavior calibration,
/				because firms evaluate their workers' demand for ESI.  
/		   (2) This MACRO is called in both calibration and simulation routines. 
/				When called in the simulation routine, this code uses the utility shifter already calibrated
/		   (3) Utility for the NL model is defined in the slide deck and has 5 components:
/				(a) Income
/				(b) Costs associated with the alternative (such as premiums and
/					individual mandate penalty if applicable) 
/				(c) Expected OOP health care spending
/				(d) Risk associated with uncertain OOP spending 
/				(e) (Unobservable) utility shifter 
/				Some of those components are calculated in codes that precede this code
/				In the simulation routine, those components are HIU income, premiums for non-group
/					and ESI, and utility shifters calibrated
/				In the calibration routine, those components are HIU income, premiums for non-group
/					and ESI
/				Other components are calculated in this code: expected OOP spending and  
/					risk associated with uncertain OOP spending.
/ 			For the more information on the utility function, see Congressional Budget Office,
/			HISIM2The Health Insurance Simulation Model Used in Preparing CBOs Spring 2019
/			Baseline Budget Projections (April 2019), www.cbo.gov/publication/55097.
/	The code is written in SAS, version 9.4.
/==============================================================================================
/============================================================================================*/

%macro calc_U_nongroup_hiu1(firm_u=,hiu_u=);

	%local i;

	/******************************************************************************************
	/	Initialize arrays to 0 for utility calculation
	/*****************************************************************************************/
	%initialize_array_0;

	/******************************************************************************************
	/	Initialize count variables to 0 for utility calculation
	/*****************************************************************************************/
	%initialize_n_to_0;

	/******************************************************************************************
	/	For each member in the HIU:
	/*****************************************************************************************/
	%do i=1 %to &DIM.; 

	/******************************************************************************************
	/	For those who are potential enrollees of nongroup plans:
	/*****************************************************************************************/
	if elig_nongroup_covg[&i.]=1 and age[&i.] ne . then do;

		/************************************************************************************** 
		/	Initialize (unweighted and weighted) numbers of people eligible for plans 
		/	in the marketplaces by age and income to 0
		/*************************************************************************************/
		age_all_inc_lt70		=0; w_age_all_inc_lt70			=0;
		age_all_inc_70to250		=0; w_age_all_inc_70to250		=0;
		age_all_inc_250to400	=0; w_age_all_inc_250to400		=0;
		age_all_inc_400p		=0; w_age_all_inc_400p			=0;
		age_all_inc_70to400		=0; w_age_all_inc_70to400		=0;
		age_lt30_inc_70to138	=0; w_age_lt30_inc_70to138		=0;
		age_31to50_inc_70to138	=0; w_age_31to50_inc_70to138	=0;
		age_51p_inc_70to138		=0; w_age_51p_inc_70to138		=0;
		age_lt30_inc_138to250	=0; w_age_lt30_inc_138to250		=0;
		age_31to50_inc_138to250	=0; w_age_31to50_inc_138to250	=0;
		age_51p_inc_138to250	=0; w_age_51p_inc_138to250		=0;
		/************************************************************************************** 
		/	Count (unweighted and weighted) numbers of people eligible for plans in the marketplaces  
		/	by age and income
		/*************************************************************************************/
		if 								FPL	<0.70 then age_all_inc_lt70			=sum(age_all_inc_lt70,wgt[&i.]/wgt[&i.]);
		if 					 	 0.70<=	FPL<=2.50 then age_all_inc_70to250		=sum(age_all_inc_70to250,wgt[&i.]/wgt[&i.]);
		if 					 	 2.50<	FPL<=4.00 then age_all_inc_250to400		=sum(age_all_inc_250to400,wgt[&i.]/wgt[&i.]);
		if 								FPL	>4.00 then age_all_inc_400p			=sum(age_all_inc_400p,wgt[&i.]/wgt[&i.]);
		if 						 0.70<=	FPL<=4.00 then age_all_inc_70to400		=sum(age_all_inc_70to400,wgt[&i.]/wgt[&i.]);
		if 		age[&i.]<=30 and 0.70<=	FPL<=1.38 then age_lt30_inc_70to138		=sum(age_lt30_inc_70to138,wgt[&i.]/wgt[&i.]);
		if 30<	age[&i.]<=50 and 0.70<= FPL<=1.38 then age_31to50_inc_70to138	=sum(age_31to50_inc_70to138,wgt[&i.]/wgt[&i.]);
		if 		age[&i.] >50 and 0.70<= FPL<=1.38 then age_51p_inc_70to138		=sum(age_51p_inc_70to138,wgt[&i.]/wgt[&i.]);
		if 		age[&i.]<=30 and 1.38<  FPL<=2.50 then age_lt30_inc_138to250	=sum(age_lt30_inc_138to250,wgt[&i.]/wgt[&i.]);
		if 30<	age[&i.]<=50 and 1.38<  FPL<=2.50 then age_31to50_inc_138to250	=sum(age_31to50_inc_138to250,wgt[&i.]/wgt[&i.]);
		if 		age[&i.] >50 and 1.38<  FPL<=2.50 then age_51p_inc_138to250		=sum(age_51p_inc_138to250,wgt[&i.]/wgt[&i.]);

		if								FPL<0.70  then w_age_all_inc_lt70		=sum(w_age_all_inc_lt70,wgt[&i.]);
		if 						 0.70<= FPL<=2.50 then w_age_all_inc_70to250	=sum(w_age_all_inc_70to250,wgt[&i.]);
		if						 2.50<	FPL<=4.00 then w_age_all_inc_250to400	=sum(w_age_all_inc_250to400,wgt[&i.]);
		if 								FPL >4.00 then w_age_all_inc_400p		=sum(w_age_all_inc_400p,wgt[&i.]);
		if						 0.70<=	FPL<=4.00 then w_age_all_inc_70to400	=sum(w_age_all_inc_70to400,wgt[&i.]);
		if 		age[&i.]<=30 and 0.70<=	FPL<=1.38 then w_age_lt30_inc_70to138	=sum(w_age_lt30_inc_70to138,wgt[&i.]);
		if 30<	age[&i.]<=50 and 0.70<=	FPL<=1.38 then w_age_31to50_inc_70to138	=sum(w_age_31to50_inc_70to138,wgt[&i.]);
		if		age[&i.] >50 and 0.70<= FPL<=1.38 then w_age_51p_inc_70to138	=sum(w_age_51p_inc_70to138,wgt[&i.]);
		if		age[&i.]<=30 and 1.38<	FPL<=2.50 then w_age_lt30_inc_138to250	=sum(w_age_lt30_inc_138to250,wgt[&i.]);
		if 30<	age[&i.]<=50 and 1.38<	FPL<=2.50 then w_age_31to50_inc_138to250=sum(w_age_31to50_inc_138to250,wgt[&i.]);
		if		age[&i.] >50 and 1.38<	FPL<=2.50 then w_age_51p_inc_138to250	=sum(w_age_51p_inc_138to250,wgt[&i.]);


		/**************************************************************************************
		/	Calculate the expected out-of-pocket health care spending on a plan in the
		/	marketplace by tier, looping through all 16 possible health states
		/	Note: (1) For details about probability distribution of health spending, 
		/		  		please refer to Jessica Banthin and others, Sources and Preparation of
		/				Data Used in HISIM2CBOs Health Insurance Simulation Model, Working Paper
		/				2019-04 (Congressional Budget Office, April 2019), www.cbo.gov/publication/55087.
		/		  (2) Nongroup plan characteristics (such as deductibles, copays, and coinsurance)
		/				are assumed to be same between the plans in and outside the marketplaces
		/				for a certain state and tier in the model, because insurers are required  
		/			    to offer the same plan outside the marketplaces as in marketplaces under current law.
		/*************************************************************************************/			
		do j=1 to 16;
			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Bronze plan is greater than zero
			/*********************************************************************************/
			if coin_nongroup_pre_b>0 then do;
			 e_oop_spend_onB_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_b/coin_nongroup_pre_b)*(SPEND&i.[j]*coin_nongroup_pre_b),
                                              (SPEND&i.[j]> ded_nongroup_b/coin_nongroup_pre_b)*(min(sum(ded_nongroup_b,(SPEND&i.[j]-ded_nongroup_b/coin_nongroup_pre_b)*coin_nongroup_post_b),moop_nongroup_b)));
			end;
			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Silver plan is greater than zero
			/*********************************************************************************/
			if coin_nongroup_pre_s>0 then do;
 			 e_oop_spend_onS_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_s/coin_nongroup_pre_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                              (SPEND&i.[j]> ded_nongroup_s/coin_nongroup_pre_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s/coin_nongroup_pre_s)*coin_nongroup_post_s),moop_nongroup_s)));
			end;
			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Gold plan is greater than zero
			/*********************************************************************************/
			if coin_nongroup_pre_g>0 then do;
 			 e_oop_spend_onG_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_g/coin_nongroup_pre_g)*(SPEND&i.[j]*coin_nongroup_pre_g),
                                              (SPEND&i.[j]> ded_nongroup_g/coin_nongroup_pre_g)*(min(sum(ded_nongroup_g,(SPEND&i.[j]-ded_nongroup_g/coin_nongroup_pre_g)*coin_nongroup_post_g),moop_nongroup_g)));
			end;	
			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Bronze plan is zero
			/*********************************************************************************/
			if coin_nongroup_pre_b=0 then do;
			 e_oop_spend_onB_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_b)*(SPEND&i.[j]*coin_nongroup_pre_b),
                                              (SPEND&i.[j]> ded_nongroup_b)*(min(sum(ded_nongroup_b,(SPEND&i.[j]-ded_nongroup_b)*coin_nongroup_post_b),moop_nongroup_b)));
			end;
			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Silver plan is zero
			/*********************************************************************************/
			if coin_nongroup_pre_s=0 then do;
 			 e_oop_spend_onS_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                              (SPEND&i.[j]> ded_nongroup_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)));
			end;
			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Gold plan is zero
			/*********************************************************************************/
			if coin_nongroup_pre_g=0 then do;
 			 e_oop_spend_onG_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_g)*(SPEND&i.[j]*coin_nongroup_pre_g),
                                              (SPEND&i.[j]> ded_nongroup_g)*(min(sum(ded_nongroup_g,(SPEND&i.[j]-ded_nongroup_g)*coin_nongroup_post_g),moop_nongroup_g)));
			end;	
		end;
		
		/************************************************************************************** 
		/	Calculate the HIU-level expected out-of-pocket health care spending on a plan in
		/	the marketplace over all health states by tier
		/*************************************************************************************/
		e_oop_spend_onB_hiu1 = sum(of e_oop_spend_onB_hlth[*]);
 		e_oop_spend_onS_hiu1 = sum(of e_oop_spend_onS_hlth[*]);
 		e_oop_spend_onG_hiu1 = sum(of e_oop_spend_onB_hlth[*]); 
		
		/**************************************************************************************
		/	Calculate the variance of out-of-pocket health care spending for each health state 
		/*************************************************************************************/
		do j=1 to 16;

			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Bronze plan is greater than zero
			/*********************************************************************************/
			if coin_nongroup_pre_b>0 then do;
				v_oop_spend_onB_hlth[j] = prob&i.[j]*(sum((SPEND&i.[j]<=ded_nongroup_b/coin_nongroup_pre_b)*(SPEND&i.[j]*coin_nongroup_pre_b),
                                          (SPEND&i.[j]> ded_nongroup_b/coin_nongroup_pre_b)*(min(sum(ded_nongroup_b,(SPEND&i.[j]-ded_nongroup_b/coin_nongroup_pre_b)*coin_nongroup_post_b),moop_nongroup_b)),0)-e_oop_spend_onB_hiu1)**2;
			 	v_oop_spend_offB_hlth[j] = prob&i.[j]*(sum((SPEND&i.[j]<=ded_nongroup_b/coin_nongroup_pre_b)*(SPEND&i.[j]*coin_nongroup_pre_b),
                                          (SPEND&i.[j]> ded_nongroup_b/coin_nongroup_pre_b)*(min(sum(ded_nongroup_b,(SPEND&i.[j]-ded_nongroup_b/coin_nongroup_pre_b)*coin_nongroup_post_b),moop_nongroup_b))  )-e_oop_spend_onB_hiu1)**2;
			end;
			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Silver plan is greater than zero
			/*********************************************************************************/
			if coin_nongroup_pre_s>0 then do;
			 %if &firm_u.=yes %then %do; /*from firms' perspective*/
			 	v_oop_spend_onS_hlth     [j] = prob&i.[j]*(max(0,sum((SPEND&i.[j]<=ded_nongroup_s/coin_nongroup_pre_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                        (SPEND&i.[j]> ded_nongroup_s/coin_nongroup_pre_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s/coin_nongroup_pre_s)*coin_nongroup_post_s),moop_nongroup_s)),-CS_VALUE_no)    )-max(0,e_oop_spend_onS_hiu1-CS_VALUE_no))**2;
			 	v_oop_spend_onS_ppo_hlth [j] = prob&i.[j]*(max(0,sum((SPEND&i.[j]<=ded_nongroup_s/coin_nongroup_pre_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                        (SPEND&i.[j]> ded_nongroup_s/coin_nongroup_pre_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s/coin_nongroup_pre_s)*coin_nongroup_post_s),moop_nongroup_s)),-CS_VALUE_PPO_o) )-max(0,e_oop_spend_onS_hiu1-CS_VALUE_PPO_o))**2;
			 	v_oop_spend_onS_hmo_hlth [j] = prob&i.[j]*(max(0,sum((SPEND&i.[j]<=ded_nongroup_s/coin_nongroup_pre_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                        (SPEND&i.[j]> ded_nongroup_s/coin_nongroup_pre_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s/coin_nongroup_pre_s)*coin_nongroup_post_s),moop_nongroup_s)),-CS_VALUE_HMO_o) )-max(0,e_oop_spend_onS_hiu1-CS_VALUE_HMO_o))**2;
			 	v_oop_spend_onS_hdhp_hlth[j] = prob&i.[j]*(max(0,sum((SPEND&i.[j]<=ded_nongroup_s/coin_nongroup_pre_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                        (SPEND&i.[j]> ded_nongroup_s/coin_nongroup_pre_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s/coin_nongroup_pre_s)*coin_nongroup_post_s),moop_nongroup_s)),-CS_VALUE_HDHP_o))-max(0,e_oop_spend_onS_hiu1-CS_VALUE_HDHP_o))**2;
			 	v_oop_spend_onS_hlth     [j] = prob&i.[j]*(      sum((SPEND&i.[j]<=ded_nongroup_s/coin_nongroup_pre_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                        (SPEND&i.[j]> ded_nongroup_s/coin_nongroup_pre_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s/coin_nongroup_pre_s)*coin_nongroup_post_s),moop_nongroup_s))                  )-e_oop_spend_onS_hiu1)**2;
			 %end;
			 %if &hiu_u.=yes %then %do; /*from HIUs' perspective*/
			 	v_oop_spend_onS_hlth[j] = prob&i.[j]*(max(0,sum((SPEND&i.[j]<=ded_nongroup_s/coin_nongroup_pre_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                   (SPEND&i.[j]> ded_nongroup_s/coin_nongroup_pre_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s/coin_nongroup_pre_s)*coin_nongroup_post_s),moop_nongroup_s)),-CS_VALUE))-max(0,e_oop_spend_onS_hiu1-CS_VALUE))**2;
			 	v_oop_spend_offS_hlth[j] = prob&i.[j]*(      sum((SPEND&i.[j]<=ded_nongroup_s/coin_nongroup_pre_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                   (SPEND&i.[j]> ded_nongroup_s/coin_nongroup_pre_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s/coin_nongroup_pre_s)*coin_nongroup_post_s),moop_nongroup_s))           )-e_oop_spend_onS_hiu1)**2;
			 %end;
			end;
			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Gold plan is greater than zero
			/*********************************************************************************/
			if coin_nongroup_pre_g>0 then do;
			 	v_oop_spend_onG_hlth[j] = prob&i.[j]*(sum((SPEND&i.[j]<=ded_nongroup_g/coin_nongroup_pre_g)*(SPEND&i.[j]*coin_nongroup_pre_g),
                                          (SPEND&i.[j]> ded_nongroup_g/coin_nongroup_pre_g)*(min(sum(ded_nongroup_g,(SPEND&i.[j]-ded_nongroup_g/coin_nongroup_pre_g)*coin_nongroup_post_g),moop_nongroup_g)),0)-e_oop_spend_onG_hiu1)**2;
			 	v_oop_spend_offG_hlth[j] = prob&i.[j]*(sum((SPEND&i.[j]<=ded_nongroup_g/coin_nongroup_pre_g)*(SPEND&i.[j]*coin_nongroup_pre_g),
                                          (SPEND&i.[j]> ded_nongroup_g/coin_nongroup_pre_g)*(min(sum(ded_nongroup_g,(SPEND&i.[j]-ded_nongroup_g/coin_nongroup_pre_g)*coin_nongroup_post_g),moop_nongroup_g))  )-e_oop_spend_onG_hiu1)**2;
			end;
			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Bronze plan is zero
			/*********************************************************************************/
			if coin_nongroup_pre_b=0 then do;
			 	v_oop_spend_onB_hlth[j] = prob&i.[j]*(sum((SPEND&i.[j]<=ded_nongroup_b)*(SPEND&i.[j]*coin_nongroup_pre_b),
                                          (SPEND&i.[j]> ded_nongroup_b)*(min(sum(ded_nongroup_b,(SPEND&i.[j]-ded_nongroup_b)*coin_nongroup_post_b),moop_nongroup_b)),0)-e_oop_spend_onB_hiu1)**2;
			 	v_oop_spend_offB_hlth[j] = prob&i.[j]*(sum((SPEND&i.[j]<=ded_nongroup_b)*(SPEND&i.[j]*coin_nongroup_pre_b),
                                          (SPEND&i.[j]> ded_nongroup_b)*(min(sum(ded_nongroup_b,(SPEND&i.[j]-ded_nongroup_b)*coin_nongroup_post_b),moop_nongroup_b))  )-e_oop_spend_onB_hiu1)**2;
			end;
			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Silver plan is zero
			/*********************************************************************************/
			if coin_nongroup_pre_s=0 then do;
			 %if &firm_u.=yes %then %do; /*from firms' perspective*/
				v_oop_spend_onS_hlth     [j] = prob&i.[j]*(max(0,sum((SPEND&i.[j]<=ded_nongroup_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                         (SPEND&i.[j]> ded_nongroup_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)),-CS_VALUE_no    ))-max(0,e_oop_spend_onS_hiu1-CS_VALUE_no))**2;
				v_oop_spend_onS_ppo_hlth [j] = prob&i.[j]*(max(0,sum((SPEND&i.[j]<=ded_nongroup_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                         (SPEND&i.[j]> ded_nongroup_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)),-CS_VALUE_PPO_o ))-max(0,e_oop_spend_onS_hiu1-CS_VALUE_PPO_o))**2;
				v_oop_spend_onS_hmo_hlth [j] = prob&i.[j]*(max(0,sum((SPEND&i.[j]<=ded_nongroup_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                         (SPEND&i.[j]> ded_nongroup_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)),-CS_VALUE_HMO_o ))-max(0,e_oop_spend_onS_hiu1-CS_VALUE_HMO_o))**2;
				v_oop_spend_onS_hdhp_hlth[j] = prob&i.[j]*(max(0,sum((SPEND&i.[j]<=ded_nongroup_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                         (SPEND&i.[j]> ded_nongroup_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)),-CS_VALUE_HDHP_o))-max(0,e_oop_spend_onS_hiu1-CS_VALUE_HDHP_o))**2;
				v_oop_spend_offS_hlth    [j] = prob&i.[j]*(      sum((SPEND&i.[j]<=ded_nongroup_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                         (SPEND&i.[j]> ded_nongroup_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s))                  )-e_oop_spend_onS_hiu1)**2;
			 %end;
			 %if &hiu_u.=yes %then %do; /*from HIUs' perspective*/
				v_oop_spend_onS_hlth[j] = prob&i.[j]*(max(0,sum((SPEND&i.[j]<=ded_nongroup_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                    (SPEND&i.[j]> ded_nongroup_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)),-CS_VALUE))-max(0,e_oop_spend_onS_hiu1-CS_VALUE))**2;
				v_oop_spend_offS_hlth[j] = prob&i.[j]*(      sum((SPEND&i.[j]<=ded_nongroup_s)*(SPEND&i.[j]*coin_nongroup_pre_s),
                                                    (SPEND&i.[j]> ded_nongroup_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s))           )-e_oop_spend_onS_hiu1)**2;
			 %end;
			end;
			/********************************************************************************** 
			/	If the pre-deductible coinsurance rate for Gold plan is zero
			/*********************************************************************************/
			if coin_nongroup_pre_g=0 then do;
			 	v_oop_spend_onG_hlth[j] = prob&i.[j]*(sum((SPEND&i.[j]<=ded_nongroup_g)*(SPEND&i.[j]*coin_nongroup_pre_g),
                                          (SPEND&i.[j]> ded_nongroup_g)*(min(sum(ded_nongroup_g,(SPEND&i.[j]-ded_nongroup_g)*coin_nongroup_post_g),moop_nongroup_g)),0)-e_oop_spend_onG_hiu1)**2;
				v_oop_spend_offG_hlth[j] = prob&i.[j]*(sum((SPEND&i.[j]<=ded_nongroup_g)*(SPEND&i.[j]*coin_nongroup_pre_g),
                                          (SPEND&i.[j]> ded_nongroup_g)*(min(sum(ded_nongroup_g,(SPEND&i.[j]-ded_nongroup_g)*coin_nongroup_post_g),moop_nongroup_g))  )-e_oop_spend_onG_hiu1)**2;
			end;

		end;

		/************************************************************************************** 
		/	Calculate the HIU-level utilities from firms' perspective
		/*************************************************************************************/
		%if &firm_u.=yes %then %do;

			/**********************************************************************************
			/	Calculate the variance of the out-of-pocket health care spending over all
			/	health states
			/	Note:	Variance related to ESI types here are used in firms' decision making
			/*********************************************************************************/
			v_oop_spend_onB_hiu1      = sum(of v_oop_spend_onB_hlth     [*]);
			v_oop_spend_onS_hiu1      = sum(of v_oop_spend_onS_hlth     [*]);
			v_oop_spend_onS_ppo_hiu1  = sum(of v_oop_spend_onS_ppo_hlth [*]);
			v_oop_spend_onS_hmo_hiu1  = sum(of v_oop_spend_onS_hmo_hlth [*]);
			v_oop_spend_onS_hdhp_hiu1 = sum(of v_oop_spend_onS_hdhp_hlth[*]);		
			v_oop_spend_onG_hiu1      = sum(of v_oop_spend_onG_hlth     [*]);

			v_oop_spend_offB_hiu1 = sum(of v_oop_spend_offB_hlth[*]);
			v_oop_spend_offS_hiu1 = sum(of v_oop_spend_offS_hlth[*]);
			v_oop_spend_offG_hiu1 = sum(of v_oop_spend_offG_hlth[*]);

			/********************************************************************************** 
			/	Make sure HIUs are not allowed to make a plan choice of which the premium 
			/	exceeds a certain fraction (&budget_constraint_frac.) of disposable income
			/*********************************************************************************/

			/********************************************************************************** 
			/	Calculate utilities for HIUs with a plan in the marketplace:
			/	(1) with an	ESI offer
			/*********************************************************************************/
			%macro u_typ(TYP);
				if (prem_onmarket_posttax_b_&TYP._o<&budget_constraint_frac.*DISP_INC) then 
					U_onB_hiu1_&TYP._o = hiuinc - prem_onmarket_posttax_b_&TYP._o -e_oop_spend_onB_hiu1 - 0.5*&RA_param.*sum(v_oop_spend_onB_hiu1*(onmarket_subsidy_&TYP._o>0),v_oop_spend_offB_hiu1*(onmarket_subsidy_&TYP._o<=0 or onmarket_subsidy_&TYP._o=.));

				if (prem_onmarket_posttax_s_&TYP._o<&budget_constraint_frac.*DISP_INC) then 
			 		U_onS_hiu1_&TYP._o = hiuinc - prem_onmarket_posttax_s_&TYP._o -max(e_oop_spend_onS_hiu1-CS_VALUE_&TYP._o,0) - 0.5*&RA_param.*sum(v_oop_spend_onS_hiu1_&TYP.*(onmarket_subsidy_&TYP._o>0),v_oop_spend_offS_hiu1*(onmarket_subsidy_&TYP._o<=0 or onmarket_subsidy_&TYP._o=.));

			 	if (prem_onmarket_posttax_g_&TYP._o<&budget_constraint_frac.*DISP_INC) then 
			 		U_onG_hiu1_&TYP._o = hiuinc - prem_onmarket_posttax_g_&TYP._o -e_oop_spend_onG_hiu1 - 0.5*&RA_param.*sum(v_oop_spend_onG_hiu1*(onmarket_subsidy_&TYP._o>0),v_oop_spend_g_offmarket_hiu1*(onmarket_subsidy_&TYP._o<=0 or onmarket_subsidy_&TYP._o=.));
			%mend u_typ;
			%u_typ(PPO);%u_typ(HMO);%u_typ(HDHP);

			/********************************************************************************** 
			/	Calculate utilities for HIUs with a plan:
			/	(2) with no ESI offer
			/*********************************************************************************/
			if prem_onmarket_posttax_b_no<&budget_constraint_frac.*DISP_INC then 
				 U_onB_hiu1_no = hiuinc - prem_onmarket_posttax_b_no -e_oop_spend_onB_hiu1 - 0.5*&RA_param.*sum(v_oop_spend_onB_hiu1*(onmarket_subsidy_no>0),v_oop_spend_offB_hiu1*(onmarket_subsidy_no<=0 or onmarket_subsidy_no=.));
			if prem_onmarket_posttax_s_no<&budget_constraint_frac.*DISP_INC then
				 U_onS_hiu1_no = hiuinc - prem_onmarket_posttax_s_no -max(e_oop_spend_onS_hiu1-CS_VALUE_no,0) - 0.5*&RA_param.*sum(v_oop_spend_onS_hiu1*(onmarket_subsidy_no>0),v_oop_spend_offS_hiu1*(onmarket_subsidy_no<=0 or onmarket_subsidy_no=.));
			if prem_onmarket_posttax_g_no<&budget_constraint_frac.*DISP_INC then
				 U_onG_hiu1_no = hiuinc - prem_onmarket_posttax_g_no -e_oop_spend_onG_hiu1 - 0.5*&RA_param.*sum(v_oop_spend_onG_hiu1*(onmarket_subsidy_no>0),v_oop_spend_g_offmarket_hiu1*(onmarket_subsidy_no<=0 or onmarket_subsidy_no=.));

			if prem_offmarket_posttax_b<&budget_constraint_frac.*DISP_INC then U_offB_hiu1 = hiuinc - prem_offmarket_posttax_b -e_oop_spend_onB_hiu1 - 0.5*&RA_param.*v_oop_spend_offB_hiu1;
			if prem_offmarket_posttax_s<&budget_constraint_frac.*DISP_INC then U_offS_hiu1 = hiuinc - prem_offmarket_posttax_s -e_oop_spend_onS_hiu1 - 0.5*&RA_param.*v_oop_spend_offS_hiu1;
			if prem_offmarket_posttax_g<&budget_constraint_frac.*DISP_INC then U_offG_hiu1 = hiuinc - prem_offmarket_posttax_g -e_oop_spend_onG_hiu1 - 0.5*&RA_param.*v_oop_spend_g_offmarket_hiu1;

			Nw_nongroup_HIU1 = wgt[&i.];

			/********************************************************************************** 
			/	Create the shifters for HIUs with a plan in the marketplace:
			/	(1) with an ESI	offer
			/*********************************************************************************/
			%macro shift_typ(TYP);

			if onmarket_subsidy_&TYP._o>0 then GET_SUB_&TYP._o=1;
				else GET_SUB_&TYP._o=0;

			SHIFTER_B_&TYP._o = sum(
							        (1-GET_SUB_&TYP._o)*(onmarket_SHIFT_HIU1_B_nosub+&network_breadth_b_ns.),
							        GET_SUB_&TYP._o*(sum(
											    age_all_inc_lt70		* (onmarket_Bs_S_1+&network_breadth_b.) ,
											    age_all_inc_70to250		* (onmarket_Bs_S_2+&network_breadth_b.) ,
											    age_all_inc_250to400	* (onmarket_Bs_S_3+&network_breadth_b.) ,
											    age_all_inc_400p		* (onmarket_Bs_S_4+&network_breadth_b.)
									           		)   )
						             );
			SHIFTER_S_&TYP._o = sum(
									(1-GET_SUB_&TYP._o)*(onmarket_SHIFT_HIU1_S_nosub+&network_breadth_s_ns.),
									GET_SUB_&TYP._o*(sum(
												age_all_inc_lt70		* (onmarket_Ss_S_1+&network_breadth_s.			) ,
												age_lt30_inc_70to138	* (onmarket_Ss_S_2+&network_breadth_s.+&nb_lt30.	) ,
												age_31to50_inc_70to138	* (onmarket_Ss_S_3+&network_breadth_s.+&nb_30to50.) ,
												age_51p_inc_70to138	 	* (onmarket_Ss_S_4+&network_breadth_s.+&nb_50p.	) ,
												age_lt30_inc_138to250	* (onmarket_Ss_S_5+&network_breadth_s.+&nb_lt30.	) ,
												age_31to50_inc_138to250	* (onmarket_Ss_S_6+&network_breadth_s.+&nb_30to50.) ,
												age_51p_inc_138to250	* (onmarket_Ss_S_7+&network_breadth_s.+&nb_50p.	) ,
												age_all_inc_250to400	* (onmarket_Ss_S_8+&network_breadth_s.			) ,
												age_all_inc_400p		* (onmarket_Ss_S_9+&network_breadth_s.			)
													)	)
									);
			SHIFTER_G_&TYP._o = sum(
									(1-GET_SUB_&TYP._o)*(onmarket_SHIFT_HIU1_G_nosub+&network_breadth_g_ns.),
									GET_SUB_&TYP._o*(sum(
												age_all_inc_lt70		* (onmarket_Gs_S_1+&network_breadth_g.) ,
												age_all_inc_70to400		* (onmarket_Gs_S_2+&network_breadth_g.) ,
												age_all_inc_400p		* (onmarket_Gs_S_3+&network_breadth_g.)
													)	)
									);

			U_onB_hiu1_&TYP._o  = U_onB_hiu1_&TYP._o + SHIFTER_B_&TYP._o;  
			U_onS_hiu1_&TYP._o  = U_onS_hiu1_&TYP._o + SHIFTER_S_&TYP._o; 
			U_onG_hiu1_&TYP._o  = U_onG_hiu1_&TYP._o + SHIFTER_G_&TYP._o; 

			%mend shift_typ;
			%shift_typ(PPO);%shift_typ(HMO);%shift_typ(HDHP);

			/********************************************************************************** 
			/	Create the shifters for HIUs with a plan in the marketplace:
			/	(2) with no ESI offer
			/*********************************************************************************/
			if onmarket_subsidy_no>0 then GET_SUB_no=1;
			 else GET_SUB_no=0;

			SHIFTER_B_no = sum(
								(1-GET_SUB_no)*(onmarket_SHIFT_HIU1_B_nosub+&network_breadth_b_ns.),
								GET_SUB_no*(sum(
												age_all_inc_lt70     	* (onmarket_Bs_S_1+&network_breadth_b.) ,
												age_all_inc_70to250		* (onmarket_Bs_S_2+&network_breadth_b.) ,
												age_all_inc_250to400	* (onmarket_Bs_S_3+&network_breadth_b.) ,
												age_all_inc_400p		* (onmarket_Bs_S_4+&network_breadth_b.)
											)	)
							);
			SHIFTER_S_no = sum(
								(1-GET_SUB_no)*(onmarket_SHIFT_HIU1_S_nosub+&network_breadth_s_ns.),
								GET_SUB_no*(sum(
												age_all_inc_lt70		* (onmarket_Ss_S_1+&network_breadth_s.			) ,
												age_lt30_inc_70to138	* (onmarket_Ss_S_2+&network_breadth_s.+&nb_lt30.	) ,
												age_31to50_inc_70to138	* (onmarket_Ss_S_3+&network_breadth_s.+&nb_30to50.) ,
												age_51p_inc_70to138	 	* (onmarket_Ss_S_4+&network_breadth_s.+&nb_50p.	) ,
												age_lt30_inc_138to250	* (onmarket_Ss_S_5+&network_breadth_s.+&nb_lt30.	) ,
												age_31to50_inc_138to250	* (onmarket_Ss_S_6+&network_breadth_s.+&nb_30to50.) ,
												age_51p_inc_138to250	* (onmarket_Ss_S_7+&network_breadth_s.+&nb_50p.	) ,
												age_all_inc_250to400	* (onmarket_Ss_S_8+&network_breadth_s.			) ,
												age_all_inc_400p		* (onmarket_Ss_S_9+&network_breadth_s.			)
											)	)
							);
			SHIFTER_G_no = sum(
							(1-GET_SUB_no)*(onmarket_SHIFT_HIU1_G_nosub+&network_breadth_g_ns.),
							GET_SUB_no*(sum(
												age_all_inc_lt70		* (onmarket_Gs_S_1+&network_breadth_g.) ,
												age_all_inc_70to400		* (onmarket_Gs_S_2+&network_breadth_g.) ,
												age_all_inc_400p		* (onmarket_Gs_S_3+&network_breadth_g.)
										)	)
							);

			/********************************************************************************** 
			/	Calculate HIU-level utilities in and outside the marketplace by plan tier
			/	by adding the utility shifters calculated above
			/*********************************************************************************/
			U_onB_hiu1_no = U_onB_hiu1_no +SHIFTER_B_no;  
			U_onS_hiu1_no = U_onS_hiu1_no +SHIFTER_S_no; 
			U_onG_hiu1_no = U_onG_hiu1_no +SHIFTER_G_no; 

			U_offB_hiu1 = U_offB_hiu1 + (offmarket_SHIFT_HIU1_B+&network_breadth_offmarket.);  
			U_offS_hiu1 = U_offS_hiu1 + (offmarket_SHIFT_HIU1_S+&network_breadth_offmarket.); 
			U_offG_hiu1 = U_offG_hiu1 + (offmarket_SHIFT_HIU1_G+&network_breadth_offmarket.); 
		%end;

		/************************************************************************************** 
		/	Calculate the HIU-level utilities from HIUs' perspective
		/*************************************************************************************/		
		%if &hiu_u.=yes %then %do;

			/**********************************************************************************
			/	Calculate the variance of the out-of-pocket health care spending over all
			/	health states
			/*********************************************************************************/
			v_oop_spend_onB_hiu1 = sum(of v_oop_spend_onB_hlth[*]);
			v_oop_spend_onS_hiu1 = sum(of v_oop_spend_onS_hlth[*]);
			v_oop_spend_onG_hiu1 = sum(of v_oop_spend_onG_hlth[*]);

			v_oop_spend_offB_hiu1 = sum(of v_oop_spend_offB_hlth[*]);
			v_oop_spend_offS_hiu1 = sum(of v_oop_spend_offS_hlth[*]);
			v_oop_spend_offG_hiu1 = sum(of v_oop_spend_offG_hlth[*]);

			/********************************************************************************** 
			/	Make sure HIUs are not allowed to make a plan choice of which the premium 
			/	exceeds a certain fraction (&budget_constraint_frac.) of disposable income
			/*********************************************************************************/

			/********************************************************************************** 
			/	Calculate utilities for HIUs with a plan in and outside the marketplace
			/*********************************************************************************/
			if prem_onmarket_posttax_b<&budget_constraint_frac.*DISP_INC then U_onB_hiu1 = hiuinc - prem_onmarket_posttax_b -e_oop_spend_onB_hiu1                -0.5*&RA_param.*v_oop_spend_onB_hiu1;
	 		if prem_onmarket_posttax_s<&budget_constraint_frac.*DISP_INC then U_onS_hiu1 = hiuinc - prem_onmarket_posttax_s -max(e_oop_spend_onS_hiu1-CS_VALUE,0)-0.5*&RA_param.*v_oop_spend_onS_hiu1;
	 		if prem_onmarket_posttax_g<&budget_constraint_frac.*DISP_INC then U_onG_hiu1 = hiuinc - prem_onmarket_posttax_g -e_oop_spend_onG_hiu1                -0.5*&RA_param.*v_oop_spend_onG_hiu1;

			if prem_offmarket_posttax_b<&budget_constraint_frac.*DISP_INC then U_offB_hiu1 = hiuinc - prem_offmarket_posttax_b -e_oop_spend_onB_hiu1                -0.5*&RA_param.*v_oop_spend_offB_hiu1;
	 		if prem_offmarket_posttax_s<&budget_constraint_frac.*DISP_INC then U_offS_hiu1 = hiuinc - prem_offmarket_posttax_s -e_oop_spend_onS_hiu1                -0.5*&RA_param.*v_oop_spend_offS_hiu1;
	 		if prem_offmarket_posttax_g<&budget_constraint_frac.*DISP_INC then U_offG_hiu1 = hiuinc - prem_offmarket_posttax_g -e_oop_spend_onG_hiu1                -0.5*&RA_param.*v_oop_spend_offG_hiu1;

			Nw_nongroup_HIU1  = wgt[&i.];		

			/********************************************************************************** 
			/	Create the shifters for HIUs with a plan in the marketplace
			/*********************************************************************************/
			if onmarket_subsidy>0 then GET_SUB=1;
		 		else GET_SUB=0;	

			SHIFTER_B = sum(
							(1-GET_SUB)*(onmarket_SHIFT_HIU1_B_nosub+&network_breadth_b_ns.),
							GET_SUB*(sum(
											age_all_inc_lt70     	* (onmarket_Bs_S_1+&network_breadth_b.) ,
											age_all_inc_70to250		* (onmarket_Bs_S_2+&network_breadth_b.) ,
											age_all_inc_250to400	* (onmarket_Bs_S_3+&network_breadth_b.) ,
											age_all_inc_400p		* (onmarket_Bs_S_4+&network_breadth_b.)
									)	)
						);
			SHIFTER_S = sum(
							(1-GET_SUB)*(onmarket_SHIFT_HIU1_S_nosub+&network_breadth_s_ns.),
							GET_SUB*(sum(
											age_all_inc_lt70		* (onmarket_Ss_S_1+&network_breadth_s.			) ,
											age_lt30_inc_70to138	* (onmarket_Ss_S_2+&network_breadth_s.+&nb_lt30.	) ,
											age_31to50_inc_70to138	* (onmarket_Ss_S_3+&network_breadth_s.+&nb_30to50.) ,
											age_51p_inc_70to138	 	* (onmarket_Ss_S_4+&network_breadth_s.+&nb_50p.	) ,
											age_lt30_inc_138to250	* (onmarket_Ss_S_5+&network_breadth_s.+&nb_lt30.	) ,
											age_31to50_inc_138to250	* (onmarket_Ss_S_6+&network_breadth_s.+&nb_30to50.) ,
											age_51p_inc_138to250	* (onmarket_Ss_S_7+&network_breadth_s.+&nb_50p.	) ,
											age_all_inc_250to400	* (onmarket_Ss_S_8+&network_breadth_s.			) ,
											age_all_inc_400p		* (onmarket_Ss_S_9+&network_breadth_s.			)
									)	)
						);
			SHIFTER_G = sum(
							(1-GET_SUB)*(onmarket_SHIFT_HIU1_G_nosub+&network_breadth_g_ns.),
							GET_SUB*(sum(
											age_all_inc_lt70		* (onmarket_Gs_S_1+&network_breadth_g.) ,
											age_all_inc_70to400		* (onmarket_Gs_S_2+&network_breadth_g.) ,
											age_all_inc_400p		* (onmarket_Gs_S_3+&network_breadth_g.)
									)	)
						);

			/********************************************************************************** 
			/	Calculate HIU-level utilities for a plan in and outside the marketplace
			/	by adding the utility shifters calculated above			
			/*********************************************************************************/
			U_onB_hiu1  = U_onB_hiu1 + SHIFTER_B;  
	 		U_onS_hiu1  = U_onS_hiu1 + SHIFTER_S; 
	 		U_onG_hiu1  = U_onG_hiu1 + SHIFTER_G; 

			U_offB_hiu1 = U_offB_hiu1 + (offmarket_SHIFT_HIU1_B+&network_breadth_offmarket.);  
			U_offS_hiu1 = U_offS_hiu1 + (offmarket_SHIFT_HIU1_S+&network_breadth_offmarket.); 
			U_offG_hiu1 = U_offG_hiu1 + (offmarket_SHIFT_HIU1_G+&network_breadth_offmarket.); 
		%end;

	end;

	%end;

%mend calc_U_nongroup_hiu1;
