/*=============================================================================================
/==============================================================================================
/	Module Name : prep_for_simulated_hiu_file.sas															
/ 	Purpose   	: To prepare HIU-level data which will be used to simulate HIUs' choices
/	Inputs		: HIU-level data with demographic information and 
/				  the firm offers simulated in the the previous step
/	Outputs 	: Three distinct datasets for different types of HIUs: 									
/					"hiu_size_0": HIUs in which all members' coverage types were held constant, 
/								  (They are unlikely to change their health insurance coverage 
/								  in response to the types of policy proposals that HISIM2 is designed to simulate.)
/		    		"hiu_size_1": Single-person HIUs, i.e. HIUs with only one person whose coverage type was not held constant    
/					"hiu_size_2p": Multi-person HIUs, i.e. HIUs with at least two members whose coverage types were not held constant
/	Summary		:
/	(1) Replace the firm offers from the data preparation (or DataPrep) with the firm offers simulated 
/		 in the previous step. (We call the preparation of the data as DataPrep for short.)
/		 For details about the preparation of the data, see Congressional Budget Office, 
/		 	"Sources and Preparation of Data Used in HISIM2CBOs Health Insurance Simulation Model" (April 2019),
/			www.cbo.gov/publication/55087
/	(2) Define individual-specific variables in an HIU to calculate HIU's utilities and policy-related 
/		variables (such as public insurance and nongroup coverage eligibility, premium subsidy, etc.)
/	The code is written in SAS, version 9.4.
/==============================================================================================
/============================================================================================*/

%macro prep_for_simulated_hiu_file;  
/*=============================================================================================
/	(1) Replace the firm offers assigned in DataPrep with the firm offers simulated in the previous step, 
/		Calculate the employer mandate penalty, and 
/		Merge those onto HIU-level data in order to calculate utilities later											
/============================================================================================*/

	/******************************************************************************************
	/	Replace the firm offers assigned in DataPrep 
	/			with the firm offers simulated in the previous step and 
	/	Keep the variables needed to calculate the employer mandate penalty
	/*****************************************************************************************/
	data hasoffer (keep = pid 
						  h_esi_firmoffers offer_PPO offer_HMO offer_HDHP 
						  lf_fulltime  lf_firmsize N_employees 
						  penalty_unaffoffer_ppo penalty_unaffoffer_hmo penalty_unaffoffer_hdhp);
		set	tempx.firm_offers_&DSETNAME.;

		if	no_offer_sim ne 1 then	h_esi_firmoffers= 1;
		else						h_esi_firmoffers= 0;
		offer_PPO	= OFFER_PPO_SIM; 
		offer_HMO	= OFFER_HMO_SIM; 
		offer_HDHP	= OFFER_HDHP_SIM;

		proc sort;	by pid; 
	run;

	/******************************************************************************************
	/	Calculate the employer mandate penalty for not offering or offering unaffordable health plans 
	/*****************************************************************************************/
	data hasoffer (drop = lf_fulltime lf_firmsize N_employees penalty_unaffoffer_ppo penalty_unaffoffer_hmo penalty_unaffoffer_hdhp);
		set hasoffer;
		
		if h_esi_firmoffers = 0 then do;
		 	employer_mandate      = (((lf_firmsize*lf_fulltime/N_employees)>=&ER_mandate_size.)*&ER_mandate_nooffer.*((lf_firmsize*lf_fulltime/N_employees)-&ER_mandate_disregard.)/lf_firmsize);
			employer_mandate_collected = &ER_perceived_liability.*employer_mandate;
		end;
		if h_esi_firmoffers = 1 then do;
		 	employer_mandate   = (min((sum(penalty_unaffoffer_ppo*offer_PPO,penalty_unaffoffer_hmo*offer_HMO,penalty_unaffoffer_hdhp*offer_HDHP)*((lf_firmsize*lf_fulltime/N_employees)>=&ER_mandate_size.))/N_employees,
	         	               (((lf_firmsize*lf_fulltime/N_employees)>=&ER_mandate_size.)*&ER_mandate_nooffer.*((lf_firmsize*lf_fulltime/N_employees)-&ER_mandate_disregard.))/lf_firmsize));
			employer_mandate_collected = &ER_perceived_liability.*employer_mandate;
		end;
	run;

	/****************************************************************************************** 
	/	Merge the simulated firm offer information onto the individual-level data from DataPrep
	/*****************************************************************************************/
	proc sort data = tempx.ind_file_for_hiu_level_setup 
			  out  = ind_level (keep =  h_seq hiu_id pid NONDEP_CHILD hiu_member_type age
									    hiu_size  
										h_esi_firmoffers worker_ignored);
		by pid; 
	run;

	data set_up_file;
		merge ind_level (in=a rename = (h_esi_firmoffers = h_esi_firmoffers_base))
	          hasoffer  (in=b);
		by pid;
		if a;
		if h_esi_firmoffers =. then	h_esi_firmoffers_base = .;
	run;

	/****************************************************************************************** 
	/	Process the individual-level data with the simulated firm offer information
	/*****************************************************************************************/
	data tempx.set_up_file;
		set set_up_file;
		/************************************************************************************** 
		/	Set offer-related variables of ignored workers to missing
		/	Note: For HIUs that have more than 3 workers, the 4th (and plus) workers are ignored 					
		/*************************************************************************************/		
		if worker_ignored = 1 then do;					
			h_esi_firmoffers			= .;
			h_esi_firmoffers_base		= .;
			offer_PPO  					= .;
			offer_HMO  					= .;
			offer_HDHP 					= .;
			employer_mandate 			= .;
			employer_mandate_collected	= .;
		end;
		/************************************************************************************** 
		/	Set missing values to 0
		/*************************************************************************************/
		if h_esi_firmoffers_base 		= . then h_esi_firmoffers_base		= 0;
		if h_esi_firmoffers		 		= . then h_esi_firmoffers			= 0;
		if offer_PPO 			 		= . then offer_PPO 					= 0;
		if offer_HMO 			 		= . then offer_HMO 					= 0;
		if offer_HDHP			 		= . then offer_HDHP					= 0;
		if employer_mandate				= . then employer_mandate			= 0;
		if employer_mandate_collected	= . then employer_mandate_collected	= 0;
		/************************************************************************************** 
		/	Assign single or family offer status to individuals
		/*************************************************************************************/
		offer_single_base = 0;			
		offer_family_base = 0;
		offer_single_sim = 0;
		offer_family_sim = 0;

		if h_esi_firmoffers_base = 1 then do;
		 	if hiu_member_type = 1 		and hiu_size = 1 then do;
		  		offer_single_base = 1;
		  		offer_family_base = 0;
		 	end;
		 	if hiu_member_type in(1,2) 	and hiu_size > 1 then do;
		  		offer_single_base = 1;
		  		offer_family_base = 1;
		 	end;
		 	if hiu_member_type = 3 					     then do;
		  		offer_single_base = 1;
		  		offer_family_base = 0;
		 	end;
		end;
		if h_esi_firmoffers = 1 then do;
		 	if hiu_member_type = 1 		and hiu_size = 1 then do;
		  		offer_single_sim = 1;
		  		offer_family_sim = 0;
		 	end;
		 	if hiu_member_type in(1,2) 	and hiu_size > 1 then do;
		  		offer_single_sim = 1;
		  		offer_family_sim = 1;
		 	end;
		 	if hiu_member_type = 3 						 then do;
		  		offer_single_sim = 1;
		  		offer_family_sim = 0;
		 	end;
		end;
	run;

	/****************************************************************************************** 
	/	Sort data by member type so that the first 2 members of an HIU have access to family offers
	/*****************************************************************************************/
	proc sort data = tempx.set_up_file; 
		by 	h_seq hiu_id NONDEP_CHILD hiu_member_type descending age; 
	run;

	/****************************************************************************************** 
	/	Open the individual-level data and hold the file in memory
	/*****************************************************************************************/
	sasfile tempx.set_up_file open;

		/************************************************************************************** 
		/	Create HIU-level data with individual-specific arrays of firm offer information 
		/*************************************************************************************/
		%macro tp(var);
			proc transpose data=tempx.set_up_file out=&var.(drop=_NAME_) prefix=&var._;
				by h_seq hiu_id;
				var &var.;
			run;
			data &var.;
				set &var.;
				_LABEL_ = "";
			run;
		%mend tp;

		%tp(offer_single_base);
		%tp(offer_family_base);
		%tp(offer_single_sim);
		%tp(offer_family_sim);
		%tp(offer_HDHP);
		%tp(offer_HMO);
		%tp(offer_PPO);
		%tp(employer_mandate);
		%tp(employer_mandate_collected);

	/****************************************************************************************** 
	/	Close the data
	/*****************************************************************************************/
	sasfile tempx.set_up_file close;

	/****************************************************************************************** 
	/	Replace the individual-specific firm offer information in the HIU-level data
	/		with the simulated individual-specific firm offer information 
	/*****************************************************************************************/
	proc sort data = tempx.hiu_file_PRE_U_calc; 
		by h_seq hiu_id; 
	run;

	data tempx.hiu_file_PRE_U_calc_sim (drop = _LABEL_);
		merge	tempx.hiu_file_PRE_U_calc (drop = offer_single_base_1 - offer_single_base_&DIM. 
												  offer_family_base_1 - offer_family_base_&DIM. 
												  offer_single_sim_1 - offer_single_sim_&DIM. 
												  offer_family_sim_1 - offer_family_sim_&DIM.
												  offer_PPO_1 	  - offer_PPO_&DIM. 
												  offer_HMO_1 	  - offer_HMO_&DIM. 
												  offer_HDHP_1	  - offer_HDHP_&DIM.) 
				offer_single_base				
				offer_family_base
				offer_single_sim				
				offer_family_sim
				offer_PPO
				offer_HMO
				offer_HDHP
				employer_mandate
				employer_mandate_collected;
		by h_seq hiu_id; 
	run;

/*=============================================================================================
/	(2) Define individual-specific variables in an HIU to calculate HIU's utilities and
/		policy-related variables (such as public insurance eligibility, premium subsidy, etc)
/============================================================================================*/
	proc sort data = tempx.hiu_file_PRE_U_calc_sim;
		by OLD_H_SEQ hiu_id; 
	run;

	data tempx.hiu_file_FOR_U_calc_sim	(drop = pid_heldconst)
		 ID_nondep_kids_heldconst		(keep = old_h_seq  hiu_id  pid_heldconst);
		merge	tempx.hiu_file_PRE_U_calc_sim	(in=a)
				N_ESI_family_offers 			(in=b);
		by OLD_H_SEQ hiu_id;
		if a and b;
		
		/************************************************************************************** 
		/	Set the arrays of individual-specific variables (demographics, health spending, 
		/	ESI offers, public insurance eligibility, plan characteristics, etc.) 
		/	(not including those whose coverage types are held constant)
		/*************************************************************************************/		
		%Set_Arrays(firm_arrays=no, hiu_arrays=yes);
		/************************************************************************************** 
		/	Declare individual-specific arrays of people whose coverage types are held constant
		/	(i.e., "var name"_M)
		/*************************************************************************************/
		array care_M     		{&DIM.} care_1			-	care_&DIM.;
		array dual_M     		{&DIM.} dual_1			-	dual_&DIM.;
		array caid_M     		{&DIM.} caid_1			-	caid_&DIM.;
		array champ_M    		{&DIM.} champ_1			-	champ_&DIM.;
		array other_M    		{&DIM.} other_1			-	other_&DIM.;
		array esi_ph_s_M 		{&DIM.} esi_ph_s_1		-	esi_ph_s_&DIM.;
		array esi_ph_f_M 		{&DIM.} esi_ph_f_1		-	esi_ph_f_&DIM.;
		array esi_dep_M  		{&DIM.} esi_dep_1		-	esi_dep_&DIM.;
		array offmarket_ph_s_M  {&DIM.} offmarket_ph_s_1-	offmarket_ph_s_&DIM.;
		array offmarket_ph_f_M  {&DIM.} offmarket_ph_f_1-	offmarket_ph_f_&DIM.;
		array offmarket_dep_M   {&DIM.} offmarket_dep_1	-	offmarket_dep_&DIM.;
		array chip_M     		{&DIM.} chip_1			-	chip_&DIM.;
		array unin_M     		{&DIM.} unin_1			-	unin_&DIM.;
		/************************************************************************************** 
		/	Initialize those variables to zero
		/*************************************************************************************/
		do i=1 to &DIM.;
			care_M[i]   		= 0;
			dual_M[i]  			= 0;
			caid_M[i]   		= 0;	
			champ_M[i]   		= 0;
			other_M[i]			= 0;
			esi_ph_s_M[i]		= 0;
			esi_ph_f_M[i]		= 0;
			esi_dep_M[i] 		= 0;	
			offmarket_ph_s_M[i]	= 0;
			offmarket_ph_f_M[i]	= 0;
			offmarket_dep_M[i]  = 0;
			chip_M[i]			= 0;
			unin_M[i]   		= 0;
		end;
		/************************************************************************************** 
		/	Specify and ignore those whose coverage types are held constant for the purpose of
		/	calculating utilities
		/*************************************************************************************/
		%Ignored_Individuals(keep_track = yes);
		/************************************************************************************** 
		/	Output the HIU-level data with individual-specific arrays
		/*************************************************************************************/
		output tempx.hiu_file_FOR_U_calc_sim;
		/************************************************************************************** 
		/	Output individual-level data of only non-dependent children whose coverage types are
		/	held constant
		/*************************************************************************************/
		do i=1 to &DIM.;
			if age[i]=. and pid[i] ne . and nondep_kids_array[i]=1 then do;
				pid_heldconst = pid[i];
				output ID_nondep_kids_heldconst;
			end;
		end;
	run;

	/****************************************************************************************** 
	/	Sort and de-duplicate the individual-level data of non-dependent children
	/*****************************************************************************************/
	proc sort data = ID_nondep_kids_heldconst nodupkey; 
		by old_h_seq hiu_id pid_heldconst; 
	run;

	/****************************************************************************************** 
	/	Create HIU-level data of non-dependent children held constant with the array of their PIDs
	/*****************************************************************************************/
	proc transpose data = ID_nondep_kids_heldconst out = tempx.ID_nondep_kids_heldconst_HIU (drop = _NAME_ ) prefix = pid_heldconst_;
		by old_h_seq hiu_id;
		var pid_heldconst;
	run;
	
	/****************************************************************************************** 
	/	Read in non-group premium factors from the baseline output data so that we can
	/	run a policy simulation starting from any year of the budget window we specify
	/*****************************************************************************************/	
	%carry_over_nongroup_prem_factor;
	/******************************************************************************************
	/	Merge the processed non-dependent children data onto the HIU-level data
	/*****************************************************************************************/
	data tempx.hiu_size_0 
		 tempx.hiu_size_1 
		 tempx.hiu_size_2p;
		merge tempx.hiu_file_FOR_U_calc_sim  				(in=a)
		      tempx.ID_nondep_kids_heldconst_HIU 		    (in=b);
		by old_h_seq hiu_id;
		if a;
		/************************************************************************************** 
		/	Set individual-specific variable arrays for HIUs (not including those whose coverage types
		/	are held constant
		/*************************************************************************************/
		%Set_Arrays(firm_arrays = no, hiu_arrays = yes);
		/************************************************************************************** 
		/	Declare individual-specific arrays of those whose coverage types are held
		/	constant (i.e., "var name"_M)
		/*************************************************************************************/
		array care_M     		{&DIM.} care_1			-	care_&DIM.;
		array dual_M     		{&DIM.} dual_1			-	dual_&DIM.;
		array caid_M     		{&DIM.} caid_1			-	caid_&DIM.;
		array champ_M    		{&DIM.} champ_1			-	champ_&DIM.;
		array other_M    		{&DIM.} other_1			-	other_&DIM.;
		array esi_ph_s_M 		{&DIM.} esi_ph_s_1		-	esi_ph_s_&DIM.;
		array esi_ph_f_M 		{&DIM.} esi_ph_f_1		-	esi_ph_f_&DIM.;
		array esi_dep_M  		{&DIM.} esi_dep_1		-	esi_dep_&DIM.;
		array offmarket_ph_s_M  {&DIM.} offmarket_ph_s_1-	offmarket_ph_s_&DIM.;
		array offmarket_ph_f_M  {&DIM.} offmarket_ph_f_1-	offmarket_ph_f_&DIM.;
		array offmarket_dep_M   {&DIM.} offmarket_dep_1	-	offmarket_dep_&DIM.;
		array chip_M     		{&DIM.} chip_1			-	chip_&DIM.;
		array unin_M     		{&DIM.} unin_1			-	unin_&DIM.;
				
		/************************************************************************************** 
		/	Declare an array of person IDs for those whose coverage types are held constant
		/*************************************************************************************/
		array pid_heldconst {&DIM_HC.} pid_heldconst_1 - pid_heldconst_&DIM_HC.;
		/************************************************************************************** 
		/	Set the variables to missing values for non-dependent children whose coverage types
		/	are held constant
		/*************************************************************************************/
		%ignore_nondep_children_constant;
		/************************************************************************************** 
		/	Truncate HIU income to avoid problems caused by exponentiating large utility values
		/*************************************************************************************/
		hiuinc = min(DISP_INC,500000);
		/************************************************************************************** 
		/	Create primary marketplace units within each HIU       
		/			(difference between a primary marketplace unit and an HIU is in non-dependent children, see notes below)
		/	Notes: (1) People in the primary marketplace unit (i.e. those not non-dependent children)
		/				will have "market_ID_primary=1", and non-dependent children will have "market_ID_primary>1".
		/		   (2) Non-dependent children appear in two separate rows, 
        /             (i) one for the case where those children are covered by ESI family plan (in multi-person HIUs), and 
        /             (ii) the other for the case where those children are their own marketplace unit (in single-person HIUs)  
        /       	The non-dependent children will be allowed to make decisions in the single-person HIU world 
        /           with their weights deflated by 1-(Probability of being on ESI family plan).
		/*************************************************************************************/		
		
		array market_ID_primary {&DIM.} market_ID_primary_1-market_ID_primary_&DIM.;

		do i=1 to &DIM.;
			if age[i] ne . then market_ID_primary[i] = 0;
			else market_ID_primary[i] = .;
		end;

		CNT=0;
		do j=1 to &DIM.;
			if age[j] ne . and market_ID_primary[j] = 0 then do;
				CNT+1;
				do i=j to &DIM.;
					if market_ID[i] = market_ID[j] then do;
					   market_ID_primary[i] = CNT;
					end;
				end;
			end;
		end;
		/************************************************************************************** 
		/	Re-calculate HIU sizes
		/*************************************************************************************/
		HIU_size_primary		= 0;
		HIU_size_full			= 0;
		do i=1 to &DIM.;
			if wgt[i]>0 and market_ID_primary[i]=1	then HIU_size_primary		= sum(HIU_size_primary,1);
			if wgt[i]>0 							then HIU_size_full			= sum(HIU_size_full,1);
		end;
		if HIU_size_primary    in(0,.) 	then HIU_size_primary	= 0;
		if HIU_size_full in(0,.) 		then HIU_size_full 		= 0;
		/************************************************************************************** 
		/	Create income variables for the heads of HIUs whose coverage types were not held constant
		/  (such as their modified adjustable gross income (MAGI),
		/			MAGI as a share of federal poverty level, and 
		/			the income variables needed to calculate the self-employed health insurance
		/			tax deduction) 
		/*************************************************************************************/				
		MTR_selfemp_deduct = 0;
		CAP_selfemp_deduct = 0;
		do i=1 to &DIM.;
			if age[i] ne . and market_ID_primary[i]=1 and mem_type_array[i] in(1,2) then do; 
				FPL				= MAGI_pov[i];
				FPL&base_year.	= MAGI_pov_&base_year.[i];
				MAGI_income		= MAGIinc[i] ;
			end;
			if mem_type_array[i] in(1,2) then do;
				MTR_selfemp_deduct = MTRinc[i]/100;
				CAP_selfemp_deduct = SE_DED[i];
			end;
		end;

		/************************************************************************************** 
		/	Calculate post-tax premiums of ESI plans (Employees' and Employers' contributions)
		/*************************************************************************************/
		do i=1 to &DIM.;
 			if offer_single_sim_array[i]=1 then do;
  				%calc_post_tax_ESI_prem;
 			end;
		end;
		/************************************************************************************** 
		/	Flag the individuals who are eligible for Public Insurance
		/*************************************************************************************/
		%if &Caid_Expand.=yes %then %do;
			%if &Marketplace_Exists.=yes %then %do;
				%set_up_public_insurance_elig;
			%end;
		%end;
		
		/************************************************************************************** 
		/	Count the number of people eligible for Medicaid or CHIP in the HIU and
		/	Check whether HIU can choose the alternative of ESI plan with public insurance (N_eligible < N_total)
		/*************************************************************************************/		
		N_medicaid_CHIP_elig = sum(0,sum(of medicaid_CHIP_elig[*]));
		if 0 < N_medicaid_CHIP_elig < HIU_size_primary then 	split_decision_hiu = 1;
		else 													split_decision_hiu = 0;
		/************************************************************************************** 
		/	Create variables related to non-group (in and outside the marketplace) 
		/*************************************************************************************/
		%if &Marketplace_Exists.=yes %then %do;
			%set_up_nongroup_markets;
		%end;
		/****************************************************************************************** 
		/	Adjust the cost-sharing reduction value
		/*****************************************************************************************/
		%adjust_csr_value;

		/************************************************************************************** 
		/	Flag the individuals who are subject to individual mandate
		/*************************************************************************************/
		%if &IM_exists.=yes %then %do;
			%set_up_individual_mandate;		
		%end;
		%if &IM_exists.=no	%then %do;
			do i=1 to &DIM.;
				subj_IM[i]=0;
			end;
		%end;
		
		/************************************************************************************** 
		/	Set the HIU-level utility shifters for simulation
		/	Note: The shifters can be set to zeros, 
		/		  the values calibrated in the calibration routine, 
		/		  or the processed calibrated values for simulation   
		/*************************************************************************************/		
		%set_U_params_hiu1(set_0  = no,	set_calib = no,	set_input_sheet = yes);
		%set_U_params_hiu2p(set_0 = no,	set_calib = no, set_input_sheet = yes);
		/*************************************************************************************
		/	Output three distinct datasets for different types of HIUs. See the header for details. 									
		/		HIUs in which all members' coverage types were held constant ("hiu_size_0"),						
		/	   	Single-person HIUs ("hiu_size_1"), and  
		/		Multi-person HIUs ("hiu_size_2p").
		/*************************************************************************************/	
		if		HIU_size_full = 0 then output tempx.hiu_size_0;
		else if HIU_size_full = 1 then output tempx.hiu_size_1;
		else if HIU_size_full > 1 then output tempx.hiu_size_2p;
	run;

%mend prep_for_simulated_hiu_file;
