
/*=============================================================================================
/	Module Name	: simulate_HIUs_cvrg_held_const.sas
/	Purpose		: To calculate the number of people by coverage types 
/					for the HIUs in which all members' coverage types were held constant
/				  For details about people whose coverage types were held constant, see 
/				  Jessica Banthin and others, Sources and Preparation of Data Used in HISIM2CBOs
/				  Health Insurance Simulation Model, Working Paper 2019-04 (Congressional Budget
/				  Office, April 2019), www.cbo.gov/publication/55087.						
/	Inputs		: Data file "hiu_size_0" from prep_for_simulated_hiu_file.sas
/	Outputs		: Data file "apply_model_base_hiu0" containing the number of people by coverage type 
/				  	for the HIUs in which all members' coverage types were held constant
/	The code is written in SAS, version 9.4.
/============================================================================================*/

%macro simulate_HIUs_cvrg_held_const;

data tempx.apply_model_base_hiu0;
	set tempx.hiu_size_0;

	/******************************************************************************************
	/	Declare arrays of variables (not including people held constant)
	/*****************************************************************************************/
	%Set_Arrays(firm_arrays=no,hiu_arrays=yes);

	/******************************************************************************************
	/	Declare arrays of variables for people held constant
	/*****************************************************************************************/
	array care_M     		{&DIM.} care_1			-	care_&DIM.;
	array dual_M     		{&DIM.} dual_1			-	dual_&DIM.;
	array caid_M     		{&DIM.} caid_1			-	caid_&DIM.;
	array champ_M    		{&DIM.} champ_1			-	champ_&DIM.;
	array other_M    		{&DIM.} other_1			-	other_&DIM.;
	array esi_ph_s_M 		{&DIM.} esi_ph_s_1		-	esi_ph_s_&DIM.;
	array esi_ph_f_M 		{&DIM.} esi_ph_f_1		-	esi_ph_f_&DIM.;
	array esi_dep_M  		{&DIM.} esi_dep_1		-	esi_dep_&DIM.;
	array offmarket_ph_s_M  {&DIM.} offmarket_ph_s_1-	offmarket_ph_s_&DIM.;
	array offmarket_ph_f_M  {&DIM.} offmarket_ph_f_1-	offmarket_ph_f_&DIM.;
	array offmarket_dep_M   {&DIM.} offmarket_dep_1	-	offmarket_dep_&DIM.;
	array chip_M     		{&DIM.} chip_1			-	chip_&DIM.;
	array unin_M     		{&DIM.} unin_1			-	unin_&DIM.;

	/******************************************************************************************
	/	Declare arrays of the primary marketplace unit variable
	/*****************************************************************************************/
	array market_ID_primary {&DIM.} market_ID_primary_1-market_ID_primary_&DIM.;

	/******************************************************************************************
	/	Calculate the number of people whose coverage types are held constant
	/*****************************************************************************************/
	cvrg_medicare_heldconst    	= sum(of care_M[*]);
	cvrg_dual_heldconst 		= sum(of dual_M[*]);  
	cvrg_medicaid_heldconst	  	= sum(sum(of caid_M[*]));
	cvrg_military_heldconst		= sum(of champ_M[*]); 
	cvrg_other_heldconst  		= sum(of other_M[*]); 
	cvrg_ESI_S_heldconst		= sum(of esi_ph_s_M[*]); 
	cvrg_ESI_F_heldconst  		= sum(sum(of esi_ph_f_M[*]),sum(of esi_dep_M[*])); 
	cvrg_offmarket_S_heldconst  = sum(of offmarket_ph_s_M[*]);
	cvrg_offmarket_F_heldconst  = sum(sum(of offmarket_ph_f_M[*]),sum(of offmarket_dep_M[*]));
	cvrg_chip_heldconst	  		= sum(sum(of chip_M[*]));
	cvrg_unins_heldconst	  	= sum(sum(of unin_M[*]));
run;

%mend simulate_HIUs_cvrg_held_const;
