/*=============================================================================================
/	Module Name	: simulate_multi_person_HIUs.sas
/	Purpose		: To calculate the probability of choosing each available alternative for multi-person HIUs and		
/				     calculate the enrollment by coverage type
/	Inputs		: Data file "hiu_size_2p" from prep_for_simulated_hiu_file.sas
/	Outputs		: Data file "apply_model_base_hiu2p" containing simulated HIUs' choices at the HIU-level for multi-person HIUs  
/	Summary		: 
/	(1) Calculate the probability of choosing each available alternative
/		(1-a) Calculate HIU's utility from choosing each available alternative
/		(1-b) Calculate HIU's probability of choosing each alternative 
/			  (Refer to Section 4.4.2. in Train 2009 for the probability formula )  			
/	(2) Calculate policy-related variables: (e.g., individual mandate penalty, premium tax
/		credits, excise tax, cost-sharing reduction payment)
/		Notes:  For multi-person HIUs, the calculations of probabilities of choosing alternatives 
/				are based on the Generalized Nested Logit (GNL) model and 
/				the utility from choosing an alternative is defined in the slide deck. 
/			For the functional form of the probabilities in GNL model, refer to 
/				Kenneth Train, "Discrete Choice Methods with Simulation", Cambridge University Press
/				Second edition, 2009.
/				Chieh-Hua Wen and Frank S. Koppelman, "The generalized nested logit model", 
/				Transportation Research Part B: Methodological, vol. 35, no. 7 (August 2001), pp. 627-641.		
/ 			For the utility function, see Congressional Budget Office, HISIM2The Health Insurance
/				Simulation Model Used in Preparing CBOs Spring 2019 Baseline Budget Projections   
/				(April 2019), www.cbo.gov/publication/55097.
/	The code is written in SAS, version 9.4.
/============================================================================================*/

%macro simulate_multi_person_HIUs;

data 	tempx.apply_model_base_hiu2p;
	set tempx.hiu_size_2p;

	/******************************************************************************************
	/	Calculate utilities to calculate probabilities
	/*****************************************************************************************/

		/**************************************************************************************
		/	Declare arrays of variables (not including people held constant)
		/*************************************************************************************/
		%Set_Arrays(firm_arrays=no,hiu_arrays=yes);

		/**************************************************************************************
		/	Declare arrays of variables for people held constant (i.e., var_M)
		/*************************************************************************************/
		array care_M     		{&DIM.} care_1			-	care_&DIM.;
		array dual_M     		{&DIM.} dual_1			-	dual_&DIM.;
		array caid_M     		{&DIM.} caid_1			-	caid_&DIM.;
		array champ_M    		{&DIM.} champ_1			-	champ_&DIM.;
		array other_M    		{&DIM.} other_1			-	other_&DIM.;
		array esi_ph_s_M 		{&DIM.} esi_ph_s_1		-	esi_ph_s_&DIM.;
		array esi_ph_f_M 		{&DIM.} esi_ph_f_1		-	esi_ph_f_&DIM.;
		array esi_dep_M  		{&DIM.} esi_dep_1		-	esi_dep_&DIM.;
		array offmarket_ph_s_M  {&DIM.} offmarket_ph_s_1-	offmarket_ph_s_&DIM.;
		array offmarket_ph_f_M  {&DIM.} offmarket_ph_f_1-	offmarket_ph_f_&DIM.;
		array offmarket_dep_M   {&DIM.} offmarket_dep_1	-	offmarket_dep_&DIM.;
		array chip_M     		{&DIM.} chip_1			-	chip_&DIM.;
		array unin_M     		{&DIM.} unin_1			-	unin_&DIM.;

		/**************************************************************************************
		/	Declare arrays of the primary marketplace unit variable
		/	Note: If one's market_ID_primary is 1, that person is in the primary marketplace unit,
		/		  (i.e. that person is not a non-dependent child).
		/		  If one's market_ID_primary is greater than 1, that person is a non-dependent child 
		/*************************************************************************************/
		array market_ID_primary {&DIM.} market_ID_primary_1-market_ID_primary_&DIM.;

		/**************************************************************************************
		/	Initialize arrays to zero
		/*************************************************************************************/
		%initialize_array_0;

		/**************************************************************************************
		/	Define person index (p_index) for those with ESI offers in an HIU
		/	Note: An HIU can get at most 3 single ESI offers.
		/		  We assume that HIU heads with a single ESI offer also have a family ESI offer. 
		/		  offer_single_sim_array[i] is an individual-specific array showing whether an
		/		  individual i has an ESI single offer from simulation
		/*************************************************************************************/
		array p_index {3} i_1 i_2 i_3;
	  	c = 0;
	  	do i = 1 to &DIM.;
	   		if offer_single_sim_array[i] = 1 then do; 			
        		c = c+1;
	    		p_index[c] = i;
	   		end;
	  	end;

		/**************************************************************************************
		/	Calculate the utilities from choosing the alternatives of non-group plans (in and
		/	outside the marketplace)
		/*************************************************************************************/
	 	%if &Marketplace_Exists.=yes %then %do;					
	  		%calc_U_nongroup_hiu2p(firm_u=no,hiu_u=yes);
	 	%end;

		/**************************************************************************************
		/	Calculate the utilities from choosing the alternatives of ESI plans
		/*************************************************************************************/
			/**********************************************************************************
			/	ESI family plan: all HIU members are on the ESI family plan
			/*********************************************************************************/
		 	%calc_U_ESI_F_hiu2p(1,firm_u=no,hiu_u=yes);
		 	%calc_U_ESI_F_hiu2p(2,firm_u=no,hiu_u=yes);
			
			/**********************************************************************************
			/	ESI family plan with public insurance: Of people who do not take up the ESI plan, 
			/	those who are eligible for public insurance enroll in the public insurance 
			/*********************************************************************************/			
		 	%calc_U_ESI_Fpo_hiu2p(1,firm_u=no,hiu_u=yes);
		 	%calc_U_ESI_Fpo_hiu2p(2,firm_u=no,hiu_u=yes);
			
			/**********************************************************************************
			/	ESI family plan with Medicaid double coverage for children: all children on ESI family plan who
			/	are eligible for Medicaid enroll in both ESI family plan and Medicaid
			/*********************************************************************************/			
		 	%calc_U_ESI_FpCD_hiu2p(1,firm_u=no,hiu_u=yes);
		 	%calc_U_ESI_FpCD_hiu2p(2,firm_u=no,hiu_u=yes);
			
			/**********************************************************************************
			/	ESI single plan with the rest being uninsured: 
			/	People who choose to take up their ESI single offer have ESI single coverage 
			/	and the rest are uninsured
			/*********************************************************************************/		
		 	%calc_U_ESI_S_hiu2p(firm_u=no,hiu_u=yes);
			
			/**********************************************************************************
			/	ESI single plan with public insurance and the rest being uninsured: 
			/	People who choose to take up their ESI single offer have ESI single coverage.
			/	Of people who do not take up the ESI offer, those who are eligible for public insurance enroll in it,
			/	and the rest are uninsured
			/*********************************************************************************/			
		 	%calc_U_ESI_Spo_hiu2p(firm_u=no,hiu_u=yes);

		/**************************************************************************************
		/	Calculate the utilities from choosing the alternatives of Public Insurance
		/		for those who are eligible
		/*************************************************************************************/
	 	%calc_U_public_hiu2p(firm_u=no,hiu_u=yes);  

		/**************************************************************************************
		/	Calculate the utilities from choosing to be uninsured
		/*************************************************************************************/
	 	%calc_U_uninsured_hiu2p(firm_u=no,hiu_u=yes);

	/******************************************************************************************
	/	Calculate the choice probabilities using utilities calculated above
	/	Note:	Probabilities in GNL model consist of the exponential functions of HIU's
	/			utilities, the allocation parameters (or alpha's), and the dissimilarity
	/			parameters (or mu's)
	/*****************************************************************************************/

		/**************************************************************************************
		/	Exponentiate utilities to prepare for probability calculations
		/*************************************************************************************/
		%macro exp_f(utility);
			/**********************************************************************************
			/	Calculate predicted value of a specified alternative if utility				
			/			for the alternative was defined. 
			/			(If the utility value of an HIU for a given alternative is missing, 
			/			HIU is not eligible for that alternative.)  
 			/	Note: 	709 is the largest number that can be exponentiated. 
			/			None actually hit the cap in the model
			/*********************************************************************************/		
			if U_&utility. ne . then do;
				if		(beta_hiu2p*U_&utility./&DIV_HIU2p.)<  709	then exp_U_&utility.=exp(beta_hiu2p*U_&utility./&DIV_HIU2p.);
				else if (beta_hiu2p*U_&utility./&DIV_HIU2p.)>= 709  then exp_U_&utility.=exp(709);
			end;
		%mend exp_f;
		%if &Marketplace_Exists.=yes %then %do;
			%exp_f(onB_F);		%exp_f(onS_F);		%exp_f(onG_F);
			%exp_f(offB_F);		%exp_f(offS_F);		%exp_f(offG_F);
		%end;
		%exp_f(ESI_F_1);		%exp_f(ESI_F_2);
		%exp_f(ESI_Fpo_1);		%exp_f(ESI_Fpo_2);
		%exp_f(ESI_FpCD_1);		%exp_f(ESI_FpCD_2);
		%exp_f(ESI_S_1_1);
		%exp_f(ESI_S_2_1);		%exp_f(ESI_S_2_2);		%exp_f(ESI_S_2_12);
		%exp_f(ESI_S_3_1);		%exp_f(ESI_S_3_2);		%exp_f(ESI_S_3_3);
		%exp_f(ESI_S_3_12);		%exp_f(ESI_S_3_13);		%exp_f(ESI_S_3_23);		%exp_f(ESI_S_3_123);
		%exp_f(ESI_Spo_1_1);
		%exp_f(ESI_Spo_2_1);	%exp_f(ESI_Spo_2_2);	%exp_f(ESI_Spo_2_12);
		%exp_f(ESI_Spo_3_1);	%exp_f(ESI_Spo_3_2);	%exp_f(ESI_Spo_3_3);
		%exp_f(ESI_Spo_3_12);	%exp_f(ESI_Spo_3_13);	%exp_f(ESI_Spo_3_23);	%exp_f(ESI_Spo_3_123);
		%exp_f(public_HIU2p);
		%exp_f(UN);

		/**************************************************************************************
		/	Create the variables needed to calculate the probability of being in the ESI nest
		/*************************************************************************************/

			/**************************************************************************************
			/	Read in allocation parameters related to ESI 
			/*************************************************************************************/
		 	alpha_esi1 = 1;  						/* ESI family */
		 	alpha_esi2 = &alpha_ESI_Fpo_ESI.;		/* ESI family with Public Insurance */
		 	alpha_esi3 = &alpha_ESI_FpCD_ESI.;		/* ESI family with Medicaid double coverage for children  */
		 	alpha_esi4 = &alpha_ESI_S_ESI.;			/* ESI single with the rest being uninsured */
		 	alpha_esi5 = &alpha_ESI_Spo_ESI.;		/* ESI single with Public Insurance and the rest being uninsured */

			/**************************************************************************************
			/	Read in the dissimilarity parameter for the ESI nest
			/*************************************************************************************/
		 	mu_esi     = &mu_esi.;					

			/**************************************************************************************
			/	Calculate the components of the ESI nest probability
			/*************************************************************************************/

			/* ESI family */
		 	exp_U_ESI_F_1_NstESI		=	(	exp_U_ESI_F_1		*	alpha_esi1	)	**	(1/mu_esi);
		 	exp_U_ESI_F_2_NstESI		=	(	exp_U_ESI_F_2		*	alpha_esi1	)	**	(1/mu_esi);
			/* ESI family with Public Insurance */
		 	exp_U_ESI_Fpo_1_NstESI		=	(	exp_U_ESI_Fpo_1		*	alpha_esi2	)	**	(1/mu_esi);
		 	exp_U_ESI_Fpo_2_NstESI		=	(	exp_U_ESI_Fpo_2		*	alpha_esi2	)	**	(1/mu_esi);
			/* ESI family with Medicaid double coverage for children */
		 	exp_U_ESI_FpCD_1_NstESI		=	(	exp_U_ESI_FpCD_1	*	alpha_esi3	)	**	(1/mu_esi);
		 	exp_U_ESI_FpCD_2_NstESI		=	(	exp_U_ESI_FpCD_2	*	alpha_esi3	)	**	(1/mu_esi);
			/* ESI single (rest uninsured) */
		 	exp_U_ESI_S_1_1_NstESI		=	(	exp_U_ESI_S_1_1		*	alpha_esi4	)	**	(1/mu_esi);
		 	exp_U_ESI_S_2_1_NstESI		=	(	exp_U_ESI_S_2_1		*	alpha_esi4	)	**	(1/mu_esi);
		 	exp_U_ESI_S_2_2_NstESI		=	(	exp_U_ESI_S_2_2		*	alpha_esi4	)	**	(1/mu_esi);
		 	exp_U_ESI_S_2_12_NstESI		=	(	exp_U_ESI_S_2_12	*	alpha_esi4	)	**	(1/mu_esi);
		 	exp_U_ESI_S_3_1_NstESI		=	(	exp_U_ESI_S_3_1		*	alpha_esi4	)	**	(1/mu_esi);
		 	exp_U_ESI_S_3_2_NstESI		=	(	exp_U_ESI_S_3_2		*	alpha_esi4	)	**	(1/mu_esi);
		 	exp_U_ESI_S_3_3_NstESI		=	(	exp_U_ESI_S_3_3		*	alpha_esi4	)	**	(1/mu_esi);
		 	exp_U_ESI_S_3_12_NstESI		=	(	exp_U_ESI_S_3_12	*	alpha_esi4	)	**	(1/mu_esi);
		 	exp_U_ESI_S_3_13_NstESI		=	(	exp_U_ESI_S_3_13	*	alpha_esi4	)	**	(1/mu_esi);
		 	exp_U_ESI_S_3_23_NstESI		=	(	exp_U_ESI_S_3_23	*	alpha_esi4	)	**	(1/mu_esi);
		 	exp_U_ESI_S_3_123_NstESI	=	(	exp_U_ESI_S_3_123	*	alpha_esi4	)	**	(1/mu_esi);
			/* ESI single with Public insurance (rest uninsured) */
		 	exp_U_ESI_Spo_1_1_NstESI	=	(	exp_U_ESI_Spo_1_1	*	alpha_esi5	)	**	(1/mu_esi);
		 	exp_U_ESI_Spo_2_1_NstESI	=	(	exp_U_ESI_Spo_2_1	*	alpha_esi5	)	**	(1/mu_esi);
		 	exp_U_ESI_Spo_2_2_NstESI	=	(	exp_U_ESI_Spo_2_2	*	alpha_esi5	)	**	(1/mu_esi);
		 	exp_U_ESI_Spo_2_12_NstESI	=	(	exp_U_ESI_Spo_2_12	*	alpha_esi5	)	**	(1/mu_esi);
		 	exp_U_ESI_Spo_3_1_NstESI	=	(	exp_U_ESI_Spo_3_1	*	alpha_esi5	)	**	(1/mu_esi);
		 	exp_U_ESI_Spo_3_2_NstESI	=	(	exp_U_ESI_Spo_3_2	*	alpha_esi5	)	**	(1/mu_esi);
		 	exp_U_ESI_Spo_3_3_NstESI	=	(	exp_U_ESI_Spo_3_3	*	alpha_esi5	)	**	(1/mu_esi);
		 	exp_U_ESI_Spo_3_12_NstESI	=	(	exp_U_ESI_Spo_3_12	*	alpha_esi5	)	**	(1/mu_esi);
		 	exp_U_ESI_Spo_3_13_NstESI	=	(	exp_U_ESI_Spo_3_13	*	alpha_esi5	)	**	(1/mu_esi);
		 	exp_U_ESI_Spo_3_23_NstESI	=	(	exp_U_ESI_Spo_3_23	*	alpha_esi5	)	**	(1/mu_esi);
		 	exp_U_ESI_Spo_3_123_NstESI	=	(	exp_U_ESI_Spo_3_123	*	alpha_esi5	)	**	(1/mu_esi);
			
		 	sum_Nst_ESI = sum( 	/* ESI family */
									exp_U_ESI_F_1_NstESI,exp_U_ESI_F_2_NstESI,
								/* ESI family with Public Insurance */
									exp_U_ESI_Fpo_1_NstESI,exp_U_ESI_Fpo_2_NstESI,
								/* ESI family with Medicaid double coverage for children */
									exp_U_ESI_FpCD_1_NstESI,exp_U_ESI_FpCD_2_NstESI,
								/* ESI single (rest uninsured) */
									exp_U_ESI_S_1_1_NstESI,exp_U_ESI_S_2_1_NstESI,exp_U_ESI_S_2_2_NstESI,exp_U_ESI_S_2_12_NstESI,exp_U_ESI_S_3_1_NstESI,exp_U_ESI_S_3_2_NstESI,
									exp_U_ESI_S_3_3_NstESI,exp_U_ESI_S_3_12_NstESI,exp_U_ESI_S_3_13_NstESI,exp_U_ESI_S_3_23_NstESI,exp_U_ESI_S_3_123_NstESI,
								/* ESI single with Public insurance (rest uninsured) */
									exp_U_ESI_Spo_1_1_NstESI,exp_U_ESI_Spo_2_1_NstESI,exp_U_ESI_Spo_2_2_NstESI,exp_U_ESI_Spo_2_12_NstESI,exp_U_ESI_Spo_3_1_NstESI,exp_U_ESI_Spo_3_2_NstESI,
									exp_U_ESI_Spo_3_3_NstESI,exp_U_ESI_Spo_3_12_NstESI,exp_U_ESI_Spo_3_13_NstESI,exp_U_ESI_Spo_3_23_NstESI,exp_U_ESI_Spo_3_123_NstESI);

		/**************************************************************************************
		/	Create variables needed to calculate the probability of being in the nest of
		/	non-group in the marketplaces
		/*************************************************************************************/

			/**************************************************************************************
			/	Read in allocation parameters related to non-group in the marketplaces
			/*************************************************************************************/
		 	alpha_onmarket=&alpha_onmarket_onmarket.;

			/**************************************************************************************
			/	Read in the dissimilarity parameter for the nest of non-group in the marketplaces
			/*************************************************************************************/
		 	mu_onmarket    =&mu_onmarket.;

			/**************************************************************************************
			/	Calculate the components of the probability of being in the nest of non-group in the
			/	marketplaces
			/*************************************************************************************/
			%if &Marketplace_Exists.=yes %then %do;
		 		exp_U_B_F_Nst_onmarket	= (exp_U_onB_F*alpha_onmarket)**(1/mu_onmarket);
		 		exp_U_S_F_Nst_onmarket	= (exp_U_onS_F*alpha_onmarket)**(1/mu_onmarket);
		 		exp_U_G_F_Nst_onmarket	= (exp_U_onG_F*alpha_onmarket)**(1/mu_onmarket);

		 		sum_Nst_onmarket = sum(exp_U_B_F_Nst_onmarket,exp_U_S_F_Nst_onmarket,exp_U_G_F_Nst_onmarket);
			%end;

		/**************************************************************************************
		/	Create variables needed to calculate the probability of being in the nest of
		/	non-group outside the marketplaces
		/*************************************************************************************/

			/**************************************************************************************
			/	Read in allocation parameters related to the nest of non-group outside the marketplace
			/	Note: The way coverage types within an HIU are allocated 
			/         into different nests (i.e. Nongroup, Public Insurance and Uninsured) 
            /         for the alternatives associated with the nest of nongroup outside the marketplaces 
            /         is assumed to be the same as the way coverage types are allocated into different nests 
            /         for the alternatives associated with the nest of nongroup in marketplaces. 
            /         That is, if an HIU chooses such alternatives, any people eligible for public insurance 
            /         take up public insurance and people not lawfully present are uninsured.
			/*************************************************************************************/		
		 	alpha_offmarket	=&alpha_onmarket_onmarket.;

			/**************************************************************************************
			/	Read in the dissimilarity parameter for the nest of non-group outside the marketplace
			/*************************************************************************************/
		 	mu_offmarket    =&mu_offmarket.;

			/**************************************************************************************
			/	Calculate components of the probability of being in the nest of non-group outside 
			/	the marketplace
			/*************************************************************************************/
			%if &Marketplace_Exists.=yes %then %do;
		 		exp_U_B_F_Nst_offmarket	= (exp_U_offB_F*alpha_offmarket)**(1/mu_offmarket);
		 		exp_U_S_F_Nst_offmarket	= (exp_U_offS_F*alpha_offmarket)**(1/mu_offmarket);
		 		exp_U_G_F_Nst_offmarket	= (exp_U_offG_F*alpha_offmarket)**(1/mu_offmarket);

		 		sum_Nst_offmarket = sum(exp_U_B_F_Nst_offmarket,exp_U_S_F_Nst_offmarket,exp_U_G_F_Nst_offmarket);
			%end;

		/**************************************************************************************
		/	Create variables needed to calculate the probability of being in the nest of
		/	public insurance
		/*************************************************************************************/

			/**************************************************************************************
			/	Read in allocation parameters related to public insurance
			/*************************************************************************************/
		 	alpha_public1=&alpha_public_public.;  		/* Public Insurance (rest uninsured) */	
		 	alpha_public2=&alpha_onmarket_F_public.; 	/* Nongroup with Public Insurance */
		 	alpha_public3=&alpha_ESI_Fpo_public.;  		/* ESI family with Public Insurance */
		 	alpha_public4=&alpha_ESI_FpCD_public.;  	/* ESI family with Medicaid double coverage for children */
		 	alpha_public5=&alpha_ESI_Spo_public.; 		/* ESI single with Public Insurance and the rest being uninsured */

			/**************************************************************************************
			/	Read in the dissimilarity parameter for the nest of public insurance
			/*************************************************************************************/
		 	mu_public    =&mu_public.;					

			/**************************************************************************************
			/	Calculate the components of the probability of being in the nest of public insurance
			/*************************************************************************************/
		 	exp_U_public_Nst_public					=	(	exp_U_public_HIU2p		*	alpha_public1	)	**	(1/mu_public);

			%if &Marketplace_Exists.=yes %then %do;
			 	exp_U_B_onmarket_Nst_public			=	(	exp_U_onB_F			*	alpha_public2	)	**	(1/mu_public);
			 	exp_U_S_onmarket_Nst_public			=	(	exp_U_onS_F			*	alpha_public2	)	**	(1/mu_public);
			 	exp_U_G_onmarket_Nst_public			=	(	exp_U_onG_F			*	alpha_public2	)	**	(1/mu_public);
			
			 	exp_U_B_offmarket_Nst_public		=	(	exp_U_offB_F		*	alpha_public2	)	**	(1/mu_public);
			 	exp_U_S_offmarket_Nst_public		=	(	exp_U_offS_F		*	alpha_public2	)	**	(1/mu_public);
			 	exp_U_G_offmarket_Nst_public		=	(	exp_U_offG_F		*	alpha_public2	)	**	(1/mu_public);
			%end;

		 	exp_U_ESI_Fpo_1_Nst_public				=	(	exp_U_ESI_Fpo_1		*	alpha_public3	)	**	(1/mu_public);
		 	exp_U_ESI_Fpo_2_Nst_public				=	(	exp_U_ESI_Fpo_2		*	alpha_public3	)	**	(1/mu_public);

		 	exp_U_ESI_FpCD_1_Nst_public				=	(	exp_U_ESI_FpCD_1	*	alpha_public4	)	**	(1/mu_public);
		 	exp_U_ESI_FpCD_2_Nst_public				=	(	exp_U_ESI_FpCD_2	*	alpha_public4	)	**	(1/mu_public);

		 	exp_U_ESI_Spo_1_1_Nst_public			=	(	exp_U_ESI_Spo_1_1	*	alpha_public5	)	**	(1/mu_public);
		 	exp_U_ESI_Spo_2_1_Nst_public			=	(	exp_U_ESI_Spo_2_1	*	alpha_public5	)	**	(1/mu_public);
		 	exp_U_ESI_Spo_2_2_Nst_public			=	(	exp_U_ESI_Spo_2_2	*	alpha_public5	)	**	(1/mu_public);
		 	exp_U_ESI_Spo_2_12_Nst_public			=	(	exp_U_ESI_Spo_2_12	*	alpha_public5	)	**	(1/mu_public);
		 	exp_U_ESI_Spo_3_1_Nst_public			=	(	exp_U_ESI_Spo_3_1	*	alpha_public5	)	**	(1/mu_public);
		 	exp_U_ESI_Spo_3_2_Nst_public			=	(	exp_U_ESI_Spo_3_2	*	alpha_public5	)	**	(1/mu_public);
		 	exp_U_ESI_Spo_3_3_Nst_public			=	(	exp_U_ESI_Spo_3_3	*	alpha_public5	)	**	(1/mu_public);
		 	exp_U_ESI_Spo_3_12_Nst_public			=	(	exp_U_ESI_Spo_3_12	*	alpha_public5	)	**	(1/mu_public);
		 	exp_U_ESI_Spo_3_13_Nst_public			=	(	exp_U_ESI_Spo_3_13	*	alpha_public5	)	**	(1/mu_public);
		 	exp_U_ESI_Spo_3_23_Nst_public			=	(	exp_U_ESI_Spo_3_23	*	alpha_public5	)	**	(1/mu_public);
		 	exp_U_ESI_Spo_3_123_Nst_public			=	(	exp_U_ESI_Spo_3_123	*	alpha_public5	)	**	(1/mu_public);

			%if &Marketplace_Exists.=yes %then %do;
		 		sum_Nst_public =sum(/* Public Insurance (rest uninsured) */
		 							exp_U_public_Nst_public,
									/* Nongroup in the marketplaces with Public Insurance *//
									exp_U_B_onmarket_Nst_public,	exp_U_S_onmarket_Nst_public,	exp_U_G_onmarket_Nst_public,
									/* Nongroup outside the marketplaces with Public Insurance */
									exp_U_B_offmarket_Nst_public,	exp_U_S_offmarket_Nst_public,	exp_U_G_offmarket_Nst_public,
									/* ESI family with Public Insurance */
									exp_U_ESI_Fpo_1_Nst_public,exp_U_ESI_Fpo_2_Nst_public,
									/* ESI family with Medicaid double coverage for children */
									exp_U_ESI_FpCD_1_Nst_public,exp_U_ESI_FpCD_2_Nst_public,
									/* ESI single with Public Insurance and the rest being uninsured  */
									exp_U_ESI_Spo_1_1_Nst_public,exp_U_ESI_Spo_2_1_Nst_public,exp_U_ESI_Spo_2_2_Nst_public,exp_U_ESI_Spo_2_12_Nst_public,exp_U_ESI_Spo_3_1_Nst_public,exp_U_ESI_Spo_3_2_Nst_public,
									exp_U_ESI_Spo_3_3_Nst_public,exp_U_ESI_Spo_3_12_Nst_public,exp_U_ESI_Spo_3_13_Nst_public,exp_U_ESI_Spo_3_23_Nst_public,exp_U_ESI_Spo_3_123_Nst_public);
			%end;

		/**************************************************************************************
		/	Create variables needed to calculate the probability of being in the uninsured nest 
		/*************************************************************************************/

			/**************************************************************************************
			/	Read in allocation parameters related to the uninsured nest
			/*************************************************************************************/			
		 	alpha_uninsured1=&alpha_onmarket_F_UN.;		/* Non-group in marketplaces */				
		 	alpha_uninsured2=&alpha_ESI_S_UN.; 			/* ESI single with the rest being uninsured */
		 	alpha_uninsured3=&alpha_ESI_Spo_UN.;		/* ESI single with Public Insurance and the rest being uninsured */
		 	alpha_uninsured4=&alpha_onmarket_F_UN.;		/* Non-group outside the marketplaces. Refer to the note about alpha_offmarket above */
		 	alpha_uninsured5=&alpha_public_UN.; 		/* Public insurance for those eligible with the rest being uninsured */
		 	alpha_uninsured6=1;    						/* All uninsured */

			/**************************************************************************************
			/	Read in the dissimilarity parameter for the uninsured nest
			/*************************************************************************************/
		 	mu_uninsured    =&mu_uninsured.;

			/**************************************************************************************
			/	Calculate the components of the probability of being in the uninsured nest
			/*************************************************************************************/
			%if &Marketplace_Exists.=yes %then %do;
		 		exp_U_B_onmarket_Nst_unins		=	(	exp_U_onB_F			*	alpha_uninsured1	)	**	(1/mu_uninsured);
		 		exp_U_S_onmarket_Nst_unins		=	(	exp_U_onS_F			*	alpha_uninsured1	)	**	(1/mu_uninsured);
		 		exp_U_G_onmarket_Nst_unins		=	(	exp_U_onG_F			*	alpha_uninsured1	)	**	(1/mu_uninsured);

		 		exp_U_B_offmarket_Nst_unins		=	(	exp_U_offB_F		*	alpha_uninsured4	)	**	(1/mu_uninsured);
		 		exp_U_S_offmarket_Nst_unins		=	(	exp_U_offS_F		*	alpha_uninsured4	)	**	(1/mu_uninsured);
		 		exp_U_G_offmarket_Nst_unins		=	(	exp_U_offG_F		*	alpha_uninsured4	)	**	(1/mu_uninsured); 
			%end;
			
		 	exp_U_ESI_S_1_1_Nst_unins			=	(	exp_U_ESI_S_1_1		*	alpha_uninsured2	)	**	(1/mu_uninsured);
		 	exp_U_ESI_S_2_1_Nst_unins			=	(	exp_U_ESI_S_2_1		*	alpha_uninsured2	)	**	(1/mu_uninsured);
		 	exp_U_ESI_S_2_2_Nst_unins			=	(	exp_U_ESI_S_2_2		*	alpha_uninsured2	)	**	(1/mu_uninsured);
		 	exp_U_ESI_S_2_12_Nst_unins			=	(	exp_U_ESI_S_2_12	*	alpha_uninsured2	)	**	(1/mu_uninsured);
		 	exp_U_ESI_S_3_1_Nst_unins			=	(	exp_U_ESI_S_3_1		*	alpha_uninsured2	)	**	(1/mu_uninsured);
		 	exp_U_ESI_S_3_2_Nst_unins			=	(	exp_U_ESI_S_3_2		*	alpha_uninsured2	)	**	(1/mu_uninsured);
		 	exp_U_ESI_S_3_3_Nst_unins			=	(	exp_U_ESI_S_3_3		*	alpha_uninsured2	)	**	(1/mu_uninsured);
		 	exp_U_ESI_S_3_12_Nst_unins			=	(	exp_U_ESI_S_3_12	*	alpha_uninsured2	)	**	(1/mu_uninsured);
		 	exp_U_ESI_S_3_13_Nst_unins			=	(	exp_U_ESI_S_3_13	*	alpha_uninsured2	)	**	(1/mu_uninsured);
		 	exp_U_ESI_S_3_23_Nst_unins			=	(	exp_U_ESI_S_3_23	*	alpha_uninsured2	)	**	(1/mu_uninsured);
		 	exp_U_ESI_S_3_123_Nst_unins			=	(	exp_U_ESI_S_3_123	*	alpha_uninsured2	)	**	(1/mu_uninsured);

		 	exp_U_ESI_Spo_1_1_Nst_unins			=	(	exp_U_ESI_Spo_1_1	*	alpha_uninsured3	)	**	(1/mu_uninsured);
		 	exp_U_ESI_Spo_2_1_Nst_unins			=	(	exp_U_ESI_Spo_2_1	*	alpha_uninsured3	)	**	(1/mu_uninsured);
		 	exp_U_ESI_Spo_2_2_Nst_unins			=	(	exp_U_ESI_Spo_2_2	*	alpha_uninsured3	)	**	(1/mu_uninsured);
		 	exp_U_ESI_Spo_2_12_Nst_unins		=	(	exp_U_ESI_Spo_2_12	*	alpha_uninsured3	)	**	(1/mu_uninsured);
		 	exp_U_ESI_Spo_3_1_Nst_unins			=	(	exp_U_ESI_Spo_3_1	*	alpha_uninsured3	)	**	(1/mu_uninsured);
		 	exp_U_ESI_Spo_3_2_Nst_unins			=	(	exp_U_ESI_Spo_3_2	*	alpha_uninsured3	)	**	(1/mu_uninsured);
		 	exp_U_ESI_Spo_3_3_Nst_unins			=	(	exp_U_ESI_Spo_3_3	*	alpha_uninsured3	)	**	(1/mu_uninsured);
		 	exp_U_ESI_Spo_3_12_Nst_unins		=	(	exp_U_ESI_Spo_3_12	*	alpha_uninsured3	)	**	(1/mu_uninsured);
		 	exp_U_ESI_Spo_3_13_Nst_unins		=	(	exp_U_ESI_Spo_3_13	*	alpha_uninsured3	)	**	(1/mu_uninsured); 
		 	exp_U_ESI_Spo_3_23_Nst_unins		=	(	exp_U_ESI_Spo_3_23	*	alpha_uninsured3	)	**	(1/mu_uninsured);
		 	exp_U_ESI_Spo_3_123_Nst_unins		=	(	exp_U_ESI_Spo_3_123	*	alpha_uninsured3	)	**	(1/mu_uninsured);

		 	exp_U_public_Nst_unins				=	(	exp_U_public_HIU2p	*	alpha_uninsured5	)	**	(1/mu_uninsured);

		 	exp_U_unins_Nst_unins				=	(	exp_U_UN			*	alpha_uninsured6	)	**	(1/mu_uninsured);

			%if &Marketplace_Exists.=yes %then %do;
			 	sum_Nst_unins =sum( /* Non-group in marketplaces */
			 						exp_U_B_onmarket_Nst_unins,exp_U_S_onmarket_Nst_unins,exp_U_G_onmarket_Nst_unins,
									/* Non-group outside the marketplaces  */
			 						exp_U_B_offmarket_Nst_unins,exp_U_S_offmarket_Nst_unins,exp_U_G_offmarket_Nst_unins,
									/* ESI single (rest uninsured) */
									exp_U_ESI_S_1_1_Nst_unins,exp_U_ESI_S_2_1_Nst_unins,exp_U_ESI_S_2_2_Nst_unins,exp_U_ESI_S_2_12_Nst_unins,exp_U_ESI_S_3_1_Nst_unins,exp_U_ESI_S_3_2_Nst_unins,exp_U_ESI_S_3_3_Nst_unins,
									exp_U_ESI_S_3_12_Nst_unins,exp_U_ESI_S_3_13_Nst_unins,exp_U_ESI_S_3_23_Nst_unins,exp_U_ESI_S_3_123_Nst_unins,
									/* ESI single with Public Insurance and the rest being uninsured */
									exp_U_ESI_Spo_1_1_Nst_unins,exp_U_ESI_Spo_2_1_Nst_unins,exp_U_ESI_Spo_2_2_Nst_unins,exp_U_ESI_Spo_2_12_Nst_unins,exp_U_ESI_Spo_3_1_Nst_unins,exp_U_ESI_Spo_3_2_Nst_unins,	
									exp_U_ESI_Spo_3_3_Nst_unins,exp_U_ESI_Spo_3_12_Nst_unins,exp_U_ESI_Spo_3_13_Nst_unins,exp_U_ESI_Spo_3_23_Nst_unins,exp_U_ESI_Spo_3_123_Nst_unins,
									/* Public insurance for the eligible with the rest uninsured */
									exp_U_public_Nst_unins,
									/* All uninsured */
									exp_U_unins_Nst_unins);
			%end;
	 
		/**************************************************************************************
		/	Initialize all probabilities to zero
		/*************************************************************************************/
	 	%macro p0(NST);
			%if &Marketplace_Exists.=yes %then %do;
	  			P_onB_F_&NST.		=0;	P_onS_F_&NST.		=0;	P_onG_F_&NST.		=0;
	  			P_offB_F_&NST.		=0;	P_offS_F_&NST.		=0;	P_offG_F_&NST.		=0;
			%end;
	  		P_ESI_F_1_&NST.			=0;	P_ESI_F_2_&NST.		=0;	P_ESI_Fpo_1_&NST.	=0;
	  		P_ESI_Fpo_2_&NST.		=0;	P_ESI_FpCD_1_&NST.	=0;	P_ESI_FpCD_2_&NST.	=0;
	  		P_ESI_S_1_1_&NST.		=0;	P_ESI_S_2_1_&NST.	=0;	P_ESI_S_2_2_&NST.	=0;
	  		P_ESI_S_2_12_&NST.		=0;	P_ESI_S_3_1_&NST.	=0;	P_ESI_S_3_2_&NST.	=0;
	  		P_ESI_S_3_3_&NST.		=0;	P_ESI_S_3_12_&NST.	=0;	P_ESI_S_3_13_&NST.	=0;
	  		P_ESI_S_3_23_&NST.		=0;	P_ESI_S_3_123_&NST.	=0;	P_ESI_Spo_1_1_&NST.	=0;
	  		P_ESI_Spo_2_1_&NST.		=0;	P_ESI_Spo_2_2_&NST.	=0;	P_ESI_Spo_2_12_&NST.=0;
	  		P_ESI_Spo_3_1_&NST.		=0;	P_ESI_Spo_3_2_&NST.	=0;	P_ESI_Spo_3_3_&NST.	=0;
	  		P_ESI_Spo_3_12_&NST.	=0;	P_ESI_Spo_3_13_&NST.=0;	P_ESI_Spo_3_23_&NST.=0;
	  		P_ESI_Spo_3_123_&NST.	=0;	
	  		P_public_HIU2p_&NST.	=0;	P_UN_&NST.			=0;
	 	%mend p0;
	 	%p0(NstESI);
		%p0(Nst_onmarket);
		%p0(Nst_offmarket);
		%p0(Nst_public);
		%p0(NstUN);

		/**************************************************************************************
		/	Calculate the probability of being in each nest: 
		/	ESI, non-group in and outside the marketplaces, public insurance, and uninsured 
		/*************************************************************************************/
		nest_denom = sum((sum_Nst_ESI)**(mu_esi),(sum_Nst_onmarket)**(mu_onmarket),(sum_Nst_offmarket)**(mu_offmarket),(sum_Nst_public)**(mu_public),(sum_Nst_unins)**(mu_uninsured));
		P_nest_ESI 		= ((sum_Nst_ESI)		**(mu_esi))			/nest_denom;
		P_nest_onmarket = ((sum_Nst_onmarket)	**(mu_onmarket)) 	/nest_denom;
		P_nest_offmarket= ((sum_Nst_offmarket)	**(mu_offmarket))  	/nest_denom;
		P_nest_public  	= ((sum_Nst_public)		**(mu_public))		/nest_denom;
		P_nest_UN  		= ((sum_Nst_unins)		**(mu_uninsured))  	/nest_denom;
	
		/**************************************************************************************
		/	Calculate the probability of choosing each alternative in the ESI nest					
		/*************************************************************************************/
		P_ESI_F_1_NstESI		=	P_nest_ESI	*	exp_U_ESI_F_1_NstESI		/sum_Nst_ESI;
		P_ESI_F_2_NstESI		=	P_nest_ESI	*	exp_U_ESI_F_2_NstESI		/sum_Nst_ESI;
		P_ESI_Fpo_1_NstESI		=	P_nest_ESI	*	exp_U_ESI_Fpo_1_NstESI		/sum_Nst_ESI;
		P_ESI_Fpo_2_NstESI		=	P_nest_ESI	*	exp_U_ESI_Fpo_2_NstESI		/sum_Nst_ESI;
		P_ESI_FpCD_1_NstESI		=	P_nest_ESI	*	exp_U_ESI_FpCD_1_NstESI		/sum_Nst_ESI;
		P_ESI_FpCD_2_NstESI		=	P_nest_ESI	*	exp_U_ESI_FpCD_2_NstESI		/sum_Nst_ESI;
		P_ESI_S_1_1_NstESI		=	P_nest_ESI	*	exp_U_ESI_S_1_1_NstESI		/sum_Nst_ESI;
		P_ESI_S_2_1_NstESI		=	P_nest_ESI	*	exp_U_ESI_S_2_1_NstESI		/sum_Nst_ESI;
		P_ESI_S_2_2_NstESI		=	P_nest_ESI	*	exp_U_ESI_S_2_2_NstESI		/sum_Nst_ESI;
		P_ESI_S_2_12_NstESI		=	P_nest_ESI	*	exp_U_ESI_S_2_12_NstESI		/sum_Nst_ESI;
		P_ESI_S_3_1_NstESI		=	P_nest_ESI	*	exp_U_ESI_S_3_1_NstESI		/sum_Nst_ESI;
		P_ESI_S_3_2_NstESI		=	P_nest_ESI	*	exp_U_ESI_S_3_2_NstESI		/sum_Nst_ESI;
		P_ESI_S_3_3_NstESI		=	P_nest_ESI	*	exp_U_ESI_S_3_3_NstESI		/sum_Nst_ESI;
		P_ESI_S_3_12_NstESI		=	P_nest_ESI	*	exp_U_ESI_S_3_12_NstESI		/sum_Nst_ESI;
		P_ESI_S_3_13_NstESI		=	P_nest_ESI	*	exp_U_ESI_S_3_13_NstESI		/sum_Nst_ESI;
		P_ESI_S_3_23_NstESI		=	P_nest_ESI	*	exp_U_ESI_S_3_23_NstESI		/sum_Nst_ESI;
		P_ESI_S_3_123_NstESI	=	P_nest_ESI	*	exp_U_ESI_S_3_123_NstESI	/sum_Nst_ESI;
		P_ESI_Spo_1_1_NstESI	=	P_nest_ESI	*	exp_U_ESI_Spo_1_1_NstESI	/sum_Nst_ESI;
		P_ESI_Spo_2_1_NstESI	=	P_nest_ESI	*	exp_U_ESI_Spo_2_1_NstESI	/sum_Nst_ESI;
		P_ESI_Spo_2_2_NstESI	=	P_nest_ESI	*	exp_U_ESI_Spo_2_2_NstESI	/sum_Nst_ESI;
		P_ESI_Spo_2_12_NstESI	=	P_nest_ESI	*	exp_U_ESI_Spo_2_12_NstESI	/sum_Nst_ESI;
		P_ESI_Spo_3_1_NstESI	=	P_nest_ESI	*	exp_U_ESI_Spo_3_1_NstESI	/sum_Nst_ESI;
		P_ESI_Spo_3_2_NstESI	=	P_nest_ESI	*	exp_U_ESI_Spo_3_2_NstESI	/sum_Nst_ESI;
		P_ESI_Spo_3_3_NstESI	=	P_nest_ESI	*	exp_U_ESI_Spo_3_3_NstESI	/sum_Nst_ESI;
		P_ESI_Spo_3_12_NstESI	=	P_nest_ESI	*	exp_U_ESI_Spo_3_12_NstESI	/sum_Nst_ESI;
		P_ESI_Spo_3_13_NstESI	=	P_nest_ESI	*	exp_U_ESI_Spo_3_13_NstESI	/sum_Nst_ESI;
		P_ESI_Spo_3_23_NstESI	=	P_nest_ESI	*	exp_U_ESI_Spo_3_23_NstESI	/sum_Nst_ESI;
		P_ESI_Spo_3_123_NstESI	=	P_nest_ESI	*	exp_U_ESI_Spo_3_123_NstESI	/sum_Nst_ESI;

		/**************************************************************************************
		/	Calculate the probability of choosing each alternative in the nongroup nests					
		/	 (in and outside the marketplaces)
		/*************************************************************************************/
		%if &Marketplace_Exists.=yes %then %do;
			P_onB_F_Nst_onmarket		=	P_nest_onmarket	*	exp_U_B_F_Nst_onmarket	/sum_Nst_onmarket ;
			P_onS_F_Nst_onmarket		=	P_nest_onmarket	*	exp_U_S_F_Nst_onmarket	/sum_Nst_onmarket ;
			P_onG_F_Nst_onmarket		=	P_nest_onmarket	*	exp_U_G_F_Nst_onmarket	/sum_Nst_onmarket ;

			P_offB_F_Nst_offmarket		=	P_nest_offmarket	*	exp_U_B_F_Nst_offmarket	/sum_Nst_offmarket ;
			P_offS_F_Nst_offmarket		=	P_nest_offmarket	*	exp_U_S_F_Nst_offmarket	/sum_Nst_offmarket ;
			P_offG_F_Nst_offmarket		=	P_nest_offmarket	*	exp_U_G_F_Nst_offmarket	/sum_Nst_offmarket ;
		%end;

		/**************************************************************************************
		/ 	Calculate the probability of choosing each alternative in the public insurance nest				
		/*************************************************************************************/
		P_public_HIU2p_Nst_public		=	P_nest_public	*	exp_U_public_Nst_public			/sum_Nst_public ;
		%if &Marketplace_Exists.=yes %then %do;
			P_onB_F_Nst_public		=	P_nest_public	*	exp_U_B_onmarket_Nst_public		/sum_Nst_public ;
			P_onS_F_Nst_public		=	P_nest_public	*	exp_U_S_onmarket_Nst_public		/sum_Nst_public ;
			P_onG_F_Nst_public		=	P_nest_public	*	exp_U_G_onmarket_Nst_public		/sum_Nst_public ;
			P_offB_F_Nst_public		=	P_nest_public	*	exp_U_B_offmarket_Nst_public	/sum_Nst_public ;
			P_offS_F_Nst_public		=	P_nest_public	*	exp_U_S_offmarket_Nst_public	/sum_Nst_public ;
			P_offG_F_Nst_public		=	P_nest_public	*	exp_U_G_offmarket_Nst_public	/sum_Nst_public ;
		%end;
		P_ESI_Fpo_1_Nst_public		=	P_nest_public	*	exp_U_ESI_Fpo_1_Nst_public		/sum_Nst_public ;
		P_ESI_Fpo_2_Nst_public		=	P_nest_public	*	exp_U_ESI_Fpo_2_Nst_public		/sum_Nst_public ;
		P_ESI_FpCD_1_Nst_public		=	P_nest_public	*	exp_U_ESI_FpCD_1_Nst_public		/sum_Nst_public ;
		P_ESI_FpCD_2_Nst_public		=	P_nest_public	*	exp_U_ESI_FpCD_2_Nst_public		/sum_Nst_public ;
		P_ESI_Spo_1_1_Nst_public	=	P_nest_public	*	exp_U_ESI_Spo_1_1_Nst_public	/sum_Nst_public ;
		P_ESI_Spo_2_1_Nst_public	=	P_nest_public	*	exp_U_ESI_Spo_2_1_Nst_public	/sum_Nst_public ;
		P_ESI_Spo_2_2_Nst_public	=	P_nest_public	*	exp_U_ESI_Spo_2_2_Nst_public	/sum_Nst_public ;
		P_ESI_Spo_2_12_Nst_public	=	P_nest_public	*	exp_U_ESI_Spo_2_12_Nst_public	/sum_Nst_public ;
		P_ESI_Spo_3_1_Nst_public	=	P_nest_public	*	exp_U_ESI_Spo_3_1_Nst_public	/sum_Nst_public ;
		P_ESI_Spo_3_2_Nst_public	=	P_nest_public	*	exp_U_ESI_Spo_3_2_Nst_public	/sum_Nst_public ;
		P_ESI_Spo_3_3_Nst_public	=	P_nest_public	*	exp_U_ESI_Spo_3_3_Nst_public	/sum_Nst_public ;
		P_ESI_Spo_3_12_Nst_public	=	P_nest_public	*	exp_U_ESI_Spo_3_12_Nst_public	/sum_Nst_public ;
		P_ESI_Spo_3_13_Nst_public	=	P_nest_public	*	exp_U_ESI_Spo_3_13_Nst_public	/sum_Nst_public ;
		P_ESI_Spo_3_23_Nst_public	=	P_nest_public	*	exp_U_ESI_Spo_3_23_Nst_public	/sum_Nst_public ;
		P_ESI_Spo_3_123_Nst_public	=	P_nest_public	*	exp_U_ESI_Spo_3_123_Nst_public	/sum_Nst_public ;

		/**************************************************************************************
		/	Calculate the probability of choosing each alternative in the uninsured nest			
		/*************************************************************************************/
		%if &Marketplace_Exists.=yes %then %do;
			P_onB_F_NstUN		=	P_nest_UN	*	exp_U_B_onmarket_Nst_unins	/sum_Nst_unins ;
			P_onS_F_NstUN		=	P_nest_UN	*	exp_U_S_onmarket_Nst_unins	/sum_Nst_unins ;
			P_onG_F_NstUN		=	P_nest_UN	*	exp_U_G_onmarket_Nst_unins	/sum_Nst_unins ;
			P_offB_F_NstUN		=	P_nest_UN	*	exp_U_B_offmarket_Nst_unins	/sum_Nst_unins ;
			P_offS_F_NstUN		=	P_nest_UN	*	exp_U_S_offmarket_Nst_unins	/sum_Nst_unins ;
			P_offG_F_NstUN		=	P_nest_UN	*	exp_U_G_offmarket_Nst_unins	/sum_Nst_unins ;
		%end;
		P_ESI_S_1_1_NstUN		=	P_nest_UN	*	exp_U_ESI_S_1_1_Nst_unins		/sum_Nst_unins ;
		P_ESI_S_2_1_NstUN		=	P_nest_UN	*	exp_U_ESI_S_2_1_Nst_unins		/sum_Nst_unins ;
		P_ESI_S_2_2_NstUN		=	P_nest_UN	*	exp_U_ESI_S_2_2_Nst_unins		/sum_Nst_unins ;
		P_ESI_S_2_12_NstUN		=	P_nest_UN	*	exp_U_ESI_S_2_12_Nst_unins		/sum_Nst_unins ;
		P_ESI_S_3_1_NstUN		=	P_nest_UN	*	exp_U_ESI_S_3_1_Nst_unins		/sum_Nst_unins ;
		P_ESI_S_3_2_NstUN		=	P_nest_UN	*	exp_U_ESI_S_3_2_Nst_unins		/sum_Nst_unins ;
		P_ESI_S_3_3_NstUN		=	P_nest_UN	*	exp_U_ESI_S_3_3_Nst_unins		/sum_Nst_unins ;
		P_ESI_S_3_12_NstUN		=	P_nest_UN	*	exp_U_ESI_S_3_12_Nst_unins		/sum_Nst_unins ;
		P_ESI_S_3_13_NstUN		=	P_nest_UN	*	exp_U_ESI_S_3_13_Nst_unins		/sum_Nst_unins ;
		P_ESI_S_3_23_NstUN		=	P_nest_UN	*	exp_U_ESI_S_3_23_Nst_unins		/sum_Nst_unins ;
		P_ESI_S_3_123_NstUN		=	P_nest_UN	*	exp_U_ESI_S_3_123_Nst_unins		/sum_Nst_unins ;
		P_ESI_Spo_1_1_NstUN		=	P_nest_UN	*	exp_U_ESI_Spo_1_1_Nst_unins		/sum_Nst_unins ;
		P_ESI_Spo_2_1_NstUN		=	P_nest_UN	*	exp_U_ESI_Spo_2_1_Nst_unins		/sum_Nst_unins ;
		P_ESI_Spo_2_2_NstUN		=	P_nest_UN	*	exp_U_ESI_Spo_2_2_Nst_unins		/sum_Nst_unins ;
		P_ESI_Spo_2_12_NstUN	=	P_nest_UN	*	exp_U_ESI_Spo_2_12_Nst_unins	/sum_Nst_unins ;
		P_ESI_Spo_3_1_NstUN		=	P_nest_UN	*	exp_U_ESI_Spo_3_1_Nst_unins		/sum_Nst_unins ;
		P_ESI_Spo_3_2_NstUN		=	P_nest_UN	*	exp_U_ESI_Spo_3_2_Nst_unins		/sum_Nst_unins ;
		P_ESI_Spo_3_3_NstUN		=	P_nest_UN	*	exp_U_ESI_Spo_3_3_Nst_unins		/sum_Nst_unins ;
		P_ESI_Spo_3_12_NstUN	=	P_nest_UN	*	exp_U_ESI_Spo_3_12_Nst_unins	/sum_Nst_unins ;
		P_ESI_Spo_3_13_NstUN	=	P_nest_UN	*	exp_U_ESI_Spo_3_13_Nst_unins	/sum_Nst_unins ;
		P_ESI_Spo_3_23_NstUN	=	P_nest_UN	*	exp_U_ESI_Spo_3_23_Nst_unins	/sum_Nst_unins ;
		P_ESI_Spo_3_123_NstUN	=	P_nest_UN	*	exp_U_ESI_Spo_3_123_Nst_unins	/sum_Nst_unins ;
		P_public_HIU2p_NstUN	=	P_nest_UN	*	exp_U_public_Nst_unins			/sum_Nst_unins ;
		P_UN_NstUN				=	P_nest_UN	*	exp_U_unins_Nst_unins			/sum_Nst_unins ;

		/**************************************************************************************
		/	Calculate the probability of choosing each alternative, 								
		/		which is the summation over all nests in the given alternative 
		/*************************************************************************************/				
		%if &Marketplace_Exists.=yes %then %do;
			P_onB_F			=	sum(P_onB_F_NstESI			,	P_onB_F_Nst_onmarket			,	P_onB_F_Nst_offmarket			,	P_onB_F_Nst_public			,	P_onB_F_NstUN			);
			P_onS_F			=	sum(P_onS_F_NstESI			,	P_onS_F_Nst_onmarket			,	P_onS_F_Nst_offmarket			,	P_onS_F_Nst_public			,	P_onS_F_NstUN			);
			P_onG_F			=	sum(P_onG_F_NstESI			,	P_onG_F_Nst_onmarket			,	P_onG_F_Nst_offmarket			,	P_onG_F_Nst_public			,	P_onG_F_NstUN			);
			P_offB_F		=	sum(P_offB_F_NstESI			,	P_offB_F_Nst_onmarket			,	P_offB_F_Nst_offmarket			,	P_offB_F_Nst_public			,	P_offB_F_NstUN			);
			P_offS_F		=	sum(P_offS_F_NstESI			,	P_offS_F_Nst_onmarket			,	P_offS_F_Nst_offmarket			,	P_offS_F_Nst_public			,	P_offS_F_NstUN			);
			P_offG_F		=	sum(P_offG_F_NstESI			,	P_offG_F_Nst_onmarket			,	P_offG_F_Nst_offmarket			,	P_offG_F_Nst_public			,	P_offG_F_NstUN			);
		%end;
		P_ESI_F_1			=	sum(P_ESI_F_1_NstESI		,	P_ESI_F_1_Nst_onmarket			,	P_ESI_F_1_Nst_offmarket			,	P_ESI_F_1_Nst_public		,	P_ESI_F_1_NstUN			);
		P_ESI_F_2			=	sum(P_ESI_F_2_NstESI		,	P_ESI_F_2_Nst_onmarket			,	P_ESI_F_2_Nst_offmarket			,	P_ESI_F_2_Nst_public		,	P_ESI_F_2_NstUN			);
		P_ESI_Fpo_1			=	sum(P_ESI_Fpo_1_NstESI		,	P_ESI_Fpo_1_Nst_onmarket		,	P_ESI_Fpo_1_Nst_offmarket		,	P_ESI_Fpo_1_Nst_public		,	P_ESI_Fpo_1_NstUN		);
		P_ESI_Fpo_2			=	sum(P_ESI_Fpo_2_NstESI		,	P_ESI_Fpo_2_Nst_onmarket		,	P_ESI_Fpo_2_Nst_offmarket		,	P_ESI_Fpo_2_Nst_public		,	P_ESI_Fpo_2_NstUN		);
		P_ESI_FpCD_1		=	sum(P_ESI_FpCD_1_NstESI		,	P_ESI_FpCD_1_Nst_onmarket		,	P_ESI_FpCD_1_Nst_offmarket		,	P_ESI_FpCD_1_Nst_public		,	P_ESI_FpCD_1_NstUN		);
		P_ESI_FpCD_2		=	sum(P_ESI_FpCD_2_NstESI		,	P_ESI_FpCD_2_Nst_onmarket		,	P_ESI_FpCD_2_Nst_offmarket		,	P_ESI_FpCD_2_Nst_public		,	P_ESI_FpCD_2_NstUN		);
		P_ESI_S_1_1			=	sum(P_ESI_S_1_1_NstESI		,	P_ESI_S_1_1_Nst_onmarket		,	P_ESI_S_1_1_Nst_offmarket		,	P_ESI_S_1_1_Nst_public		,	P_ESI_S_1_1_NstUN		);
		P_ESI_S_2_1			=	sum(P_ESI_S_2_1_NstESI		,	P_ESI_S_2_1_Nst_onmarket		,	P_ESI_S_2_1_Nst_offmarket		,	P_ESI_S_2_1_Nst_public		,	P_ESI_S_2_1_NstUN		);
		P_ESI_S_2_2			=	sum(P_ESI_S_2_2_NstESI		,	P_ESI_S_2_2_Nst_onmarket		,	P_ESI_S_2_2_Nst_offmarket		,	P_ESI_S_2_2_Nst_public		,	P_ESI_S_2_2_NstUN		);
		P_ESI_S_2_12		=	sum(P_ESI_S_2_12_NstESI		,	P_ESI_S_2_12_Nst_onmarket		,	P_ESI_S_2_12_Nst_offmarket		,	P_ESI_S_2_12_Nst_public		,	P_ESI_S_2_12_NstUN		);
		P_ESI_S_3_1			=	sum(P_ESI_S_3_1_NstESI		,	P_ESI_S_3_1_Nst_onmarket		,	P_ESI_S_3_1_Nst_offmarket		,	P_ESI_S_3_1_Nst_public		,	P_ESI_S_3_1_NstUN		);
		P_ESI_S_3_2			=	sum(P_ESI_S_3_2_NstESI		,	P_ESI_S_3_2_Nst_onmarket		,	P_ESI_S_3_2_Nst_offmarket		,	P_ESI_S_3_2_Nst_public		,	P_ESI_S_3_2_NstUN		);
		P_ESI_S_3_3			=	sum(P_ESI_S_3_3_NstESI		,	P_ESI_S_3_3_Nst_onmarket		,	P_ESI_S_3_3_Nst_offmarket		,	P_ESI_S_3_3_Nst_public		,	P_ESI_S_3_3_NstUN		);
		P_ESI_S_3_12		=	sum(P_ESI_S_3_12_NstESI		,	P_ESI_S_3_12_Nst_onmarket		,	P_ESI_S_3_12_Nst_offmarket		,	P_ESI_S_3_12_Nst_public		,	P_ESI_S_3_12_NstUN		);
		P_ESI_S_3_13		=	sum(P_ESI_S_3_13_NstESI		,	P_ESI_S_3_13_Nst_onmarket		,	P_ESI_S_3_13_Nst_offmarket		,	P_ESI_S_3_13_Nst_public		,	P_ESI_S_3_13_NstUN		);
		P_ESI_S_3_23		=	sum(P_ESI_S_3_23_NstESI		,	P_ESI_S_3_23_Nst_onmarket		,	P_ESI_S_3_23_Nst_offmarket		,	P_ESI_S_3_23_Nst_public		,	P_ESI_S_3_23_NstUN		);
		P_ESI_S_3_123		=	sum(P_ESI_S_3_123_NstESI	,	P_ESI_S_3_123_Nst_onmarket		,	P_ESI_S_3_123_Nst_offmarket		,	P_ESI_S_3_123_Nst_public	,	P_ESI_S_3_123_NstUN		);
		P_ESI_Spo_1_1		=	sum(P_ESI_Spo_1_1_NstESI	,	P_ESI_Spo_1_1_Nst_onmarket		,	P_ESI_Spo_1_1_Nst_offmarket		,	P_ESI_Spo_1_1_Nst_public	,	P_ESI_Spo_1_1_NstUN		);
		P_ESI_Spo_2_1		=	sum(P_ESI_Spo_2_1_NstESI	,	P_ESI_Spo_2_1_Nst_onmarket		,	P_ESI_Spo_2_1_Nst_offmarket		,	P_ESI_Spo_2_1_Nst_public	,	P_ESI_Spo_2_1_NstUN		);
		P_ESI_Spo_2_2		=	sum(P_ESI_Spo_2_2_NstESI	,	P_ESI_Spo_2_2_Nst_onmarket		,	P_ESI_Spo_2_2_Nst_offmarket		,	P_ESI_Spo_2_2_Nst_public	,	P_ESI_Spo_2_2_NstUN		);
		P_ESI_Spo_2_12		=	sum(P_ESI_Spo_2_12_NstESI	,	P_ESI_Spo_2_12_Nst_onmarket		,	P_ESI_Spo_2_12_Nst_offmarket	,	P_ESI_Spo_2_12_Nst_public	,	P_ESI_Spo_2_12_NstUN	);
		P_ESI_Spo_3_1		=	sum(P_ESI_Spo_3_1_NstESI	,	P_ESI_Spo_3_1_Nst_onmarket		,	P_ESI_Spo_3_1_Nst_offmarket		,	P_ESI_Spo_3_1_Nst_public	,	P_ESI_Spo_3_1_NstUN		);
		P_ESI_Spo_3_2		=	sum(P_ESI_Spo_3_2_NstESI	,	P_ESI_Spo_3_2_Nst_onmarket		,	P_ESI_Spo_3_2_Nst_offmarket		,	P_ESI_Spo_3_2_Nst_public	,	P_ESI_Spo_3_2_NstUN		);
		P_ESI_Spo_3_3		=	sum(P_ESI_Spo_3_3_NstESI	,	P_ESI_Spo_3_3_Nst_onmarket		,	P_ESI_Spo_3_3_Nst_offmarket		,	P_ESI_Spo_3_3_Nst_public	,	P_ESI_Spo_3_3_NstUN		);
		P_ESI_Spo_3_12		=	sum(P_ESI_Spo_3_12_NstESI	,	P_ESI_Spo_3_12_Nst_onmarket		,	P_ESI_Spo_3_12_Nst_offmarket	,	P_ESI_Spo_3_12_Nst_public	,	P_ESI_Spo_3_12_NstUN	);
		P_ESI_Spo_3_13		=	sum(P_ESI_Spo_3_13_NstESI	,	P_ESI_Spo_3_13_Nst_onmarket		,	P_ESI_Spo_3_13_Nst_offmarket	,	P_ESI_Spo_3_13_Nst_public	,	P_ESI_Spo_3_13_NstUN	);
		P_ESI_Spo_3_23		=	sum(P_ESI_Spo_3_23_NstESI	,	P_ESI_Spo_3_23_Nst_onmarket		,	P_ESI_Spo_3_23_Nst_offmarket	,	P_ESI_Spo_3_23_Nst_public	,	P_ESI_Spo_3_23_NstUN	);
		P_ESI_Spo_3_123		=	sum(P_ESI_Spo_3_123_NstESI	,	P_ESI_Spo_3_123_Nst_onmarket	,	P_ESI_Spo_3_123_Nst_offmarket	,	P_ESI_Spo_3_123_Nst_public	,	P_ESI_Spo_3_123_NstUN	);
		P_public_HIU2p		=	sum(P_public_HIU2p_NstESI	,	P_public_HIU2p_Nst_onmarket		,	P_public_HIU2p_Nst_offmarket	,	P_public_HIU2p_Nst_public	,	P_public_HIU2p_NstUN	);
		P_UN_HIU2p			=	sum(P_UN_NstESI				,	P_UN_Nst_onmarket				,	P_UN_Nst_offmarket				,	P_UN_Nst_public				,	P_UN_NstUN				);

	/******************************************************************************************
	/	Calculate the number of people with certain coverage types
	/*****************************************************************************************/

		/**************************************************************************************
		/	Calculate the number of people who enroll in ESI family plan by plan type
		/*************************************************************************************/ 
		cvrg_ESI_F_PPO  	= sum(	P_ESI_F_1*Nw_ESI_F_PPO_1,P_ESI_F_2*Nw_ESI_F_PPO_2,P_ESI_Fpo_1*Nw_ESI_Fpo_PPO_1,P_ESI_Fpo_2*Nw_ESI_Fpo_PPO_2, 
		                    	P_ESI_FpCD_1*Nw_ESI_FpCD_PPO_1,P_ESI_FpCD_2*Nw_ESI_FpCD_PPO_2);
		cvrg_ESI_F_HMO  	= sum(	P_ESI_F_1*Nw_ESI_F_HMO_1,P_ESI_F_2*Nw_ESI_F_HMO_2,P_ESI_Fpo_1*Nw_ESI_Fpo_HMO_1,P_ESI_Fpo_2*Nw_ESI_Fpo_HMO_2, 
		                      	P_ESI_FpCD_1*Nw_ESI_FpCD_HMO_1,P_ESI_FpCD_2*Nw_ESI_FpCD_HMO_2);
		cvrg_ESI_F_HDHP  	= sum(	P_ESI_F_1*Nw_ESI_F_HDHP_1,P_ESI_F_2*Nw_ESI_F_HDHP_2,P_ESI_Fpo_1*Nw_ESI_Fpo_HDHP_1,P_ESI_Fpo_2*Nw_ESI_Fpo_HDHP_2,
		                      	P_ESI_FpCD_1*Nw_ESI_FpCD_HDHP_1,P_ESI_FpCD_2*Nw_ESI_FpCD_HDHP_2);

		/**************************************************************************************
		/	Calculate the number of non-dependent children on their parents' ESI family plan
		/*************************************************************************************/   
	 	cvrg_ESI_F_nondep_child	= sum(	P_ESI_F_1*Nw_ESI_F_nodepkids_1,P_ESI_F_2*Nw_ESI_F_nodepkids_2,
										P_ESI_Fpo_1*Nw_ESI_Fpo_nondepkids_1,P_ESI_Fpo_2*Nw_ESI_Fpo_nondepkids_2, 
										P_ESI_FpCD_1*Nw_ESI_FpCD_nodepkids_1,P_ESI_FpCD_2*Nw_ESI_FpCD_nodepkids_2);

		/**************************************************************************************
		/	Calculate the number of ESI family plan dependents (children) who are also covered
		/	by Medicaid
		/*************************************************************************************/
	 	cvrg_ESI_F_medicaid_double	= sum(	P_ESI_FpCD_1*Nw_ESI_FpCD_double_1,P_ESI_FpCD_2*Nw_ESI_FpCD_double_2); 

		/**************************************************************************************
		/	Calculate the number of people who enroll in ESI single plan by plan type
		/*************************************************************************************/
		cvrg_ESI_S_PPO  	= sum(	P_ESI_S_1_1*Nw_ESI_S_PPO_1_1,P_ESI_S_2_1*Nw_ESI_S_PPO_2_1,P_ESI_S_2_2*Nw_ESI_S_PPO_2_2,P_ESI_S_2_12*Nw_ESI_S_PPO_2_12,		
							  	P_ESI_S_3_1*Nw_ESI_S_PPO_3_1,P_ESI_S_3_2*Nw_ESI_S_PPO_3_2,P_ESI_S_3_3*Nw_ESI_S_PPO_3_3,P_ESI_S_3_12*Nw_ESI_S_PPO_3_12,		
							  	P_ESI_S_3_13*Nw_ESI_S_PPO_3_13,P_ESI_S_3_23*Nw_ESI_S_PPO_3_23,P_ESI_S_3_123*Nw_ESI_S_PPO_3_123,P_ESI_Spo_1_1*Nw_ESI_Spo_PPO_1_1,		
							  	P_ESI_Spo_2_1*Nw_ESI_Spo_PPO_2_1,P_ESI_Spo_2_2*Nw_ESI_Spo_PPO_2_2,P_ESI_Spo_2_12*Nw_ESI_Spo_PPO_2_12,P_ESI_Spo_3_1*Nw_ESI_Spo_PPO_3_1,		
							  	P_ESI_Spo_3_2*Nw_ESI_Spo_PPO_3_2,P_ESI_Spo_3_3*Nw_ESI_Spo_PPO_3_3,P_ESI_Spo_3_12*Nw_ESI_Spo_PPO_3_12,P_ESI_Spo_3_13*Nw_ESI_Spo_PPO_3_13,		
							  	P_ESI_Spo_3_23*Nw_ESI_Spo_PPO_3_23,P_ESI_Spo_3_123*Nw_ESI_Spo_PPO_3_123);	
		cvrg_ESI_S_HMO 		= sum(	P_ESI_S_1_1*Nw_ESI_S_HMO_1_1,P_ESI_S_2_1*Nw_ESI_S_HMO_2_1,P_ESI_S_2_2*Nw_ESI_S_HMO_2_2,P_ESI_S_2_12*Nw_ESI_S_HMO_2_12,		
							  	P_ESI_S_3_1*Nw_ESI_S_HMO_3_1,P_ESI_S_3_2*Nw_ESI_S_HMO_3_2,P_ESI_S_3_3*Nw_ESI_S_HMO_3_3,P_ESI_S_3_12*Nw_ESI_S_HMO_3_12,		
							  	P_ESI_S_3_13*Nw_ESI_S_HMO_3_13,P_ESI_S_3_23*Nw_ESI_S_HMO_3_23,P_ESI_S_3_123*Nw_ESI_S_HMO_3_123,P_ESI_Spo_1_1*Nw_ESI_Spo_HMO_1_1,		
							  	P_ESI_Spo_2_1*Nw_ESI_Spo_HMO_2_1,P_ESI_Spo_2_2*Nw_ESI_Spo_HMO_2_2,P_ESI_Spo_2_12*Nw_ESI_Spo_HMO_2_12,P_ESI_Spo_3_1*Nw_ESI_Spo_HMO_3_1,		
							  	P_ESI_Spo_3_2*Nw_ESI_Spo_HMO_3_2,P_ESI_Spo_3_3*Nw_ESI_Spo_HMO_3_3,P_ESI_Spo_3_12*Nw_ESI_Spo_HMO_3_12,P_ESI_Spo_3_13*Nw_ESI_Spo_HMO_3_13,		
							  	P_ESI_Spo_3_23*Nw_ESI_Spo_HMO_3_23,P_ESI_Spo_3_123*Nw_ESI_Spo_HMO_3_123);	
		cvrg_ESI_S_HDHP  	= sum(	P_ESI_S_1_1*Nw_ESI_S_HDHP_1_1,P_ESI_S_2_1*Nw_ESI_S_HDHP_2_1,P_ESI_S_2_2*Nw_ESI_S_HDHP_2_2,P_ESI_S_2_12*Nw_ESI_S_HDHP_2_12,		
							  	P_ESI_S_3_1*Nw_ESI_S_HDHP_3_1,P_ESI_S_3_2*Nw_ESI_S_HDHP_3_2,P_ESI_S_3_3*Nw_ESI_S_HDHP_3_3,P_ESI_S_3_12*Nw_ESI_S_HDHP_3_12,		
							  	P_ESI_S_3_13*Nw_ESI_S_HDHP_3_13,P_ESI_S_3_23*Nw_ESI_S_HDHP_3_23,P_ESI_S_3_123*Nw_ESI_S_HDHP_3_123,P_ESI_Spo_1_1*Nw_ESI_Spo_HDHP_1_1,		
							  	P_ESI_Spo_2_1*Nw_ESI_Spo_HDHP_2_1,P_ESI_Spo_2_2*Nw_ESI_Spo_HDHP_2_2,P_ESI_Spo_2_12*Nw_ESI_Spo_HDHP_2_12,P_ESI_Spo_3_1*Nw_ESI_Spo_HDHP_3_1,		
							  	P_ESI_Spo_3_2*Nw_ESI_Spo_HDHP_3_2,P_ESI_Spo_3_3*Nw_ESI_Spo_HDHP_3_3,P_ESI_Spo_3_12*Nw_ESI_Spo_HDHP_3_12,P_ESI_Spo_3_13*Nw_ESI_Spo_HDHP_3_13,		
							  	P_ESI_Spo_3_23*Nw_ESI_Spo_HDHP_3_23,P_ESI_Spo_3_123*Nw_ESI_Spo_HDHP_3_123);	

		/**************************************************************************************
		/	Calculate the number of people who enroll in non-group plans (in or outside the
		/   marketplace) by plan tier and subsidized status 
		/*************************************************************************************/
		%if &Marketplace_Exists.=yes %then %do;
			if GET_SUB ne 1 then GET_SUB=0; 
			cvrg_B_onmarket_sub 		= sum(P_onB_F*Nw_nongroup)*GET_SUB;
			cvrg_S_onmarket_sub 		= sum(P_onS_F*Nw_nongroup)*GET_SUB;
			cvrg_G_onmarket_sub 		= sum(P_onG_F*Nw_nongroup)*GET_SUB;

			cvrg_B_onmarket_nosub 	= sum(P_onB_F*Nw_nongroup)*(1-GET_SUB);
			cvrg_S_onmarket_nosub 	= sum(P_onS_F*Nw_nongroup)*(1-GET_SUB);
			cvrg_G_onmarket_nosub 	= sum(P_onG_F*Nw_nongroup)*(1-GET_SUB);

			cvrg_B_offmarket	 		= sum(P_offB_F*Nw_nongroup);
			cvrg_S_offmarket			= sum(P_offS_F*Nw_nongroup);
			cvrg_G_offmarket			= sum(P_offG_F*Nw_nongroup);

		/**********************************************************************************
		/	Calculate the number of people with public insurance: 
		/		Medicaid coverage by eligibility category 
		/			(previously eligible children, previously eligible adults, and newly eligible adults)
		/		CHIP, and 
		/		Medicare
		/*********************************************************************************/
		cvrg_public_pe_kid	= 	
			sum(P_onB_F*Nw_nongroup_F_MCDpe_kid,		P_onS_F*Nw_nongroup_F_MCDpe_kid,	P_onG_F*Nw_nongroup_F_MCDpe_kid,
				P_ESI_Fpo_1*Nw_ESI_Fpo_MCDpe_kid_1,		P_ESI_Fpo_2*Nw_ESI_Fpo_MCDpe_kid_2,
				P_ESI_Spo_1_1*Nw_ESI_Spo_MCDpe_kid_1_1,
				P_ESI_Spo_2_1*Nw_ESI_Spo_MCDpe_kid_2_1,	P_ESI_Spo_2_2*Nw_ESI_Spo_MCDpe_kid_2_2,P_ESI_Spo_2_12*Nw_ESI_Spo_MCDpe_kid_2_12,
				P_ESI_Spo_3_1*Nw_ESI_Spo_MCDpe_kid_3_1,	P_ESI_Spo_3_2*Nw_ESI_Spo_MCDpe_kid_3_2,P_ESI_Spo_3_3*Nw_ESI_Spo_MCDpe_kid_3_3,
				P_ESI_Spo_3_12*Nw_ESI_Spo_MCDpe_kid_3_12,P_ESI_Spo_3_13*Nw_ESI_Spo_MCDpe_kid_3_13,P_ESI_Spo_3_23*Nw_ESI_Spo_MCDpe_kid_3_23,
				P_ESI_Spo_3_123*Nw_ESI_Spo_MCDpe_kid_3_123,
				P_public_HIU2p*Nw_public_MCDpe_kid,
				P_offB_F*Nw_nongroup_F_MCDpe_kid,		P_offS_F*Nw_nongroup_F_MCDpe_kid,	P_offG_F*Nw_nongroup_F_MCDpe_kid);
		cvrg_public_pe_adult = 	
			sum(P_onB_F*Nw_nongroup_F_MCDpe_adult,		P_onS_F*Nw_nongroup_F_MCDpe_adult,	P_onG_F*Nw_nongroup_F_MCDpe_adult,
				P_ESI_Fpo_1*Nw_ESI_Fpo_MCDpe_adult_1,	P_ESI_Fpo_2*Nw_ESI_Fpo_MCDpe_adult_2,
				P_ESI_Spo_1_1*Nw_ESI_Spo_MCDpe_adult_1_1,
				P_ESI_Spo_2_1*Nw_ESI_Spo_MCDpe_adult_2_1,	P_ESI_Spo_2_2*Nw_ESI_Spo_MCDpe_adult_2_2,P_ESI_Spo_2_12*Nw_ESI_Spo_MCDpe_adult_2_12,
				P_ESI_Spo_3_1*Nw_ESI_Spo_MCDpe_adult_3_1,	P_ESI_Spo_3_2*Nw_ESI_Spo_MCDpe_adult_3_2,P_ESI_Spo_3_3*Nw_ESI_Spo_MCDpe_adult_3_3,
				P_ESI_Spo_3_12*Nw_ESI_Spo_MCDpe_adult_3_12,	P_ESI_Spo_3_13*Nw_ESI_Spo_MCDpe_adult_3_13,P_ESI_Spo_3_23*Nw_ESI_Spo_MCDpe_adult_3_23,
				P_ESI_Spo_3_123*Nw_ESI_Spo_MCDpe_adult_3_123,
				P_public_HIU2p*Nw_public_MCDpe_adult,	
				P_offB_F*Nw_nongroup_F_MCDpe_adult,		P_offS_F*Nw_nongroup_F_MCDpe_adult,	P_offG_F*Nw_nongroup_F_MCDpe_adult);
		cvrg_public_ne = 	
			sum(P_onB_F*Nw_nongroup_F_MCDne,	P_onS_F*Nw_nongroup_F_MCDne,	P_onG_F*Nw_nongroup_F_MCDne,
				P_ESI_Fpo_1*Nw_ESI_Fpo_MCDne_1,	P_ESI_Fpo_2*Nw_ESI_Fpo_MCDne_2,
				P_ESI_Spo_1_1*Nw_ESI_Spo_MCDne_1_1,		
				P_ESI_Spo_2_1*Nw_ESI_Spo_MCDne_2_1,	P_ESI_Spo_2_2*Nw_ESI_Spo_MCDne_2_2,	P_ESI_Spo_2_12*Nw_ESI_Spo_MCDne_2_12,	
				P_ESI_Spo_3_1*Nw_ESI_Spo_MCDne_3_1,	P_ESI_Spo_3_2*Nw_ESI_Spo_MCDne_3_2,		P_ESI_Spo_3_3*Nw_ESI_Spo_MCDne_3_3,		
				P_ESI_Spo_3_12*Nw_ESI_Spo_MCDne_3_12,	P_ESI_Spo_3_13*Nw_ESI_Spo_MCDne_3_13,	P_ESI_Spo_3_23*Nw_ESI_Spo_MCDne_3_23,	
				P_ESI_Spo_3_123*Nw_ESI_Spo_MCDne_3_123,
				P_public_HIU2p*Nw_public_MCDne,
				P_offB_F*Nw_nongroup_F_MCDne,	P_offS_F*Nw_nongroup_F_MCDne,	P_offG_F*Nw_nongroup_F_MCDne);
		cvrg_public_chip = 	
			sum(P_onB_F*Nw_nongroup_F_chip,		P_onS_F*Nw_nongroup_F_chip,		P_onG_F*Nw_nongroup_F_chip,
				P_ESI_Fpo_1*Nw_ESI_Fpo_chip_1,	P_ESI_Fpo_2*Nw_ESI_Fpo_chip_2,
				P_ESI_Spo_1_1*Nw_ESI_Spo_chip_1_1,	
				P_ESI_Spo_2_1*Nw_ESI_Spo_chip_2_1,	P_ESI_Spo_2_2*Nw_ESI_Spo_chip_2_2,	P_ESI_Spo_2_12*Nw_ESI_Spo_chip_2_12,	
				P_ESI_Spo_3_1*Nw_ESI_Spo_chip_3_1,	P_ESI_Spo_3_2*Nw_ESI_Spo_chip_3_2,	P_ESI_Spo_3_3*Nw_ESI_Spo_chip_3_3,		
				P_ESI_Spo_3_12*Nw_ESI_Spo_chip_3_12,P_ESI_Spo_3_13*Nw_ESI_Spo_chip_3_13,P_ESI_Spo_3_23*Nw_ESI_Spo_chip_3_23,	
				P_ESI_Spo_3_123*Nw_ESI_Spo_chip_3_123,
				P_public_HIU2p*Nw_public_chip,
				P_offB_F*Nw_nongroup_F_chip,	P_offS_F*Nw_nongroup_F_chip,	P_offG_F*Nw_nongroup_F_chip);
		cvrg_public_medicare =
			sum(P_ESI_Spo_1_1*Nw_ESI_Spo_MCR_1_1,
				P_ESI_Spo_2_1*Nw_ESI_Spo_MCR_2_1,	P_ESI_Spo_2_2*Nw_ESI_Spo_MCR_2_2,P_ESI_Spo_2_12*Nw_ESI_Spo_MCR_2_12,
				P_ESI_Spo_3_1*Nw_ESI_Spo_MCR_3_1,	P_ESI_Spo_3_2*Nw_ESI_Spo_MCR_3_2,P_ESI_Spo_3_3*Nw_ESI_Spo_MCR_3_3,
				P_ESI_Spo_3_12*Nw_ESI_Spo_MCR_3_12,	P_ESI_Spo_3_13*Nw_ESI_Spo_MCR_3_13,P_ESI_Spo_3_23*Nw_ESI_Spo_MCR_3_23,
				P_ESI_Spo_3_123*Nw_ESI_Spo_MCR_3_123,
				P_public_HIU2p*Nw_public_MCR,
				P_onB_F*Nw_nongroup_F_MCR,		P_onS_F*Nw_nongroup_F_MCR,		P_onG_F*Nw_nongroup_F_MCR,
				P_offB_F*Nw_nongroup_F_MCR,		P_offS_F*Nw_nongroup_F_MCR,		P_offG_F*Nw_nongroup_F_MCR);

		/**********************************************************************************
		/	Calculate the number of the uninsured
		/*********************************************************************************/
		cvrg_unins = 	
			sum(P_onB_F*Nw_nongroup_F_UN,	P_onS_F*Nw_nongroup_F_UN,	P_onG_F*Nw_nongroup_F_UN,
				P_ESI_S_1_1*Nw_ESI_S_UN_1_1,
				P_ESI_S_2_1*Nw_ESI_S_UN_2_1,P_ESI_S_2_2*Nw_ESI_S_UN_2_2,P_ESI_S_2_12*Nw_ESI_S_UN_2_12,
				P_ESI_S_3_1*Nw_ESI_S_UN_3_1,P_ESI_S_3_2*Nw_ESI_S_UN_3_2,P_ESI_S_3_3*Nw_ESI_S_UN_3_3,
				P_ESI_S_3_12*Nw_ESI_S_UN_3_12,P_ESI_S_3_13*Nw_ESI_S_UN_3_13,P_ESI_S_3_23*Nw_ESI_S_UN_3_23,
				P_ESI_S_3_123*Nw_ESI_S_UN_3_123,
				P_ESI_Spo_1_1*Nw_ESI_Spo_UN_1_1,
				P_ESI_Spo_2_1*Nw_ESI_Spo_UN_2_1,	P_ESI_Spo_2_2*Nw_ESI_Spo_UN_2_2,	P_ESI_Spo_2_12*Nw_ESI_Spo_UN_2_12,
				P_ESI_Spo_3_1*Nw_ESI_Spo_UN_3_1,	P_ESI_Spo_3_2*Nw_ESI_Spo_UN_3_2,	P_ESI_Spo_3_3*Nw_ESI_Spo_UN_3_3,
				P_ESI_Spo_3_12*Nw_ESI_Spo_UN_3_12,	P_ESI_Spo_3_13*Nw_ESI_Spo_UN_3_13,	P_ESI_Spo_3_23*Nw_ESI_Spo_UN_3_23,
				P_ESI_Spo_3_123*Nw_ESI_Spo_UN_3_123,
				P_public_HIU2p*Nw_public_UN,	P_UN_HIU2p*Nw_UN_F,
				P_offB_F*Nw_nongroup_F_UN,		P_offS_F*Nw_nongroup_F_UN,	P_offG_F*Nw_nongroup_F_UN);
		%end;

		/**************************************************************************************
		/	Calculate the number of people whose coverage types are held constant in multi-person HIUs
		/	Note that a multi-person HIU can have people whose coverage types are held constant in that HIU.
		/		even if there are at least two persons whose coverage types are not held constant
		/*************************************************************************************/
		cvrg_medicare_heldconst    	= sum(of care_M[*]);
		cvrg_dual_heldconst 		= sum(of dual_M[*]);  
		cvrg_medicaid_heldconst	  	= sum(sum(of caid_M[*]));
		cvrg_military_heldconst		= sum(of champ_M[*]); 
		cvrg_other_heldconst  		= sum(of other_M[*]); 
		cvrg_ESI_S_heldconst		= sum(of esi_ph_s_M[*]); 
		cvrg_ESI_F_heldconst  		= sum(sum(of esi_ph_f_M[*]),sum(of esi_dep_M[*])); 
		cvrg_offmarket_S_heldconst  = sum(of offmarket_ph_s_M[*]);
		cvrg_offmarket_F_heldconst  = sum(sum(of offmarket_ph_f_M[*]),sum(of offmarket_dep_M[*]));
		cvrg_chip_heldconst	  		= sum(sum(of chip_M[*]));
		cvrg_unins_heldconst	  	= sum(sum(of unin_M[*]));

	/******************************************************************************************
	/	Calculate the policy-related variables (e.g., individual mandate penalty, premium tax
	/	credits, excise tax, cost-sharing reduction payment)
	/*****************************************************************************************/

	/******************************************************************************************
	/	 Calculate variables about individual mandate penalty 
	/*****************************************************************************************/
		/**************************************************************************************
		/	Calculate the expected individual mandate penalty to each HIU if it is subject to
		/	the individual mandate
		/*************************************************************************************/
		IM_PENALTY = sum(P_public_HIU2p	*IM_HIU2p_public			,	
						 P_UN_HIU2p		*IM_HIU2p_UN				,
						 P_ESI_S_1_1	*IM_HIU2p_ESI_S_1_1 		,
						 P_ESI_S_2_1	*IM_HIU2p_ESI_S_2_1 		,
						 P_ESI_S_2_2	*IM_HIU2p_ESI_S_2_2 		,
						 P_ESI_S_2_12	*IM_HIU2p_ESI_S_2_12		,
						 P_ESI_S_3_1	*IM_HIU2p_ESI_S_3_1 		,
						 P_ESI_S_3_2	*IM_HIU2p_ESI_S_3_2 		,
						 P_ESI_S_3_3	*IM_HIU2p_ESI_S_3_3		,
						 P_ESI_S_3_12	*IM_HIU2p_ESI_S_3_12		, 	
						 P_ESI_S_3_13	*IM_HIU2p_ESI_S_3_13 	,	
						 P_ESI_S_3_23	*IM_HIU2p_ESI_S_3_23 	,	
						 P_ESI_S_3_123	*IM_HIU2p_ESI_S_3_123	,	
						 P_ESI_Spo_1_1	*IM_HIU2p_ESI_Spo_1_1 	,	
						 P_ESI_Spo_2_1	*IM_HIU2p_ESI_Spo_2_1 	,	
						 P_ESI_Spo_2_2	*IM_HIU2p_ESI_Spo_2_2 	,	
						 P_ESI_Spo_2_12	*IM_HIU2p_ESI_Spo_2_12	,	
						 P_ESI_Spo_3_1	*IM_HIU2p_ESI_Spo_3_1 	,
						 P_ESI_Spo_3_2	*IM_HIU2p_ESI_Spo_3_2 	,
						 P_ESI_Spo_3_3	*IM_HIU2p_ESI_Spo_3_3	,
						 P_ESI_Spo_3_12	*IM_HIU2p_ESI_Spo_3_12 	,
						 P_ESI_Spo_3_13	*IM_HIU2p_ESI_Spo_3_13 	,
						 P_ESI_Spo_3_23	*IM_HIU2p_ESI_Spo_3_23 	,
						 P_ESI_Spo_3_123*IM_HIU2p_ESI_Spo_3_123	);

		/**************************************************************************************
		/	Calculate the expected average individual mandate penalty per person in an HIU
		/*************************************************************************************/
		IM_PENALTY_avg = sum((N_public_UN		>0)*(P_public_HIU2p	*IM_HIU2p_public		/max(N_public_UN,1)			),		
							 (N_UN_F			>0)*(P_UN_HIU2p		*IM_HIU2p_UN			/max(N_UN_F,1)				),	
							 (N_ESI_S_UN_1_1	>0)*(P_ESI_S_1_1	*IM_HIU2p_ESI_S_1_1 	/max(N_ESI_S_UN_1_1,1)		),
							 (N_ESI_S_UN_2_1	>0)*(P_ESI_S_2_1	*IM_HIU2p_ESI_S_2_1 	/max(N_ESI_S_UN_2_1,1)		),
							 (N_ESI_S_UN_2_2	>0)*(P_ESI_S_2_2	*IM_HIU2p_ESI_S_2_2 	/max(N_ESI_S_UN_2_2,1)		),
							 (N_ESI_S_UN_2_12	>0)*(P_ESI_S_2_12	*IM_HIU2p_ESI_S_2_12	/max(N_ESI_S_UN_2_12,1)		),
							 (N_ESI_S_UN_3_1	>0)*(P_ESI_S_3_1	*IM_HIU2p_ESI_S_3_1 	/max(N_ESI_S_UN_3_1,1)		),
							 (N_ESI_S_UN_3_2	>0)*(P_ESI_S_3_2	*IM_HIU2p_ESI_S_3_2 	/max(N_ESI_S_UN_3_2,1)		),
							 (N_ESI_S_UN_3_3	>0)*(P_ESI_S_3_3	*IM_HIU2p_ESI_S_3_3		/max(N_ESI_S_UN_3_3,1)		),
							 (N_ESI_S_UN_3_12	>0)*(P_ESI_S_3_12	*IM_HIU2p_ESI_S_3_12	/max(N_ESI_S_UN_3_12,1)		), 	
							 (N_ESI_S_UN_3_13	>0)*(P_ESI_S_3_13	*IM_HIU2p_ESI_S_3_13 	/max(N_ESI_S_UN_3_13,1)		),	
							 (N_ESI_S_UN_3_23	>0)*(P_ESI_S_3_23	*IM_HIU2p_ESI_S_3_23 	/max(N_ESI_S_UN_3_23,1)		),	
							 (N_ESI_S_UN_3_123	>0)*(P_ESI_S_3_123	*IM_HIU2p_ESI_S_3_123	/max(N_ESI_S_UN_3_123,1)	),	
							 (N_ESI_Spo_UN_1_1	>0)*(P_ESI_Spo_1_1	*IM_HIU2p_ESI_Spo_1_1 	/max(N_ESI_Spo_UN_1_1,1)	),	
							 (N_ESI_Spo_UN_2_1	>0)*(P_ESI_Spo_2_1	*IM_HIU2p_ESI_Spo_2_1 	/max(N_ESI_Spo_UN_2_1,1)	),	
							 (N_ESI_Spo_UN_2_2	>0)*(P_ESI_Spo_2_2	*IM_HIU2p_ESI_Spo_2_2 	/max(N_ESI_Spo_UN_2_2,1)	),	
							 (N_ESI_Spo_UN_2_12	>0)*(P_ESI_Spo_2_12	*IM_HIU2p_ESI_Spo_2_12	/max(N_ESI_Spo_UN_2_12,1)	),	
							 (N_ESI_Spo_UN_3_1	>0)*(P_ESI_Spo_3_1	*IM_HIU2p_ESI_Spo_3_1 	/max(N_ESI_Spo_UN_3_1,1)	),
							 (N_ESI_Spo_UN_3_2	>0)*(P_ESI_Spo_3_2	*IM_HIU2p_ESI_Spo_3_2 	/max(N_ESI_Spo_UN_3_2,1)	),
							 (N_ESI_Spo_UN_3_3	>0)*(P_ESI_Spo_3_3	*IM_HIU2p_ESI_Spo_3_3	/max(N_ESI_Spo_UN_3_3,1)	),
							 (N_ESI_Spo_UN_3_12	>0)*(P_ESI_Spo_3_12	*IM_HIU2p_ESI_Spo_3_12 	/max(N_ESI_Spo_UN_3_12,1)	),
							 (N_ESI_Spo_UN_3_13	>0)*(P_ESI_Spo_3_13	*IM_HIU2p_ESI_Spo_3_13 	/max(N_ESI_Spo_UN_3_13,1)	),
							 (N_ESI_Spo_UN_3_23	>0)*(P_ESI_Spo_3_23	*IM_HIU2p_ESI_Spo_3_23 	/max(N_ESI_Spo_UN_3_23,1)	),
							 (N_ESI_Spo_UN_3_123>0)*(P_ESI_Spo_3_123*IM_HIU2p_ESI_Spo_3_123	/max(N_ESI_Spo_UN_3_123,1)	));

	/**************************************************************************************
	/	Calculate the number of people in an HIU eligible for the premium tax credits in
	/	the marketplace and the expected subsidy amount
	/*************************************************************************************/
	%if &Marketplace_Exists.=yes %then %do;
		n_elig_PTC_in_hiu = 0; 
		do i = 1 to &dim.;
			if (elig_nongroup_covg[i] = 1 & age[i] ne . & elig_premium_tax_credit_hiu=1)  then n_elig_PTC_in_hiu  = n_elig_PTC_in_hiu + 1;		
		end;
		if (n_elig_PTC_in_hiu > 0 ) then	
			e_onmarket_sub = sum(P_onB_F*min(onmarket_subsidy,prem_onmarket_b),P_onS_F*min(onmarket_subsidy,prem_onmarket_s),P_onG_F*min(onmarket_subsidy,prem_onmarket_g))/n_elig_PTC_in_hiu; 
		else e_onmarket_sub = 0;
	%end;

	/**************************************************************************************
	/	Calculate the excise tax amount
	/*************************************************************************************/
	ET_total=0;
	%do i=1 %to &DIM.;
		%macro o_type(TYP);
		if offer_&TYP.[&i.]=1 then do;
			/******************************************************************************
			/	For ESI family offer
			/*****************************************************************************/
			if offer_family_sim_1 = 1 and p_index[1] = &i. then do;
				ET_total=sum(ET_total,sum(P_ESI_F_1*Nw_ESI_F_&TYP._1,P_ESI_Fpo_1*Nw_ESI_Fpo_&TYP._1,P_ESI_FpCD_1*Nw_ESI_FpCD_&TYP._1)*max(0,esi_f_prem_&TYP._tot[&i.]-(&EXCISE_TAX_THRESH_F.))*&ET_RATE.);
			end;
			if offer_family_sim_2 = 1 and p_index[2] = &i. then do;
				ET_total=sum(ET_total,sum(P_ESI_F_2*Nw_ESI_F_&TYP._2,P_ESI_Fpo_2*Nw_ESI_Fpo_&TYP._2,P_ESI_FpCD_2*Nw_ESI_FpCD_&TYP._2)*max(0,esi_f_prem_&TYP._tot[&i.]-(&EXCISE_TAX_THRESH_F.))*&ET_RATE.);
			end;
			/******************************************************************************
			/	For ESI single offer
			/*****************************************************************************/
			if p_index[1]=&i. then do;
				ET_total=sum(ET_total,wgt[&i.]*sum(P_ESI_S_1_1,P_ESI_S_2_1,P_ESI_S_2_12,P_ESI_S_3_1,P_ESI_S_3_12,P_ESI_S_3_13,P_ESI_S_3_123,P_ESI_Spo_1_1,P_ESI_Spo_2_1,P_ESI_Spo_2_12,P_ESI_Spo_3_1,P_ESI_Spo_3_12,P_ESI_Spo_3_13,P_ESI_Spo_3_123)*max(0,esi_s_prem_&TYP._tot[&i.]-(&EXCISE_TAX_THRESH_S.))*&ET_RATE.);
			end;
			if p_index[2]=&i. then do;
				ET_total=sum(ET_total,wgt[&i.]*sum(P_ESI_S_2_2,P_ESI_S_2_12,P_ESI_S_3_2,P_ESI_S_3_12,P_ESI_S_3_23,P_ESI_S_3_123,P_ESI_Spo_2_2,P_ESI_Spo_2_12,P_ESI_Spo_3_2,P_ESI_Spo_3_12,P_ESI_Spo_3_23,P_ESI_Spo_3_123)*max(0,esi_s_prem_&TYP._tot[&i.]-(&EXCISE_TAX_THRESH_S.))*&ET_RATE.);
			end;
			if p_index[3]=&i. then do;
				ET_total=sum(ET_total,wgt[&i.]*sum(P_ESI_S_3_3,P_ESI_S_3_13,P_ESI_S_3_23,P_ESI_S_3_123,P_ESI_Spo_3_3,P_ESI_Spo_3_13,P_ESI_Spo_3_23,P_ESI_Spo_3_123)*max(0,esi_s_prem_&TYP._tot[&i.]-(&EXCISE_TAX_THRESH_S.))*&ET_RATE.);
			end;
		end;
		%mend o_type; 
		%o_type(PPO); %o_type(HMO); %o_type(HDHP);
	%end;

	/**************************************************************************************
	/	Calculate the expected insurers' cost, expected premiums for the insurers, 
	/	and cost-sharing reduction payment in the marketplaces
	/*************************************************************************************/

		/**************************************************************************************
		/	Initialize arrays to zero
		/*************************************************************************************/
		%initialize_array_0;

		/**************************************************************************************
		/	Initialize the location array to zero
		/*************************************************************************************/
		do i=1 to &DIM.;
			location[i] = 0;
		end;

		/************************************************************************************** 
		/	Count the number of people who can make non-group plan purchase decisions, 
		/	i.e. people who are lawfully present and ineligible for public insurance  
		/		 (excluding those whose coverage types were held constant and non-dependent children)
		/	and populate the location array indexing the person number corresponding to 
		/		the total number of people who can choose non-group plans in an HIU
		/*************************************************************************************/
		c = 0;
		N = 0;
		do i=1 to &DIM.;
			if	market_ID_primary[i]=1 and medicaid_CHIP_elig[i] ne 1 and medicare_elig[i] ne 1 and age[i] ne . and undoc[i]=0 then do;
				c = c+1;
				N = sum(N,wgt[i]/wgt[i]);
				location[c] = i;
			end;
		end;

		/**************************************************************************************
		/	Estimate HIU-level health spending probabilities for family plan coverage options
		/	The macro outputs individual-specific arrays of prob_hlth_hiu and spend_hlth_hiu
		/	Note: For details about probability distribution of health spending, see 
		/		  Jessica Banthin and others, Sources and Preparation of Data Used in HISIM2CBOs
		/		  Health Insurance Simulation Model, Working Paper 2019-04 (Congressional Budget
		/		  Office, April 2019), www.cbo.gov/publication/55087						
		/*************************************************************************************/	
		%estimate_HIU_HS_probs;

		/**************************************************************************************
		/	For multi-person HIU's who can choose multiple coverage types for 
		/		alternatives related to ESI or nongroup plans
		/		or none in the HIU is eligible for Medicaid or CHIP
		/*************************************************************************************/
		if split_decision_hiu = 1 or N_medicaid_CHIP_elig = 0 then do;

			/**********************************************************************************
			/	Initialize count variables to 0
			/*********************************************************************************/
			%initialize_n_to_0;

			/**********************************************************************************
			/	Calculate total number of people eligible for non-group plans 
			/	(excluding people whose coverage types are held constant or who are eligible for public insurance)
			/*********************************************************************************/
			%if &Marketplace_Exists.=yes %then %do;
		   		%do i=1 %to &DIM.;
		    		if medicaid_CHIP_elig[&i.] ne 1 and medicare_elig[&i.] ne 1 and age[&i.] ne . and undoc[&i.]=0 then do;
			 			N_nongroup  = sum(N_nongroup,	wgt[&i.]/wgt[&i.]);
			 			Nw_nongroup = sum(Nw_nongroup,	wgt[&i.]);
		    		end;
				%end;
			%end;

			/**********************************************************************************
			/	For HIUs with at least 1 person eligible for the non-group plans 
			/*********************************************************************************/
			if N_nongroup>0 then do;

				/******************************************************************************
				/	For HIUs with 2 or more members eligible for the non-group plans 
				/*****************************************************************************/
				if N>1 then do;

					/**************************************************************************
					/	Calculate the expected out-of-pocket health care spending of enrolling 
					/	in non-group plans in the marketplace in total and by tier, 
					/	looping through all 16 possible health states  
					/*************************************************************************/		
					do j=1 to 16;

						e_tot_spend_hlth[j] 			= prob_hlth_hiu[j]*spend_hlth_hiu[j];

						if coin_nongroup_pre_b>0 then do;
						 e_oop_spend_onB_hlth[j] = prob_hlth_hiu[j]*sum((spend_hlth_hiu[j]<=2*ded_nongroup_b/coin_nongroup_pre_b)*(spend_hlth_hiu[j]*coin_nongroup_pre_b),(spend_hlth_hiu[j]>2*ded_nongroup_b/coin_nongroup_pre_b)*(min(sum(2*ded_nongroup_b,(spend_hlth_hiu[j]-2*ded_nongroup_b)*coin_nongroup_post_b),moop_nongroup_b)));
						end;
						if coin_nongroup_pre_s>0 then do;
			 			 e_oop_spend_onS_hlth[j] = prob_hlth_hiu[j]*sum((spend_hlth_hiu[j]<=2*ded_nongroup_s/coin_nongroup_pre_s)*(spend_hlth_hiu[j]*coin_nongroup_pre_s),(spend_hlth_hiu[j]>2*ded_nongroup_s/coin_nongroup_pre_s)*(min(sum(2*ded_nongroup_s,(spend_hlth_hiu[j]-2*ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)));
						end;
						if coin_nongroup_pre_g>0 then do;
			 			 e_oop_spend_onG_hlth[j] = prob_hlth_hiu[j]*sum((spend_hlth_hiu[j]<=2*ded_nongroup_g/coin_nongroup_pre_g)*(spend_hlth_hiu[j]*coin_nongroup_pre_g),(spend_hlth_hiu[j]>2*ded_nongroup_g/coin_nongroup_pre_g)*(min(sum(2*ded_nongroup_g,(spend_hlth_hiu[j]-2*ded_nongroup_g)*coin_nongroup_post_g),moop_nongroup_g)));
						end;	

						if coin_nongroup_pre_b=0 then do;
						 e_oop_spend_onB_hlth[j] = prob_hlth_hiu[j]*sum((spend_hlth_hiu[j]<=2*ded_nongroup_b)*(spend_hlth_hiu[j]*coin_nongroup_pre_b),(spend_hlth_hiu[j]>2*ded_nongroup_b)*(min(sum(2*ded_nongroup_b,(spend_hlth_hiu[j]-2*ded_nongroup_b)*coin_nongroup_post_b),moop_nongroup_b)));
						end;
						if coin_nongroup_pre_s=0 then do;
			 			 e_oop_spend_onS_hlth[j] = prob_hlth_hiu[j]*sum((spend_hlth_hiu[j]<=2*ded_nongroup_s)*(spend_hlth_hiu[j]*coin_nongroup_pre_s),(spend_hlth_hiu[j]>2*ded_nongroup_s)*(min(sum(2*ded_nongroup_s,(spend_hlth_hiu[j]-2*ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)));
						end;
						if coin_nongroup_pre_g=0 then do;
			 			 e_oop_spend_onG_hlth[j] = prob_hlth_hiu[j]*sum((spend_hlth_hiu[j]<=2*ded_nongroup_g)*(spend_hlth_hiu[j]*coin_nongroup_pre_g),(spend_hlth_hiu[j]>2*ded_nongroup_g)*(min(sum(2*ded_nongroup_g,(spend_hlth_hiu[j]-2*ded_nongroup_g)*coin_nongroup_post_g),moop_nongroup_g)));
						end;	

					end;
				end;

				/******************************************************************************
				/	For HIUs with only one member eligible for the non-group plans
				/*****************************************************************************/
				else if N=1 then do;
					
					/**************************************************************************
					/	Locate that member and 
					/	Calculate the expected out-of-pocket health care spending of enrolling 
					/	in non-group plans in the marketplace in total and by tier, 
					/	looping through all 16 possible health states. 
					/	Note: the arrays of prob&p.[j] and SPEND&p.[j] are the probability of being 
					/		  in health status[j] and related spending for person &p. in the HIU 
					/		  For details about probability distribution of health spending, 
					/		  see Jessica Banthin and others, Sources and Preparation of Data Used
					/		  in HISIM2CBOs Health Insurance Simulation Model, Working Paper 2019-04
					/		  (Congressional Budget Office, April 2019), www.cbo.gov/publication/55087								
					/*************************************************************************/
					%do p=1 %to &DIM.;
						if &p.=location[1] then do;
							do j=1 to 16;

								e_tot_spend_hlth[j] 			= prob&p.[j]*SPEND&p.[j];			
								
								if coin_nongroup_pre_b>0 then do;
								 e_oop_spend_onB_hlth[j] = prob&p.[j]*sum((SPEND&p.[j]<=ded_nongroup_b/coin_nongroup_pre_b)*(SPEND&p.[j]*coin_nongroup_pre_b),(SPEND&p.[j]>ded_nongroup_b/coin_nongroup_pre_b)*(min(sum(ded_nongroup_b,(SPEND&p.[j]-ded_nongroup_b)*coin_nongroup_post_b),moop_nongroup_b)));
								end;
								if coin_nongroup_pre_s>0 then do;
					 			 e_oop_spend_onS_hlth[j] = prob&p.[j]*sum((SPEND&p.[j]<=ded_nongroup_s/coin_nongroup_pre_s)*(SPEND&p.[j]*coin_nongroup_pre_s),(SPEND&p.[j]>ded_nongroup_s/coin_nongroup_pre_s)*(min(sum(ded_nongroup_s,(SPEND&p.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)));
								end;
								if coin_nongroup_pre_g>0 then do;
					 			 e_oop_spend_onG_hlth[j] = prob&p.[j]*sum((SPEND&p.[j]<=ded_nongroup_g/coin_nongroup_pre_g)*(SPEND&p.[j]*coin_nongroup_pre_g),(SPEND&p.[j]>ded_nongroup_g/coin_nongroup_pre_g)*(min(sum(ded_nongroup_g,(SPEND&p.[j]-ded_nongroup_g)*coin_nongroup_post_g),moop_nongroup_g)));
								end;	

								if coin_nongroup_pre_b=0 then do;
								 e_oop_spend_onB_hlth[j] = prob&p.[j]*sum((SPEND&p.[j]<=ded_nongroup_b)*(SPEND&p.[j]*coin_nongroup_pre_b),(SPEND&p.[j]>ded_nongroup_b)*(min(sum(ded_nongroup_b,(SPEND&p.[j]-ded_nongroup_b)*coin_nongroup_post_b),moop_nongroup_b)));
								end;
								if coin_nongroup_pre_s=0 then do;
					 			 e_oop_spend_onS_hlth[j] = prob&p.[j]*sum((SPEND&p.[j]<=ded_nongroup_s)*(SPEND&p.[j]*coin_nongroup_pre_s),(SPEND&p.[j]>ded_nongroup_s)*(min(sum(ded_nongroup_s,(SPEND&p.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)));
								end;
								if coin_nongroup_pre_g=0 then do;
					 			 e_oop_spend_onG_hlth[j] = prob&p.[j]*sum((SPEND&p.[j]<=ded_nongroup_g)*(SPEND&p.[j]*coin_nongroup_pre_g),(SPEND&p.[j]>ded_nongroup_g)*(min(sum(ded_nongroup_g,(SPEND&p.[j]-ded_nongroup_g)*coin_nongroup_post_g),moop_nongroup_g)));
								end;	

							end;  	
						end;		
					%end;			
				end;

				/******************************************************************************
				/	Calculate the HIU-level expected out-of-pocket health spending
				/*****************************************************************************/
				e_tot_spend_hiu2p = sum(of e_tot_spend_hlth[*] );  						
		   		e_oop_spend_onB_hiu2p   = sum(of e_oop_spend_onB_hlth[*] );
		   		e_oop_spend_onS_hiu2p   = sum(of e_oop_spend_onS_hlth[*] );
		   		e_oop_spend_onG_hiu2p   = sum(of e_oop_spend_onG_hlth[*] );

				/******************************************************************************
				/	Calculate the HIU-level expected cost to the insurer
				/	Note: Nongroup plan characteristics (such as deductibles, copays, and coinsurance)
				/		  are assumed to be same between the plans in and outside the marketplaces
				/		  for a certain state and tier in the model, because insurers are required  
				/		  to offer the same plan outside the marketplaces as in marketplaces under current law.
				/*****************************************************************************/
				e_ins_spend_onB		= ((e_tot_spend_hiu2p-e_oop_spend_onB_hiu2p)/N_nongroup)*sum(P_onB_F)*Nw_nongroup;
				e_ins_spend_onS 	= ((e_tot_spend_hiu2p-e_oop_spend_onS_hiu2p)/N_nongroup)*sum(P_onS_F)*Nw_nongroup;
				e_ins_spend_onG 	= ((e_tot_spend_hiu2p-e_oop_spend_onG_hiu2p)/N_nongroup)*sum(P_onG_F)*Nw_nongroup;

				e_ins_spend_offB 	= ((e_tot_spend_hiu2p-e_oop_spend_onB_hiu2p)/N_nongroup)*sum(P_offB_F)*Nw_nongroup;
				e_ins_spend_offS 	= ((e_tot_spend_hiu2p-e_oop_spend_onS_hiu2p)/N_nongroup)*sum(P_offS_F)*Nw_nongroup;
				e_ins_spend_offG	= ((e_tot_spend_hiu2p-e_oop_spend_onG_hiu2p)/N_nongroup)*sum(P_offG_F)*Nw_nongroup;

				/******************************************************************************
				/	Calculate the HIU-level expected premiums for the insurer
				/*****************************************************************************/
				e_ins_prem_onB      	= (prem_onmarket_b/N_nongroup)*sum(P_onB_F)*Nw_nongroup;
				e_ins_prem_onS      	= (prem_onmarket_s/N_nongroup)*sum(P_onS_F)*Nw_nongroup;
				e_ins_prem_onG      	= (prem_onmarket_g/N_nongroup)*sum(P_onG_F)*Nw_nongroup;

				e_ins_prem_offB		    = (prem_offmarket_b/N_nongroup)	*sum(P_offB_F)*Nw_nongroup;
				e_ins_prem_offS	 	    = (prem_offmarket_s/N_nongroup)	*sum(P_offS_F)*Nw_nongroup;
				e_ins_prem_offG		    = (prem_offmarket_g/N_nongroup)	*sum(P_offG_F)*Nw_nongroup;

				/******************************************************************************
				/	Calculate the HIU-level expected cost-sharing reduction payment
				/*****************************************************************************/
				e_csr_payment		   = Nw_nongroup*((CS_VALUE*P_onS_F)/N_nongroup);
			end;
		end;

		/**************************************************************************************
		/	Calculate the adjusted weights for non-dependent children 
		/	Note: Non-dependent children appear in two separate rows, 
		/		  (1) one for the case where those children are covered by ESI family plan (in multi-person HIUs), and 
		/		  (2) the other for the case where those children are their own marketplace unit (in single-person HIUs)
		/		  The weight of a non-dependent child is split into two to take this structure into account.		
		/   	  The non-dependent children will be allowed to make decisions in the single-person HIU world 
		/		  with their weights deflated by 1-(Probability of being on ESI family plan).
		/*************************************************************************************/
		wgt_adj = 1-sum(P_ESI_F_1,P_ESI_F_2,P_ESI_Fpo_1,P_ESI_Fpo_2,P_ESI_FpCD_1,P_ESI_FpCD_2);

 	/******************************************************************************************
	/	Output the HIU-level data for multi-person HIUs 
	/*****************************************************************************************/
	output tempx.apply_model_base_hiu2p;
run;

%mend simulate_multi_person_HIUs;
