/*=============================================================================================
/	Module Name	: simulate_single_person_HIUs.sas
/	Purpose		: To calculate the probability of choosing each available alternative for single-person HIUs and			
/				     calculate the enrollment by coverage type
/	Inputs		: Data file "hiu_size_1" from prep_for_simulated_hiu_file.sas
/				  Data file "apply_model_base_hiu2p" from simulate_multi_person_HIUs.sas
/	Outputs		: Data file "apply_model_base_hiu1" containing simulated HIUs' choices at the HIU-level for single-person HIUs
/	Summary		: 
/	(1) Calculate the probability of choosing each available alternative
/		(1-a) Calculate HIU's utility from choosing each available alternative
/		(1-b) Calculate HIU's probability of choosing each alternative 
/			  (Refer to Section 4.4.2. in Train 2009 for the probability formula )  
/	(2) Calculate policy-related variables: (e.g., individual mandate penalty, premium tax
/		credits, excise tax, cost-sharing reduction payment)
/		Notes:  For single-person HIUs, the calculations of probabilities of choosing alternatives 
/				are based on the Nested Logit (NL) model and 
/				the utility from choosing an alternative is defined in the slide deck. 
/			For the functional form of the probabilities in NL model, refer to 
/				Kenneth Train, "Discrete Choice Methods with Simulation", Cambridge University Press
/				Second edition, 2009.
/ 			For the utility function, see Congressional Budget Office, HISIM2The Health Insurance
/				Simulation Model Used in Preparing CBOs Spring 2019 Baseline Budget Projections   
/				(April 2019), www.cbo.gov/publication/55097.
//	The code is written in SAS, version 9.4.
/============================================================================================*/

%macro simulate_single_person_HIUs;

proc sort data = tempx.hiu_size_1; 
	by OLD_H_SEQ HIU_ID; 
run;
proc sort data = tempx.apply_model_base_hiu2p 
		   out = wgtadj(keep = OLD_H_SEQ HIU_ID wgt_adj); 
	by OLD_H_SEQ HIU_ID; 
run;

data tempx.apply_model_base_hiu1;
	/******************************************************************************************
	/	Merge the adjusted weights for non-dependent children from the multi-person HIU data 
	/		onto the single-person HIU data 
	/*****************************************************************************************/

	merge tempx.hiu_size_1 	(in=a)
	      		wgtadj     	(in=b);
	by OLD_H_SEQ HIU_ID;
	if a;
	
	/******************************************************************************************
	/	Calculate utilities to calculate probabilities
	/*****************************************************************************************/

		/**************************************************************************************
		/	Declare arrays of variables (not including people held constant)
		/*************************************************************************************/
		%Set_Arrays(firm_arrays=no,hiu_arrays=yes);

		/**************************************************************************************
		/	Declare arrays of variables for people held constant (i.e., var_M)
		/*************************************************************************************/
		array care_M     		{&DIM.} care_1			-	care_&DIM.;
		array dual_M     		{&DIM.} dual_1			-	dual_&DIM.;
		array caid_M     		{&DIM.} caid_1			-	caid_&DIM.;
		array champ_M    		{&DIM.} champ_1			-	champ_&DIM.;
		array other_M    		{&DIM.} other_1			-	other_&DIM.;
		array esi_ph_s_M 		{&DIM.} esi_ph_s_1		-	esi_ph_s_&DIM.;
		array esi_ph_f_M 		{&DIM.} esi_ph_f_1		-	esi_ph_f_&DIM.;
		array esi_dep_M  		{&DIM.} esi_dep_1		-	esi_dep_&DIM.;
		array offmarket_ph_s_M  {&DIM.} offmarket_ph_s_1-	offmarket_ph_s_&DIM.;
		array offmarket_ph_f_M  {&DIM.} offmarket_ph_f_1-	offmarket_ph_f_&DIM.;
		array offmarket_dep_M   {&DIM.} offmarket_dep_1	-	offmarket_dep_&DIM.;
		array chip_M     		{&DIM.} chip_1			-	chip_&DIM.;
		array unin_M     		{&DIM.} unin_1			-	unin_&DIM.;

		/**************************************************************************************
		/	Declare arrays of the primary marketplace unit variable
		/*************************************************************************************/
		array market_ID_primary {&DIM.} market_ID_primary_1-market_ID_primary_&DIM.;

		/**************************************************************************************
		/	Adjust weights for non-dependent children 
		/	Note: Non-dependent children appear in two separate rows, 
		/		  (1) one for the case where those children are covered by ESI family plan (in multi-person HIUs), and 
		/		  (2) the other for the case where those children are their own marketplace unit (in single-person HIUs)
		/		  The weight of a non-dependent child is split into two to take this structure into account.		
		/   	  The non-dependent children will be allowed to make decisions in the single-person HIU world 
		/		  with their weights deflated by 1-(Probability of being on ESI family plan).
		/*************************************************************************************/
		if wgt_adj =. then wgt_adj = 1;
		do i=1 to &DIM.;
			if wgt[i] ne .	then do;
				wgt[i] 	 = wgt[i]*wgt_adj;
			if wgt[i]= 0	then delete;
			end;
		end;

		/**************************************************************************************
		/	Initialize arrays to zero
		/*************************************************************************************/
		%initialize_array_0;

		/**************************************************************************************
		/	Calculate the utilities from choosing the alternatives of non-group plans (in and
		/	outside the marketplace)
		/*************************************************************************************/
		%if &Marketplace_Exists.=yes %then %do;
			%calc_U_nongroup_hiu1(firm_u=no,hiu_u=yes);
		%end;

		/**************************************************************************************
		/	Calculate the utilities from choosing the alternatives of ESI plans
		/*************************************************************************************/
		%calc_U_ESI_S_hiu1(firm_u=no,hiu_u=yes);

		/**************************************************************************************
		/	Calculate the utilities from choosing the alternatives of public insurance if
		/	eligible
		/*************************************************************************************/
		%calc_U_public_hiu1(firm_u=no,hiu_u=yes);  

		/**************************************************************************************
		/	Calculate the utilities from choosing to be uninsured
		/*************************************************************************************/
		%calc_U_uninsured_hiu1(firm_u=no,hiu_u=yes); 

	/******************************************************************************************
	/	Calculate the choice probabilities using utilities calculated above
	/	Notes:	Probabilities in NL model consist of the exponential functions of HIU's
	/			utilities, and the dissimilarity parameters (or mu's).
	/			In NL, the allocation parameters (or alpha's) are set to 1, because an alternative
	/			belongs to only one nest.
	/*****************************************************************************************/

		/**************************************************************************************
		/	Initialize arrays to zero
		/*************************************************************************************/
		%initialize_array_0;

		/**********************************************************************************
		/	Calculate predicted value of a specified alternative if utility							
		/			for the alternative was defined. 
		/			(If the utility value of an HIU for a given alternative is missing, 
		/			HIU is not eligible for that alternative.)  
 		/	Note: 	709 is the largest number that can be exponentiated. 
		/			None actually hit the cap in the model
		/*********************************************************************************/
		%macro exp_s(utility);
			if U_&utility. ne . then do;
				if 		(beta_hiu1*U_&utility./&DIV_HIU1.)<	 709 then exp_U_&utility.= exp(beta_hiu1*U_&utility./&DIV_HIU1.);
				else if (beta_hiu1*U_&utility./&DIV_HIU1.)>= 709 then exp_U_&utility.= exp(709);
			end;
		%mend exp_s;
		%if &Marketplace_Exists.=yes %then %do;
			%exp_s(onB_S_HIU1);		%exp_s(onS_S_HIU1);		%exp_s(onG_S_HIU1);
			%exp_s(offB_S_HIU1);	%exp_s(offS_S_HIU1);	%exp_s(offG_S_HIU1);
		%end;
		%exp_s(ESI_S_HIU1);
		%exp_s(public_HIU1);
		%exp_s(UN_HIU1);

	 	/**************************************************************************************
		/	Create the variables needed to calculate the probability of being in the ESI nest
		/*************************************************************************************/

			/**************************************************************************************
			/	Set allocation parameters related to ESI
			/	Note that alpha is 1 for single-person HIUs (NL model)
			/*************************************************************************************/
		 	alpha_esi1		= 1;

			/**************************************************************************************
			/	Read in the dissimilarity parameter for the ESI nest
			/*************************************************************************************/
		 	mu_esi    		= &mu_esi.;

			/**************************************************************************************
			/	Calculate a component of the ESI nest probability
			/*************************************************************************************/
		 	exp_ESI_nstESI  = (exp_U_ESI_S_HIU1   *alpha_esi1)**(1/mu_esi);
		 	sum_Nst_esi 	= sum(exp_ESI_nstESI);

	 	/**************************************************************************************
		/	Create the variables needed to calculate the probability of being in the nest of
		/	non-group plans in the marketplace
		/*************************************************************************************/

			/**************************************************************************************
			/	Set allocation parameters related to non-group plans in the marketplace
			/	Note that alpha is 1 for single-person HIUs
			/*************************************************************************************/
		 	alpha_onmarket1		= 1;

			/**************************************************************************************
			/	Read in the dissimilarity parameter for the nest of non-group in the marketplace
			/*************************************************************************************/
			mu_onmarket	= &mu_onmarket.;

			/**************************************************************************************
			/	Calculate components of the probability of being in the nest of non-group plans in the marketplace
			/*************************************************************************************/
			%if &Marketplace_Exists.=yes %then %do;
		 		exp_U_B_Nst_onmarket	= (exp_U_onB_S_HIU1*alpha_onmarket1)**(1/mu_onmarket);
		 		exp_U_S_Nst_onmarket	= (exp_U_onS_S_HIU1*alpha_onmarket1)**(1/mu_onmarket);
		 		exp_U_G_Nst_onmarket	= (exp_U_onG_S_HIU1*alpha_onmarket1)**(1/mu_onmarket);
		 		sum_Nst_onmarket_hiu1= sum(exp_U_B_Nst_onmarket,exp_U_S_Nst_onmarket,exp_U_G_Nst_onmarket);
			%end;

	 	/**************************************************************************************
		/	Create the variables needed to calculate the probability of being in the nest of
		/	non-group plans outside the marketplace
		/*************************************************************************************/

			/**************************************************************************************
			/	Set allocation parameters related to non-group plans outside the marketplaces
			/	Note that alpha is 1 for single-person HIUs
			/*************************************************************************************/
		 	alpha_offmarket1		= 1;

			/**************************************************************************************
			/	Read in the dissimilarity parameter for the nest of non-group plans outside the marketplace
			/*************************************************************************************/
		 	mu_offmarket  	= &mu_offmarket.;

			/**************************************************************************************
			/	Calculate components of the probability of being in the nest of non-group plans outside the
			/	marketplaces
			/*************************************************************************************/
			%if &Marketplace_Exists.=yes %then %do;
		 		exp_U_B_Nst_offmarket	= (exp_U_offB_S_HIU1*alpha_offmarket1)**(1/mu_offmarket);
		 		exp_U_S_Nst_offmarket	= (exp_U_offS_S_HIU1*alpha_offmarket1)**(1/mu_offmarket);
		 		exp_U_G_Nst_offmarket	= (exp_U_offG_S_HIU1*alpha_offmarket1)**(1/mu_offmarket);
		 		sum_Nst_offmarket_hiu1	= sum(exp_U_B_Nst_offmarket,exp_U_S_Nst_offmarket,exp_U_G_Nst_offmarket);
			%end;

	 	/**************************************************************************************
		/	Create the variables needed and calculate the probability of being in the nest of
		/	public insurance
		/*************************************************************************************/

			/**************************************************************************************
			/	Set allocation parameters related to public insurance
			/	Note that alpha is 1 for single-person HIUs
			/*************************************************************************************/
		 	alpha_public1	= 1;

			/**************************************************************************************
			/	Read in the dissimilarity parameter for the public insurance nest
			/*************************************************************************************/
		 	mu_public    	= &mu_public.;

			/**************************************************************************************
			/	Calculate a component of the probability of being in the nest of public insurance
			/*************************************************************************************/
		 	exp_U_public_Nst_public_hiu1  = (exp_U_public_HIU1 * alpha_public1)**(1/mu_public); 
		 	sum_Nst_public 	= sum(exp_U_public_Nst_public_hiu1);

	 	/**************************************************************************************
		/	Being uninsured is in its own nest and the exponentiated utility is exp_U_UN_HIU1
		/*************************************************************************************/

	 	/**************************************************************************************
		/	Calculate the probability of being in each nest: 
		/	ESI, non-group (in and outside the marketplace), Public insurance, and uninsured 
		/*************************************************************************************/
	 	denom 		= sum((sum_Nst_esi)**(mu_esi),(sum_Nst_onmarket_hiu1)**(mu_onmarket),(sum_Nst_offmarket_hiu1)**(mu_offmarket),(sum_Nst_public)**(mu_public),exp_U_UN_HIU1);
	 	P_ESI 		= (sum_Nst_esi)				**(mu_esi)			/denom;
	 	P_onmarket  = (sum_Nst_onmarket_hiu1)	**(mu_onmarket )	/denom;
	 	P_offmarket = (sum_Nst_offmarket_hiu1)	**(mu_offmarket )	/denom;
	 	P_public  	= (sum_Nst_public)			**(mu_public )		/denom;
	 	P_UN  		= (exp_U_UN_HIU1)								/denom;

	 	/**************************************************************************************
		/	Calculate the choice probability of a specific coverage type
		/*************************************************************************************/
	 	P_ESI_nstESI  	= P_ESI*exp_ESI_nstESI /sum_Nst_esi;

		%if &Marketplace_Exists.=yes %then %do;
		 	P_onB_Nst_onmarket	= P_onmarket*exp_U_B_Nst_onmarket	/sum_Nst_onmarket_hiu1;
		 	P_onS_Nst_onmarket	= P_onmarket*exp_U_S_Nst_onmarket	/sum_Nst_onmarket_hiu1;
		 	P_onG_Nst_onmarket	= P_onmarket*exp_U_G_Nst_onmarket	/sum_Nst_onmarket_hiu1;
		 	
		 	P_offB_Nst_offmarket= P_offmarket*exp_U_B_Nst_offmarket	/sum_Nst_offmarket_hiu1;
		 	P_offS_Nst_offmarket= P_offmarket*exp_U_S_Nst_offmarket	/sum_Nst_offmarket_hiu1;
		 	P_offG_Nst_offmarket= P_offmarket*exp_U_G_Nst_offmarket	/sum_Nst_offmarket_hiu1;
		%end;
	 	
	 	P_public_Nst_public   	= P_public*exp_U_public_Nst_public_hiu1 /sum_Nst_public;
	 	
	 	P_UN_nstUN    	= P_UN;

	/******************************************************************************************
	/	Calculate the number of people with certain coverage types
	/*****************************************************************************************/

		/**************************************************************************************
		/	Calculate the number of people who enroll in ESI single plan by plan type
		/*************************************************************************************/
		P_PPO_HIU1	= P_ESI_nstESI*Nw_ESI_PPO_HIU1 ;  
	 	P_HMO_HIU1	= P_ESI_nstESI*Nw_ESI_HMO_HIU1 ;
	 	P_HDHP_HIU1	= P_ESI_nstESI*Nw_ESI_HDHP_HIU1 ;

		cvrg_ESI_S_PPO_hiu1  = sum(P_PPO_HIU1);	
		cvrg_ESI_S_HMO_hiu1  = sum(P_HMO_HIU1);	
		cvrg_ESI_S_HDHP_hiu1 = sum(P_HDHP_HIU1);

		/**************************************************************************************
		/	Calculate the number of people who enroll in non-group plans in and outside
		/	the marketplaces (subsidized vs unsubsidized)
		/*************************************************************************************/
		%if &Marketplace_Exists.=yes %then %do;
	 		cvrg_B_onmarket_hiu1 	= P_onB_Nst_onmarket*Nw_nongroup_HIU1;
	 		cvrg_S_onmarket_hiu1 	= P_onS_Nst_onmarket*Nw_nongroup_HIU1;
	 		cvrg_G_onmarket_hiu1 	= P_onG_Nst_onmarket*Nw_nongroup_HIU1;
	 		cvrg_B_offmarket_hiu1  	= P_offB_Nst_offmarket*Nw_nongroup_HIU1;
	 		cvrg_S_offmarket_hiu1  	= P_offS_Nst_offmarket*Nw_nongroup_HIU1;
	 		cvrg_G_offmarket_hiu1  	= P_offG_Nst_offmarket*Nw_nongroup_HIU1;

			if GET_SUB ne 1 then GET_SUB=0; 
				cvrg_B_onmarket_sub_hiu1 	= sum(cvrg_B_onmarket_hiu1)*GET_SUB;
				cvrg_S_onmarket_sub_hiu1 	= sum(cvrg_S_onmarket_hiu1)*GET_SUB;
				cvrg_G_onmarket_sub_hiu1 	= sum(cvrg_G_onmarket_hiu1)*GET_SUB;

				cvrg_B_onmarket_nosub_hiu1 	= sum(cvrg_B_onmarket_hiu1)*(1-GET_SUB);
				cvrg_S_onmarket_nosub_hiu1 	= sum(cvrg_S_onmarket_hiu1)*(1-GET_SUB);
				cvrg_G_onmarket_nosub_hiu1 	= sum(cvrg_G_onmarket_hiu1)*(1-GET_SUB);

				cvrg_B_offmarket_hiu1	 		= sum(cvrg_B_offmarket_hiu1);
				cvrg_S_offmarket_hiu1 			= sum(cvrg_S_offmarket_hiu1);
				cvrg_G_offmarket_hiu1 			= sum(cvrg_G_offmarket_hiu1);
		%end;

		/**************************************************************************************
		/	Calculate the number of people with public insurance
		/*************************************************************************************/
	 	cvrg_medicaid_pe_hiu1	= P_public_Nst_public*Nw_MCDpe_hiu1;   	
	 	cvrg_medicaid_ne_hiu1	= P_public_Nst_public*Nw_MCDne_hiu1;	 	
		cvrg_medicare_hiu1		= P_public_Nst_public*Nw_Medicare_hiu1;		

		cvrg_medicaid_pe_hiu1	= sum(cvrg_medicaid_pe_hiu1);
		cvrg_medicaid_ne_hiu1	= sum(cvrg_medicaid_ne_hiu1);
		cvrg_medicare_hiu1     	= sum(cvrg_medicare_hiu1);

		/**************************************************************************************
		/	Calculate the number of the uninsured
		/*************************************************************************************/
		cvrg_unins_hiu1	= P_UN_nstUN*Nw_unins_hiu1;					
		cvrg_unins_hiu1	= sum(cvrg_unins_hiu1);

		/**************************************************************************************
		/	Calculate the number of people whose coverage types are held constant in single-person HIUs
		/	Note that a single-person HIU can have more than one person in the HIU 
		/		as long as there is only one person whose coverage type is not held constant
		/*************************************************************************************/
		cvrg_medicare_heldconst    	= sum(of care_M[*]);
		cvrg_dual_heldconst 		= sum(of dual_M[*]);  
		cvrg_medicaid_heldconst	  	= sum(sum(of caid_M[*]));
		cvrg_military_heldconst		= sum(of champ_M[*]); 
		cvrg_other_heldconst  		= sum(of other_M[*]); 
		cvrg_ESI_S_heldconst		= sum(of esi_ph_s_M[*]); 
		cvrg_ESI_F_heldconst  		= sum(sum(of esi_ph_f_M[*]),sum(of esi_dep_M[*])); 
		cvrg_offmarket_S_heldconst  = sum(of offmarket_ph_s_M[*]);
		cvrg_offmarket_F_heldconst  = sum(sum(of offmarket_ph_f_M[*]),sum(of offmarket_dep_M[*]));
		cvrg_chip_heldconst	  		= sum(sum(of chip_M[*]));
		cvrg_unins_heldconst	  	= sum(sum(of unin_M[*]));

	/******************************************************************************************
	/	Calculate the policy-related variables (e.g., individual mandate penalty, premium tax
	/	credits, excise tax, cost-sharing reduction payment)
	/*****************************************************************************************/

		/**************************************************************************************
		/	Calculate the expected individual mandate penalty to the single-person HIU 
		/		if the only person in that HIU (whose coverage type is not held constant) is 
		/		subject to the individual mandate 
		/	Note that the expected average penalty per person is the total penalty for single-person HIUs 
		/*************************************************************************************/
		IM_PENALTY 		= sum(P_UN_nstUN	*IM_HIU1	);
		IM_PENALTY_avg	= sum(P_UN_nstUN	*IM_HIU1 /1	);

		/**************************************************************************************
		/	Count whether the only person in the single-person HIU (whose coverage type is not held constant)
		/		is eligible for the premium tax credits in the marketplace. 
		/	Calculate the expected subsidy amount
		/*************************************************************************************/
		%if &Marketplace_Exists.=yes %then %do;
			n_elig_PTC_in_hiu = 0; 
				do i = 1 to &dim.;
					if (elig_nongroup_covg[i] = 1 & age[i] ne . & elig_premium_tax_credit_hiu=1)  then n_elig_PTC_in_hiu  = n_elig_PTC_in_hiu + 1;		
				end;
			if (n_elig_PTC_in_hiu > 0 ) then	
				  e_onmarket_sub = sum(P_onB_Nst_onmarket*min(onmarket_subsidy,prem_onmarket_b),P_onS_Nst_onmarket*min(onmarket_subsidy,prem_onmarket_s),P_onG_Nst_onmarket*min(onmarket_subsidy,prem_onmarket_g));
			else  e_onmarket_sub = 0;
		%end;

		/**************************************************************************************
		/	Calculate the excise tax amount
		/*************************************************************************************/
		ET_total = 0;
		%do i=1 %to &DIM.;
			%macro o_type(TYP);
				if offer_&TYP.[&i.]=1 then do;
					ET_total=sum(ET_total,wgt[&i.]*sum(P_ESI_nstESI)*max(0,esi_s_prem_&TYP._tot[&i.]-(&EXCISE_TAX_THRESH_S.))*&ET_RATE.);
				end;
			%mend o_type; 
			%o_type(PPO); %o_type(HMO); %o_type(HDHP);
		%end;

		/**************************************************************************************
		/	Calculate the expected insurers' cost, expected premiums for the insurers, 
		/	and cost-sharing reduction payment in the marketplaces
		/*************************************************************************************/

			/**************************************************************************************
			/	Initialize arrays to zero
			/*************************************************************************************/
			%initialize_array_0;

			/**************************************************************************************
			/	Initialize the count variables to zero
			/*************************************************************************************/
			%initialize_n_to_0;

			/**************************************************************************************
			/	For the (only) member who is eligible for non-group plans in the marketplace
			/*************************************************************************************/
			%do i=1 %to &DIM.; 
				if undoc[&i.]=0 and medicaid_CHIP_elig[&i.] ne 1 and medicare_elig[&i.] ne 1 then do;
					/******************************************************************************
					/	Calculate the expected out-of-pocket health spending of enrolling 
					/	in non-group plans in the marketplace in total and by tier,
					/	looping through all 16 possible health states.
					/	Note: the arrays of prob&i.[j] and SPEND&p.[j] are the probability of being 
					/		  in health status[j] and related spending for person &i. in the HIU 
					/		  For details about probability distribution of health spending, 
					/		  see Jessica Banthin and others, Sources and Preparation of Data Used in
					/		  HISIM2CBOs Health Insurance Simulation Model, Working Paper 2019-04
					/		  (Congressional Budget Office, April 2019), www.cbo.gov/publication/55087.															
					/*****************************************************************************/
					do j=1 to 16;

						e_tot_spend_hlth[j] 	 = prob&i.[j]*SPEND&i.[j];

						if coin_nongroup_pre_b>0 then do;
						 e_oop_spend_onB_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_b/coin_nongroup_pre_b)*(SPEND&i.[j]*coin_nongroup_pre_b),(SPEND&i.[j]>ded_nongroup_b/coin_nongroup_pre_b)*(min(sum(ded_nongroup_b,(SPEND&i.[j]-ded_nongroup_b)*coin_nongroup_post_b),moop_nongroup_b)));
						end;
						if coin_nongroup_pre_s>0 then do;
			 			 e_oop_spend_onS_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_s/coin_nongroup_pre_s)*(SPEND&i.[j]*coin_nongroup_pre_s),(SPEND&i.[j]>ded_nongroup_s/coin_nongroup_pre_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)));
						end;
						if coin_nongroup_pre_g>0 then do;
			 			 e_oop_spend_onG_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_g/coin_nongroup_pre_g)*(SPEND&i.[j]*coin_nongroup_pre_g),(SPEND&i.[j]>ded_nongroup_g/coin_nongroup_pre_g)*(min(sum(ded_nongroup_g,(SPEND&i.[j]-ded_nongroup_g)*coin_nongroup_post_g),moop_nongroup_g)));
						end;	

						if coin_nongroup_pre_b=0 then do;
						 e_oop_spend_onB_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_b)*(SPEND&i.[j]*coin_nongroup_pre_b),(SPEND&i.[j]>ded_nongroup_b)*(min(sum(ded_nongroup_b,(SPEND&i.[j]-ded_nongroup_b)*coin_nongroup_post_b),moop_nongroup_b)));
						end;
						if coin_nongroup_pre_s=0 then do;
			 			 e_oop_spend_onS_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_s)*(SPEND&i.[j]*coin_nongroup_pre_s),(SPEND&i.[j]>ded_nongroup_s)*(min(sum(ded_nongroup_s,(SPEND&i.[j]-ded_nongroup_s)*coin_nongroup_post_s),moop_nongroup_s)));
						end;
						if coin_nongroup_pre_g=0 then do;
			 			 e_oop_spend_onG_hlth[j] = prob&i.[j]*sum((SPEND&i.[j]<=ded_nongroup_g)*(SPEND&i.[j]*coin_nongroup_pre_g),(SPEND&i.[j]>ded_nongroup_g)*(min(sum(ded_nongroup_g,(SPEND&i.[j]-ded_nongroup_g)*coin_nongroup_post_g),moop_nongroup_g)));
						end;	
					end;

					/******************************************************************************
					/	Calculate the HIU-level expected out-of-pocket health spending
					/*****************************************************************************/
					e_tot_spend_hiu1 	   = sum(of e_tot_spend_hlth[*]);
					e_oop_spend_onB_hiu1   = sum(of e_oop_spend_onB_hlth[*]);
			 		e_oop_spend_onS_hiu1   = sum(of e_oop_spend_onS_hlth[*]);
			 		e_oop_spend_onG_hiu1   = sum(of e_oop_spend_onG_hlth[*]);

					/******************************************************************************
					/	Calculate the HIU-level expected cost to the insurer
					/	Note: Nongroup plan characteristics (such as deductibles, copays, and coinsurance)
					/		  are assumed to be same between the plans in and outside the marketplaces
					/		  for a certain state and tier in the model, because insurers are required  
					/		  to offer the same plan outside the marketplaces as in marketplaces under current law.
					/*****************************************************************************/
					e_ins_spend_onB  	= (e_tot_spend_hiu1-e_oop_spend_onB_hiu1)*sum(P_onB_Nst_onmarket)*wgt[&i.];  
					e_ins_spend_onS  	= (e_tot_spend_hiu1-e_oop_spend_onS_hiu1)*sum(P_onS_Nst_onmarket)*wgt[&i.];
					e_ins_spend_onG  	= (e_tot_spend_hiu1-e_oop_spend_onG_hiu1)*sum(P_onG_Nst_onmarket)*wgt[&i.];	

					e_ins_spend_offB	= (e_tot_spend_hiu1-e_oop_spend_onB_hiu1)*sum(P_offB_Nst_offmarket)*wgt[&i.];	
					e_ins_spend_offS	= (e_tot_spend_hiu1-e_oop_spend_onS_hiu1)*sum(P_offS_Nst_offmarket)*wgt[&i.];	
					e_ins_spend_offG	= (e_tot_spend_hiu1-e_oop_spend_onG_hiu1)*sum(P_offG_Nst_offmarket)*wgt[&i.];	

					/******************************************************************************
					/	Calculate the HIU-level expected premium for the insurer
					/*****************************************************************************/
					e_ins_prem_onB	= prem_onmarket_b*sum(P_onB_Nst_onmarket)*wgt[&i.];
					e_ins_prem_onS  = prem_onmarket_s*sum(P_onS_Nst_onmarket)*wgt[&i.];
					e_ins_prem_onG  = prem_onmarket_g*sum(P_onG_Nst_onmarket)*wgt[&i.];

					e_ins_prem_offB = prem_offmarket_b*sum(P_offB_Nst_offmarket)*wgt[&i.];
					e_ins_prem_offS = prem_offmarket_s*sum(P_offS_Nst_offmarket)*wgt[&i.];
					e_ins_prem_offG = prem_offmarket_g*sum(P_offG_Nst_offmarket)*wgt[&i.];

					/******************************************************************************
					/	Calculate the HIU-level expected cost-sharing reduction payment
					/*****************************************************************************/
					e_csr_payment	= wgt[&i.]*(CS_VALUE*P_onS_Nst_onmarket);
				end;
			%end;

	/******************************************************************************************
	/	Output the HIU-level data for single-person HIUs 
	/*****************************************************************************************/
	output tempx.apply_model_base_hiu1;

run;

%mend simulate_single_person_HIUs;
